import { decodeAccount, assertAccountExists, fetchEncodedAccount, assertAccountsExist, fetchEncodedAccounts } from '@solana/accounts';
import { getProgramDerivedAddress, getAddressEncoder, getAddressDecoder, isProgramDerivedAddress } from '@solana/addresses';
import { getStringEncoder, getScalarEnumEncoder, getScalarEnumDecoder, combineCodec, getStructEncoder, getStructDecoder, getDataEnumEncoder, mapEncoder, getU64Encoder, getDataEnumDecoder, getU64Decoder, getBooleanEncoder, getBooleanDecoder, getUnitEncoder, getTupleEncoder, getUnitDecoder, getTupleDecoder, getU16Encoder, getOptionEncoder, getArrayEncoder, getU8Encoder, none, getStringDecoder, getU16Decoder, getOptionDecoder, getArrayDecoder, getU8Decoder, getMapEncoder, getMapDecoder, getBytesEncoder, getBytesDecoder, getU32Encoder, getU32Decoder } from '@solana/codecs';
import { AccountRole, upgradeRoleToSigner } from '@solana/instructions';
import { isTransactionSigner as isTransactionSigner$1, generateKeyPairSigner } from '@solana/signers';
import { getProgramDerivedAddress as getProgramDerivedAddress$1, getAddressEncoder as getAddressEncoder$1, pipe, appendTransactionInstruction } from '@solana/web3.js';
import { TOKEN_PROGRAM_ID, ASSOCIATED_TOKEN_ACCOUNTS_PROGRAM_ID, createDefaultTransaction, signAndSendTransaction, TOKEN22_PROGRAM_ID } from '@tensor-foundation/test-helpers';

// env-shim.ts
var __DEV__ = /* @__PURE__ */ (() => process["env"].NODE_ENV === "development")();
async function findCollectionAuthorityRecordPda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return getProgramDerivedAddress({
    programAddress,
    seeds: [
      getStringEncoder({ size: "variable" }).encode("metadata"),
      getAddressEncoder().encode(programAddress),
      getAddressEncoder().encode(seeds.mint),
      getStringEncoder({ size: "variable" }).encode("collection_authority"),
      getAddressEncoder().encode(seeds.collectionAuthority)
    ]
  });
}
async function findEditionMarkerPda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return getProgramDerivedAddress({
    programAddress,
    seeds: [
      getStringEncoder({ size: "variable" }).encode("metadata"),
      getAddressEncoder().encode(programAddress),
      getAddressEncoder().encode(seeds.mint),
      getStringEncoder({ size: "variable" }).encode("edition"),
      getStringEncoder({ size: "variable" }).encode(seeds.editionMarker)
    ]
  });
}
async function findEditionMarkerV2Pda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return getProgramDerivedAddress({
    programAddress,
    seeds: [
      getStringEncoder({ size: "variable" }).encode("metadata"),
      getAddressEncoder().encode(programAddress),
      getAddressEncoder().encode(seeds.mint),
      getStringEncoder({ size: "variable" }).encode("edition"),
      getStringEncoder({ size: "variable" }).encode("marker")
    ]
  });
}
async function findMasterEditionPda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return getProgramDerivedAddress({
    programAddress,
    seeds: [
      getStringEncoder({ size: "variable" }).encode("metadata"),
      getAddressEncoder().encode(programAddress),
      getAddressEncoder().encode(seeds.mint),
      getStringEncoder({ size: "variable" }).encode("edition")
    ]
  });
}
async function findMetadataPda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return getProgramDerivedAddress({
    programAddress,
    seeds: [
      getStringEncoder({ size: "variable" }).encode("metadata"),
      getAddressEncoder().encode(programAddress),
      getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findTokenRecordPda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return getProgramDerivedAddress({
    programAddress,
    seeds: [
      getStringEncoder({ size: "variable" }).encode("metadata"),
      getAddressEncoder().encode(programAddress),
      getAddressEncoder().encode(seeds.mint),
      getStringEncoder({ size: "variable" }).encode("token_record"),
      getAddressEncoder().encode(seeds.token)
    ]
  });
}
async function findUseAuthorityRecordPda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return getProgramDerivedAddress({
    programAddress,
    seeds: [
      getStringEncoder({ size: "variable" }).encode("metadata"),
      getAddressEncoder().encode(programAddress),
      getAddressEncoder().encode(seeds.mint),
      getStringEncoder({ size: "variable" }).encode("user"),
      getAddressEncoder().encode(seeds.useAuthority)
    ]
  });
}
var AuthorityType = /* @__PURE__ */ ((AuthorityType2) => {
  AuthorityType2[AuthorityType2["None"] = 0] = "None";
  AuthorityType2[AuthorityType2["Metadata"] = 1] = "Metadata";
  AuthorityType2[AuthorityType2["Holder"] = 2] = "Holder";
  AuthorityType2[AuthorityType2["MetadataDelegate"] = 3] = "MetadataDelegate";
  AuthorityType2[AuthorityType2["TokenDelegate"] = 4] = "TokenDelegate";
  return AuthorityType2;
})(AuthorityType || {});
function getAuthorityTypeEncoder() {
  return getScalarEnumEncoder(AuthorityType);
}
function getAuthorityTypeDecoder() {
  return getScalarEnumDecoder(AuthorityType);
}
function getAuthorityTypeCodec() {
  return combineCodec(getAuthorityTypeEncoder(), getAuthorityTypeDecoder());
}
function getAuthorizationDataEncoder() {
  return getStructEncoder([["payload", getPayloadEncoder()]]);
}
function getAuthorizationDataDecoder() {
  return getStructDecoder([["payload", getPayloadDecoder()]]);
}
function getAuthorizationDataCodec() {
  return combineCodec(
    getAuthorizationDataEncoder(),
    getAuthorizationDataDecoder()
  );
}
function getBurnArgsEncoder() {
  return getDataEnumEncoder([
    [
      "V1",
      mapEncoder(getStructEncoder([["amount", getU64Encoder()]]), (value) => ({
        ...value,
        amount: value.amount ?? 1
      }))
    ]
  ]);
}
function getBurnArgsDecoder() {
  return getDataEnumDecoder([
    ["V1", getStructDecoder([["amount", getU64Decoder()]])]
  ]);
}
function getBurnArgsCodec() {
  return combineCodec(getBurnArgsEncoder(), getBurnArgsDecoder());
}
function burnArgs(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isBurnArgs(kind, value) {
  return value.__kind === kind;
}
function getCollectionEncoder() {
  return getStructEncoder([
    ["verified", getBooleanEncoder()],
    ["key", getAddressEncoder()]
  ]);
}
function getCollectionDecoder() {
  return getStructDecoder([
    ["verified", getBooleanDecoder()],
    ["key", getAddressDecoder()]
  ]);
}
function getCollectionCodec() {
  return combineCodec(getCollectionEncoder(), getCollectionDecoder());
}
function getCollectionDetailsEncoder() {
  return getDataEnumEncoder([
    ["V1", getStructEncoder([["size", getU64Encoder()]])]
  ]);
}
function getCollectionDetailsDecoder() {
  return getDataEnumDecoder([
    ["V1", getStructDecoder([["size", getU64Decoder()]])]
  ]);
}
function getCollectionDetailsCodec() {
  return combineCodec(
    getCollectionDetailsEncoder(),
    getCollectionDetailsDecoder()
  );
}
function collectionDetails(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isCollectionDetails(kind, value) {
  return value.__kind === kind;
}
function getCollectionDetailsToggleEncoder() {
  return getDataEnumEncoder([
    ["None", getUnitEncoder()],
    ["Clear", getUnitEncoder()],
    [
      "Set",
      getStructEncoder([
        ["fields", getTupleEncoder([getCollectionDetailsEncoder()])]
      ])
    ]
  ]);
}
function getCollectionDetailsToggleDecoder() {
  return getDataEnumDecoder([
    ["None", getUnitDecoder()],
    ["Clear", getUnitDecoder()],
    [
      "Set",
      getStructDecoder([
        ["fields", getTupleDecoder([getCollectionDetailsDecoder()])]
      ])
    ]
  ]);
}
function getCollectionDetailsToggleCodec() {
  return combineCodec(
    getCollectionDetailsToggleEncoder(),
    getCollectionDetailsToggleDecoder()
  );
}
function collectionDetailsToggle(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isCollectionDetailsToggle(kind, value) {
  return value.__kind === kind;
}
function getCollectionToggleEncoder() {
  return getDataEnumEncoder([
    ["None", getUnitEncoder()],
    ["Clear", getUnitEncoder()],
    [
      "Set",
      getStructEncoder([["fields", getTupleEncoder([getCollectionEncoder()])]])
    ]
  ]);
}
function getCollectionToggleDecoder() {
  return getDataEnumDecoder([
    ["None", getUnitDecoder()],
    ["Clear", getUnitDecoder()],
    [
      "Set",
      getStructDecoder([["fields", getTupleDecoder([getCollectionDecoder()])]])
    ]
  ]);
}
function getCollectionToggleCodec() {
  return combineCodec(
    getCollectionToggleEncoder(),
    getCollectionToggleDecoder()
  );
}
function collectionToggle(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isCollectionToggle(kind, value) {
  return value.__kind === kind;
}
function getCreateArgsEncoder() {
  return getDataEnumEncoder([
    [
      "V1",
      mapEncoder(
        getStructEncoder([
          ["name", getStringEncoder()],
          ["symbol", getStringEncoder()],
          ["uri", getStringEncoder()],
          ["sellerFeeBasisPoints", getU16Encoder()],
          ["creators", getOptionEncoder(getArrayEncoder(getCreatorEncoder()))],
          ["primarySaleHappened", getBooleanEncoder()],
          ["isMutable", getBooleanEncoder()],
          ["tokenStandard", getTokenStandardEncoder()],
          ["collection", getOptionEncoder(getCollectionEncoder())],
          ["uses", getOptionEncoder(getUsesEncoder())],
          [
            "collectionDetails",
            getOptionEncoder(getCollectionDetailsEncoder())
          ],
          ["ruleSet", getOptionEncoder(getAddressEncoder())],
          ["decimals", getOptionEncoder(getU8Encoder())],
          ["printSupply", getOptionEncoder(getPrintSupplyEncoder())]
        ]),
        (value) => ({
          ...value,
          symbol: value.symbol ?? "",
          primarySaleHappened: value.primarySaleHappened ?? false,
          isMutable: value.isMutable ?? true,
          collection: value.collection ?? none(),
          uses: value.uses ?? none(),
          collectionDetails: value.collectionDetails ?? none(),
          ruleSet: value.ruleSet ?? none(),
          decimals: value.decimals ?? none(),
          printSupply: value.printSupply ?? none()
        })
      )
    ]
  ]);
}
function getCreateArgsDecoder() {
  return getDataEnumDecoder([
    [
      "V1",
      getStructDecoder([
        ["name", getStringDecoder()],
        ["symbol", getStringDecoder()],
        ["uri", getStringDecoder()],
        ["sellerFeeBasisPoints", getU16Decoder()],
        ["creators", getOptionDecoder(getArrayDecoder(getCreatorDecoder()))],
        ["primarySaleHappened", getBooleanDecoder()],
        ["isMutable", getBooleanDecoder()],
        ["tokenStandard", getTokenStandardDecoder()],
        ["collection", getOptionDecoder(getCollectionDecoder())],
        ["uses", getOptionDecoder(getUsesDecoder())],
        ["collectionDetails", getOptionDecoder(getCollectionDetailsDecoder())],
        ["ruleSet", getOptionDecoder(getAddressDecoder())],
        ["decimals", getOptionDecoder(getU8Decoder())],
        ["printSupply", getOptionDecoder(getPrintSupplyDecoder())]
      ])
    ]
  ]);
}
function getCreateArgsCodec() {
  return combineCodec(getCreateArgsEncoder(), getCreateArgsDecoder());
}
function createArgs(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isCreateArgs(kind, value) {
  return value.__kind === kind;
}
function getCreatorEncoder() {
  return getStructEncoder([
    ["address", getAddressEncoder()],
    ["verified", getBooleanEncoder()],
    ["share", getU8Encoder()]
  ]);
}
function getCreatorDecoder() {
  return getStructDecoder([
    ["address", getAddressDecoder()],
    ["verified", getBooleanDecoder()],
    ["share", getU8Decoder()]
  ]);
}
function getCreatorCodec() {
  return combineCodec(getCreatorEncoder(), getCreatorDecoder());
}
function getDataEncoder() {
  return getStructEncoder([
    ["name", getStringEncoder()],
    ["symbol", getStringEncoder()],
    ["uri", getStringEncoder()],
    ["sellerFeeBasisPoints", getU16Encoder()],
    ["creators", getOptionEncoder(getArrayEncoder(getCreatorEncoder()))]
  ]);
}
function getDataDecoder() {
  return getStructDecoder([
    ["name", getStringDecoder()],
    ["symbol", getStringDecoder()],
    ["uri", getStringDecoder()],
    ["sellerFeeBasisPoints", getU16Decoder()],
    ["creators", getOptionDecoder(getArrayDecoder(getCreatorDecoder()))]
  ]);
}
function getDataCodec() {
  return combineCodec(getDataEncoder(), getDataDecoder());
}
function getDataV2Encoder() {
  return getStructEncoder([
    ["name", getStringEncoder()],
    ["symbol", getStringEncoder()],
    ["uri", getStringEncoder()],
    ["sellerFeeBasisPoints", getU16Encoder()],
    ["creators", getOptionEncoder(getArrayEncoder(getCreatorEncoder()))],
    ["collection", getOptionEncoder(getCollectionEncoder())],
    ["uses", getOptionEncoder(getUsesEncoder())]
  ]);
}
function getDataV2Decoder() {
  return getStructDecoder([
    ["name", getStringDecoder()],
    ["symbol", getStringDecoder()],
    ["uri", getStringDecoder()],
    ["sellerFeeBasisPoints", getU16Decoder()],
    ["creators", getOptionDecoder(getArrayDecoder(getCreatorDecoder()))],
    ["collection", getOptionDecoder(getCollectionDecoder())],
    ["uses", getOptionDecoder(getUsesDecoder())]
  ]);
}
function getDataV2Codec() {
  return combineCodec(getDataV2Encoder(), getDataV2Decoder());
}
function getDelegateArgsEncoder() {
  return getDataEnumEncoder([
    [
      "CollectionV1",
      mapEncoder(
        getStructEncoder([
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          authorizationData: value.authorizationData ?? none()
        })
      )
    ],
    [
      "SaleV1",
      mapEncoder(
        getStructEncoder([
          ["amount", getU64Encoder()],
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          amount: value.amount ?? 1,
          authorizationData: value.authorizationData ?? none()
        })
      )
    ],
    [
      "TransferV1",
      mapEncoder(
        getStructEncoder([
          ["amount", getU64Encoder()],
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          amount: value.amount ?? 1,
          authorizationData: value.authorizationData ?? none()
        })
      )
    ],
    [
      "DataV1",
      mapEncoder(
        getStructEncoder([
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          authorizationData: value.authorizationData ?? none()
        })
      )
    ],
    [
      "UtilityV1",
      mapEncoder(
        getStructEncoder([
          ["amount", getU64Encoder()],
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          amount: value.amount ?? 1,
          authorizationData: value.authorizationData ?? none()
        })
      )
    ],
    [
      "StakingV1",
      mapEncoder(
        getStructEncoder([
          ["amount", getU64Encoder()],
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          amount: value.amount ?? 1,
          authorizationData: value.authorizationData ?? none()
        })
      )
    ],
    [
      "StandardV1",
      mapEncoder(getStructEncoder([["amount", getU64Encoder()]]), (value) => ({
        ...value,
        amount: value.amount ?? 1
      }))
    ],
    [
      "LockedTransferV1",
      mapEncoder(
        getStructEncoder([
          ["amount", getU64Encoder()],
          ["lockedAddress", getAddressEncoder()],
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          amount: value.amount ?? 1,
          authorizationData: value.authorizationData ?? none()
        })
      )
    ],
    [
      "ProgrammableConfigV1",
      mapEncoder(
        getStructEncoder([
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          authorizationData: value.authorizationData ?? none()
        })
      )
    ],
    [
      "AuthorityItemV1",
      mapEncoder(
        getStructEncoder([
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          authorizationData: value.authorizationData ?? none()
        })
      )
    ],
    [
      "DataItemV1",
      mapEncoder(
        getStructEncoder([
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          authorizationData: value.authorizationData ?? none()
        })
      )
    ],
    [
      "CollectionItemV1",
      mapEncoder(
        getStructEncoder([
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          authorizationData: value.authorizationData ?? none()
        })
      )
    ],
    [
      "ProgrammableConfigItemV1",
      mapEncoder(
        getStructEncoder([
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          authorizationData: value.authorizationData ?? none()
        })
      )
    ]
  ]);
}
function getDelegateArgsDecoder() {
  return getDataEnumDecoder([
    [
      "CollectionV1",
      getStructDecoder([
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "SaleV1",
      getStructDecoder([
        ["amount", getU64Decoder()],
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "TransferV1",
      getStructDecoder([
        ["amount", getU64Decoder()],
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "DataV1",
      getStructDecoder([
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "UtilityV1",
      getStructDecoder([
        ["amount", getU64Decoder()],
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "StakingV1",
      getStructDecoder([
        ["amount", getU64Decoder()],
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    ["StandardV1", getStructDecoder([["amount", getU64Decoder()]])],
    [
      "LockedTransferV1",
      getStructDecoder([
        ["amount", getU64Decoder()],
        ["lockedAddress", getAddressDecoder()],
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "ProgrammableConfigV1",
      getStructDecoder([
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "AuthorityItemV1",
      getStructDecoder([
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "DataItemV1",
      getStructDecoder([
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "CollectionItemV1",
      getStructDecoder([
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "ProgrammableConfigItemV1",
      getStructDecoder([
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ]
  ]);
}
function getDelegateArgsCodec() {
  return combineCodec(getDelegateArgsEncoder(), getDelegateArgsDecoder());
}
function delegateArgs(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isDelegateArgs(kind, value) {
  return value.__kind === kind;
}
function getEscrowAuthorityEncoder() {
  return getDataEnumEncoder([
    ["TokenOwner", getUnitEncoder()],
    [
      "Creator",
      getStructEncoder([["fields", getTupleEncoder([getAddressEncoder()])]])
    ]
  ]);
}
function getEscrowAuthorityDecoder() {
  return getDataEnumDecoder([
    ["TokenOwner", getUnitDecoder()],
    [
      "Creator",
      getStructDecoder([["fields", getTupleDecoder([getAddressDecoder()])]])
    ]
  ]);
}
function getEscrowAuthorityCodec() {
  return combineCodec(getEscrowAuthorityEncoder(), getEscrowAuthorityDecoder());
}
function escrowAuthority(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isEscrowAuthority(kind, value) {
  return value.__kind === kind;
}
var Key = /* @__PURE__ */ ((Key4) => {
  Key4[Key4["Uninitialized"] = 0] = "Uninitialized";
  Key4[Key4["EditionV1"] = 1] = "EditionV1";
  Key4[Key4["MasterEditionV1"] = 2] = "MasterEditionV1";
  Key4[Key4["ReservationListV1"] = 3] = "ReservationListV1";
  Key4[Key4["MetadataV1"] = 4] = "MetadataV1";
  Key4[Key4["ReservationListV2"] = 5] = "ReservationListV2";
  Key4[Key4["MasterEditionV2"] = 6] = "MasterEditionV2";
  Key4[Key4["EditionMarker"] = 7] = "EditionMarker";
  Key4[Key4["UseAuthorityRecord"] = 8] = "UseAuthorityRecord";
  Key4[Key4["CollectionAuthorityRecord"] = 9] = "CollectionAuthorityRecord";
  Key4[Key4["TokenOwnedEscrow"] = 10] = "TokenOwnedEscrow";
  Key4[Key4["TokenRecord"] = 11] = "TokenRecord";
  Key4[Key4["MetadataDelegate"] = 12] = "MetadataDelegate";
  Key4[Key4["EditionMarkerV2"] = 13] = "EditionMarkerV2";
  return Key4;
})(Key || {});
function getKeyEncoder() {
  return getScalarEnumEncoder(Key);
}
function getKeyDecoder() {
  return getScalarEnumDecoder(Key);
}
function getKeyCodec() {
  return combineCodec(getKeyEncoder(), getKeyDecoder());
}
function getLockArgsEncoder() {
  return getDataEnumEncoder([
    [
      "V1",
      mapEncoder(
        getStructEncoder([
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          authorizationData: value.authorizationData ?? none()
        })
      )
    ]
  ]);
}
function getLockArgsDecoder() {
  return getDataEnumDecoder([
    [
      "V1",
      getStructDecoder([
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ]
  ]);
}
function getLockArgsCodec() {
  return combineCodec(getLockArgsEncoder(), getLockArgsDecoder());
}
function lockArgs(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isLockArgs(kind, value) {
  return value.__kind === kind;
}
var MetadataDelegateRole = /* @__PURE__ */ ((MetadataDelegateRole2) => {
  MetadataDelegateRole2[MetadataDelegateRole2["AuthorityItem"] = 0] = "AuthorityItem";
  MetadataDelegateRole2[MetadataDelegateRole2["Collection"] = 1] = "Collection";
  MetadataDelegateRole2[MetadataDelegateRole2["Use"] = 2] = "Use";
  MetadataDelegateRole2[MetadataDelegateRole2["Data"] = 3] = "Data";
  MetadataDelegateRole2[MetadataDelegateRole2["ProgrammableConfig"] = 4] = "ProgrammableConfig";
  MetadataDelegateRole2[MetadataDelegateRole2["DataItem"] = 5] = "DataItem";
  MetadataDelegateRole2[MetadataDelegateRole2["CollectionItem"] = 6] = "CollectionItem";
  MetadataDelegateRole2[MetadataDelegateRole2["ProgrammableConfigItem"] = 7] = "ProgrammableConfigItem";
  return MetadataDelegateRole2;
})(MetadataDelegateRole || {});
function getMetadataDelegateRoleEncoder() {
  return getScalarEnumEncoder(MetadataDelegateRole);
}
function getMetadataDelegateRoleDecoder() {
  return getScalarEnumDecoder(MetadataDelegateRole);
}
function getMetadataDelegateRoleCodec() {
  return combineCodec(
    getMetadataDelegateRoleEncoder(),
    getMetadataDelegateRoleDecoder()
  );
}
var MigrationType = /* @__PURE__ */ ((MigrationType2) => {
  MigrationType2[MigrationType2["CollectionV1"] = 0] = "CollectionV1";
  MigrationType2[MigrationType2["ProgrammableV1"] = 1] = "ProgrammableV1";
  return MigrationType2;
})(MigrationType || {});
function getMigrationTypeEncoder() {
  return getScalarEnumEncoder(MigrationType);
}
function getMigrationTypeDecoder() {
  return getScalarEnumDecoder(MigrationType);
}
function getMigrationTypeCodec() {
  return combineCodec(getMigrationTypeEncoder(), getMigrationTypeDecoder());
}
function getMintArgsEncoder() {
  return getDataEnumEncoder([
    [
      "V1",
      mapEncoder(
        getStructEncoder([
          ["amount", getU64Encoder()],
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          amount: value.amount ?? 1,
          authorizationData: value.authorizationData ?? none()
        })
      )
    ]
  ]);
}
function getMintArgsDecoder() {
  return getDataEnumDecoder([
    [
      "V1",
      getStructDecoder([
        ["amount", getU64Decoder()],
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ]
  ]);
}
function getMintArgsCodec() {
  return combineCodec(getMintArgsEncoder(), getMintArgsDecoder());
}
function mintArgs(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isMintArgs(kind, value) {
  return value.__kind === kind;
}
function getMintNewEditionFromMasterEditionViaTokenArgsEncoder() {
  return getStructEncoder([["edition", getU64Encoder()]]);
}
function getMintNewEditionFromMasterEditionViaTokenArgsDecoder() {
  return getStructDecoder([["edition", getU64Decoder()]]);
}
function getMintNewEditionFromMasterEditionViaTokenArgsCodec() {
  return combineCodec(
    getMintNewEditionFromMasterEditionViaTokenArgsEncoder(),
    getMintNewEditionFromMasterEditionViaTokenArgsDecoder()
  );
}
function getPayloadEncoder() {
  return getStructEncoder([
    ["map", getMapEncoder(getStringEncoder(), getPayloadTypeEncoder())]
  ]);
}
function getPayloadDecoder() {
  return getStructDecoder([
    ["map", getMapDecoder(getStringDecoder(), getPayloadTypeDecoder())]
  ]);
}
function getPayloadCodec() {
  return combineCodec(getPayloadEncoder(), getPayloadDecoder());
}
var PayloadKey = /* @__PURE__ */ ((PayloadKey2) => {
  PayloadKey2[PayloadKey2["Amount"] = 0] = "Amount";
  PayloadKey2[PayloadKey2["Authority"] = 1] = "Authority";
  PayloadKey2[PayloadKey2["AuthoritySeeds"] = 2] = "AuthoritySeeds";
  PayloadKey2[PayloadKey2["Delegate"] = 3] = "Delegate";
  PayloadKey2[PayloadKey2["DelegateSeeds"] = 4] = "DelegateSeeds";
  PayloadKey2[PayloadKey2["Destination"] = 5] = "Destination";
  PayloadKey2[PayloadKey2["DestinationSeeds"] = 6] = "DestinationSeeds";
  PayloadKey2[PayloadKey2["Holder"] = 7] = "Holder";
  PayloadKey2[PayloadKey2["Source"] = 8] = "Source";
  PayloadKey2[PayloadKey2["SourceSeeds"] = 9] = "SourceSeeds";
  return PayloadKey2;
})(PayloadKey || {});
function getPayloadKeyEncoder() {
  return getScalarEnumEncoder(PayloadKey);
}
function getPayloadKeyDecoder() {
  return getScalarEnumDecoder(PayloadKey);
}
function getPayloadKeyCodec() {
  return combineCodec(getPayloadKeyEncoder(), getPayloadKeyDecoder());
}
function getPayloadTypeEncoder() {
  return getDataEnumEncoder([
    [
      "Pubkey",
      getStructEncoder([["fields", getTupleEncoder([getAddressEncoder()])]])
    ],
    [
      "Seeds",
      getStructEncoder([["fields", getTupleEncoder([getSeedsVecEncoder()])]])
    ],
    [
      "MerkleProof",
      getStructEncoder([["fields", getTupleEncoder([getProofInfoEncoder()])]])
    ],
    [
      "Number",
      getStructEncoder([["fields", getTupleEncoder([getU64Encoder()])]])
    ]
  ]);
}
function getPayloadTypeDecoder() {
  return getDataEnumDecoder([
    [
      "Pubkey",
      getStructDecoder([["fields", getTupleDecoder([getAddressDecoder()])]])
    ],
    [
      "Seeds",
      getStructDecoder([["fields", getTupleDecoder([getSeedsVecDecoder()])]])
    ],
    [
      "MerkleProof",
      getStructDecoder([["fields", getTupleDecoder([getProofInfoDecoder()])]])
    ],
    [
      "Number",
      getStructDecoder([["fields", getTupleDecoder([getU64Decoder()])]])
    ]
  ]);
}
function getPayloadTypeCodec() {
  return combineCodec(getPayloadTypeEncoder(), getPayloadTypeDecoder());
}
function payloadType(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isPayloadType(kind, value) {
  return value.__kind === kind;
}
function getPrintArgsEncoder() {
  return getDataEnumEncoder([
    ["V1", getStructEncoder([["edition", getU64Encoder()]])]
  ]);
}
function getPrintArgsDecoder() {
  return getDataEnumDecoder([
    ["V1", getStructDecoder([["edition", getU64Decoder()]])]
  ]);
}
function getPrintArgsCodec() {
  return combineCodec(getPrintArgsEncoder(), getPrintArgsDecoder());
}
function printArgs(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isPrintArgs(kind, value) {
  return value.__kind === kind;
}
function getPrintSupplyEncoder() {
  return getDataEnumEncoder([
    ["Zero", getUnitEncoder()],
    [
      "Limited",
      getStructEncoder([["fields", getTupleEncoder([getU64Encoder()])]])
    ],
    ["Unlimited", getUnitEncoder()]
  ]);
}
function getPrintSupplyDecoder() {
  return getDataEnumDecoder([
    ["Zero", getUnitDecoder()],
    [
      "Limited",
      getStructDecoder([["fields", getTupleDecoder([getU64Decoder()])]])
    ],
    ["Unlimited", getUnitDecoder()]
  ]);
}
function getPrintSupplyCodec() {
  return combineCodec(getPrintSupplyEncoder(), getPrintSupplyDecoder());
}
function printSupply(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isPrintSupply(kind, value) {
  return value.__kind === kind;
}
function getProgrammableConfigEncoder() {
  return getDataEnumEncoder([
    [
      "V1",
      getStructEncoder([["ruleSet", getOptionEncoder(getAddressEncoder())]])
    ]
  ]);
}
function getProgrammableConfigDecoder() {
  return getDataEnumDecoder([
    [
      "V1",
      getStructDecoder([["ruleSet", getOptionDecoder(getAddressDecoder())]])
    ]
  ]);
}
function getProgrammableConfigCodec() {
  return combineCodec(
    getProgrammableConfigEncoder(),
    getProgrammableConfigDecoder()
  );
}
function programmableConfig(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isProgrammableConfig(kind, value) {
  return value.__kind === kind;
}
function getProofInfoEncoder() {
  return getStructEncoder([
    ["proof", getArrayEncoder(getBytesEncoder({ size: 32 }))]
  ]);
}
function getProofInfoDecoder() {
  return getStructDecoder([
    ["proof", getArrayDecoder(getBytesDecoder({ size: 32 }))]
  ]);
}
function getProofInfoCodec() {
  return combineCodec(getProofInfoEncoder(), getProofInfoDecoder());
}
function getReservationEncoder() {
  return getStructEncoder([
    ["address", getAddressEncoder()],
    ["spotsRemaining", getU64Encoder()],
    ["totalSpots", getU64Encoder()]
  ]);
}
function getReservationDecoder() {
  return getStructDecoder([
    ["address", getAddressDecoder()],
    ["spotsRemaining", getU64Decoder()],
    ["totalSpots", getU64Decoder()]
  ]);
}
function getReservationCodec() {
  return combineCodec(getReservationEncoder(), getReservationDecoder());
}
function getReservationV1Encoder() {
  return getStructEncoder([
    ["address", getAddressEncoder()],
    ["spotsRemaining", getU8Encoder()],
    ["totalSpots", getU8Encoder()]
  ]);
}
function getReservationV1Decoder() {
  return getStructDecoder([
    ["address", getAddressDecoder()],
    ["spotsRemaining", getU8Decoder()],
    ["totalSpots", getU8Decoder()]
  ]);
}
function getReservationV1Codec() {
  return combineCodec(getReservationV1Encoder(), getReservationV1Decoder());
}
var RevokeArgs = /* @__PURE__ */ ((RevokeArgs2) => {
  RevokeArgs2[RevokeArgs2["CollectionV1"] = 0] = "CollectionV1";
  RevokeArgs2[RevokeArgs2["SaleV1"] = 1] = "SaleV1";
  RevokeArgs2[RevokeArgs2["TransferV1"] = 2] = "TransferV1";
  RevokeArgs2[RevokeArgs2["DataV1"] = 3] = "DataV1";
  RevokeArgs2[RevokeArgs2["UtilityV1"] = 4] = "UtilityV1";
  RevokeArgs2[RevokeArgs2["StakingV1"] = 5] = "StakingV1";
  RevokeArgs2[RevokeArgs2["StandardV1"] = 6] = "StandardV1";
  RevokeArgs2[RevokeArgs2["LockedTransferV1"] = 7] = "LockedTransferV1";
  RevokeArgs2[RevokeArgs2["ProgrammableConfigV1"] = 8] = "ProgrammableConfigV1";
  RevokeArgs2[RevokeArgs2["MigrationV1"] = 9] = "MigrationV1";
  RevokeArgs2[RevokeArgs2["AuthorityItemV1"] = 10] = "AuthorityItemV1";
  RevokeArgs2[RevokeArgs2["DataItemV1"] = 11] = "DataItemV1";
  RevokeArgs2[RevokeArgs2["CollectionItemV1"] = 12] = "CollectionItemV1";
  RevokeArgs2[RevokeArgs2["ProgrammableConfigItemV1"] = 13] = "ProgrammableConfigItemV1";
  return RevokeArgs2;
})(RevokeArgs || {});
function getRevokeArgsEncoder() {
  return getScalarEnumEncoder(RevokeArgs);
}
function getRevokeArgsDecoder() {
  return getScalarEnumDecoder(RevokeArgs);
}
function getRevokeArgsCodec() {
  return combineCodec(getRevokeArgsEncoder(), getRevokeArgsDecoder());
}
function getRuleSetToggleEncoder() {
  return getDataEnumEncoder([
    ["None", getUnitEncoder()],
    ["Clear", getUnitEncoder()],
    [
      "Set",
      getStructEncoder([["fields", getTupleEncoder([getAddressEncoder()])]])
    ]
  ]);
}
function getRuleSetToggleDecoder() {
  return getDataEnumDecoder([
    ["None", getUnitDecoder()],
    ["Clear", getUnitDecoder()],
    [
      "Set",
      getStructDecoder([["fields", getTupleDecoder([getAddressDecoder()])]])
    ]
  ]);
}
function getRuleSetToggleCodec() {
  return combineCodec(getRuleSetToggleEncoder(), getRuleSetToggleDecoder());
}
function ruleSetToggle(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isRuleSetToggle(kind, value) {
  return value.__kind === kind;
}
function getSeedsVecEncoder() {
  return getStructEncoder([
    ["seeds", getArrayEncoder(getBytesEncoder({ size: getU32Encoder() }))]
  ]);
}
function getSeedsVecDecoder() {
  return getStructDecoder([
    ["seeds", getArrayDecoder(getBytesDecoder({ size: getU32Decoder() }))]
  ]);
}
function getSeedsVecCodec() {
  return combineCodec(getSeedsVecEncoder(), getSeedsVecDecoder());
}
function getSetCollectionSizeArgsEncoder() {
  return getStructEncoder([["size", getU64Encoder()]]);
}
function getSetCollectionSizeArgsDecoder() {
  return getStructDecoder([["size", getU64Decoder()]]);
}
function getSetCollectionSizeArgsCodec() {
  return combineCodec(
    getSetCollectionSizeArgsEncoder(),
    getSetCollectionSizeArgsDecoder()
  );
}
var TokenDelegateRole = /* @__PURE__ */ ((TokenDelegateRole3) => {
  TokenDelegateRole3[TokenDelegateRole3["Sale"] = 0] = "Sale";
  TokenDelegateRole3[TokenDelegateRole3["Transfer"] = 1] = "Transfer";
  TokenDelegateRole3[TokenDelegateRole3["Utility"] = 2] = "Utility";
  TokenDelegateRole3[TokenDelegateRole3["Staking"] = 3] = "Staking";
  TokenDelegateRole3[TokenDelegateRole3["Standard"] = 4] = "Standard";
  TokenDelegateRole3[TokenDelegateRole3["LockedTransfer"] = 5] = "LockedTransfer";
  TokenDelegateRole3[TokenDelegateRole3["Migration"] = 6] = "Migration";
  return TokenDelegateRole3;
})(TokenDelegateRole || {});
function getTokenDelegateRoleEncoder() {
  return getScalarEnumEncoder(TokenDelegateRole);
}
function getTokenDelegateRoleDecoder() {
  return getScalarEnumDecoder(TokenDelegateRole);
}
function getTokenDelegateRoleCodec() {
  return combineCodec(
    getTokenDelegateRoleEncoder(),
    getTokenDelegateRoleDecoder()
  );
}
var TokenStandard2 = /* @__PURE__ */ ((TokenStandard5) => {
  TokenStandard5[TokenStandard5["NonFungible"] = 0] = "NonFungible";
  TokenStandard5[TokenStandard5["FungibleAsset"] = 1] = "FungibleAsset";
  TokenStandard5[TokenStandard5["Fungible"] = 2] = "Fungible";
  TokenStandard5[TokenStandard5["NonFungibleEdition"] = 3] = "NonFungibleEdition";
  TokenStandard5[TokenStandard5["ProgrammableNonFungible"] = 4] = "ProgrammableNonFungible";
  TokenStandard5[TokenStandard5["ProgrammableNonFungibleEdition"] = 5] = "ProgrammableNonFungibleEdition";
  return TokenStandard5;
})(TokenStandard2 || {});
function getTokenStandardEncoder() {
  return getScalarEnumEncoder(TokenStandard2);
}
function getTokenStandardDecoder() {
  return getScalarEnumDecoder(TokenStandard2);
}
function getTokenStandardCodec() {
  return combineCodec(getTokenStandardEncoder(), getTokenStandardDecoder());
}
var TokenState = /* @__PURE__ */ ((TokenState3) => {
  TokenState3[TokenState3["Unlocked"] = 0] = "Unlocked";
  TokenState3[TokenState3["Locked"] = 1] = "Locked";
  TokenState3[TokenState3["Listed"] = 2] = "Listed";
  return TokenState3;
})(TokenState || {});
function getTokenStateEncoder() {
  return getScalarEnumEncoder(TokenState);
}
function getTokenStateDecoder() {
  return getScalarEnumDecoder(TokenState);
}
function getTokenStateCodec() {
  return combineCodec(getTokenStateEncoder(), getTokenStateDecoder());
}
function getTransferArgsEncoder() {
  return getDataEnumEncoder([
    [
      "V1",
      mapEncoder(
        getStructEncoder([
          ["amount", getU64Encoder()],
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          amount: value.amount ?? 1,
          authorizationData: value.authorizationData ?? none()
        })
      )
    ]
  ]);
}
function getTransferArgsDecoder() {
  return getDataEnumDecoder([
    [
      "V1",
      getStructDecoder([
        ["amount", getU64Decoder()],
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ]
  ]);
}
function getTransferArgsCodec() {
  return combineCodec(getTransferArgsEncoder(), getTransferArgsDecoder());
}
function transferArgs(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isTransferArgs(kind, value) {
  return value.__kind === kind;
}
function getUnlockArgsEncoder() {
  return getDataEnumEncoder([
    [
      "V1",
      mapEncoder(
        getStructEncoder([
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          authorizationData: value.authorizationData ?? none()
        })
      )
    ]
  ]);
}
function getUnlockArgsDecoder() {
  return getDataEnumDecoder([
    [
      "V1",
      getStructDecoder([
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ]
  ]);
}
function getUnlockArgsCodec() {
  return combineCodec(getUnlockArgsEncoder(), getUnlockArgsDecoder());
}
function unlockArgs(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isUnlockArgs(kind, value) {
  return value.__kind === kind;
}
function getUpdateArgsEncoder() {
  return getDataEnumEncoder([
    [
      "V1",
      mapEncoder(
        getStructEncoder([
          ["newUpdateAuthority", getOptionEncoder(getAddressEncoder())],
          ["data", getOptionEncoder(getDataEncoder())],
          ["primarySaleHappened", getOptionEncoder(getBooleanEncoder())],
          ["isMutable", getOptionEncoder(getBooleanEncoder())],
          ["collection", getCollectionToggleEncoder()],
          ["collectionDetails", getCollectionDetailsToggleEncoder()],
          ["uses", getUsesToggleEncoder()],
          ["ruleSet", getRuleSetToggleEncoder()],
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          newUpdateAuthority: value.newUpdateAuthority ?? none(),
          data: value.data ?? none(),
          primarySaleHappened: value.primarySaleHappened ?? none(),
          isMutable: value.isMutable ?? none(),
          collection: value.collection ?? collectionToggle("None"),
          collectionDetails: value.collectionDetails ?? collectionDetailsToggle("None"),
          uses: value.uses ?? usesToggle("None"),
          ruleSet: value.ruleSet ?? ruleSetToggle("None"),
          authorizationData: value.authorizationData ?? none()
        })
      )
    ],
    [
      "AsUpdateAuthorityV2",
      mapEncoder(
        getStructEncoder([
          ["newUpdateAuthority", getOptionEncoder(getAddressEncoder())],
          ["data", getOptionEncoder(getDataEncoder())],
          ["primarySaleHappened", getOptionEncoder(getBooleanEncoder())],
          ["isMutable", getOptionEncoder(getBooleanEncoder())],
          ["collection", getCollectionToggleEncoder()],
          ["collectionDetails", getCollectionDetailsToggleEncoder()],
          ["uses", getUsesToggleEncoder()],
          ["ruleSet", getRuleSetToggleEncoder()],
          ["tokenStandard", getOptionEncoder(getTokenStandardEncoder())],
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          newUpdateAuthority: value.newUpdateAuthority ?? none(),
          data: value.data ?? none(),
          primarySaleHappened: value.primarySaleHappened ?? none(),
          isMutable: value.isMutable ?? none(),
          collection: value.collection ?? collectionToggle("None"),
          collectionDetails: value.collectionDetails ?? collectionDetailsToggle("None"),
          uses: value.uses ?? usesToggle("None"),
          ruleSet: value.ruleSet ?? ruleSetToggle("None"),
          tokenStandard: value.tokenStandard ?? none(),
          authorizationData: value.authorizationData ?? none()
        })
      )
    ],
    [
      "AsAuthorityItemDelegateV2",
      mapEncoder(
        getStructEncoder([
          ["newUpdateAuthority", getOptionEncoder(getAddressEncoder())],
          ["primarySaleHappened", getOptionEncoder(getBooleanEncoder())],
          ["isMutable", getOptionEncoder(getBooleanEncoder())],
          ["tokenStandard", getOptionEncoder(getTokenStandardEncoder())],
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          newUpdateAuthority: value.newUpdateAuthority ?? none(),
          primarySaleHappened: value.primarySaleHappened ?? none(),
          isMutable: value.isMutable ?? none(),
          tokenStandard: value.tokenStandard ?? none(),
          authorizationData: value.authorizationData ?? none()
        })
      )
    ],
    [
      "AsCollectionDelegateV2",
      mapEncoder(
        getStructEncoder([
          ["collection", getCollectionToggleEncoder()],
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          collection: value.collection ?? collectionToggle("None"),
          authorizationData: value.authorizationData ?? none()
        })
      )
    ],
    [
      "AsDataDelegateV2",
      mapEncoder(
        getStructEncoder([
          ["data", getOptionEncoder(getDataEncoder())],
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          data: value.data ?? none(),
          authorizationData: value.authorizationData ?? none()
        })
      )
    ],
    [
      "AsProgrammableConfigDelegateV2",
      mapEncoder(
        getStructEncoder([
          ["ruleSet", getRuleSetToggleEncoder()],
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          ruleSet: value.ruleSet ?? ruleSetToggle("None"),
          authorizationData: value.authorizationData ?? none()
        })
      )
    ],
    [
      "AsDataItemDelegateV2",
      mapEncoder(
        getStructEncoder([
          ["data", getOptionEncoder(getDataEncoder())],
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          data: value.data ?? none(),
          authorizationData: value.authorizationData ?? none()
        })
      )
    ],
    [
      "AsCollectionItemDelegateV2",
      mapEncoder(
        getStructEncoder([
          ["collection", getCollectionToggleEncoder()],
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          collection: value.collection ?? collectionToggle("None"),
          authorizationData: value.authorizationData ?? none()
        })
      )
    ],
    [
      "AsProgrammableConfigItemDelegateV2",
      mapEncoder(
        getStructEncoder([
          ["ruleSet", getRuleSetToggleEncoder()],
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          ruleSet: value.ruleSet ?? ruleSetToggle("None"),
          authorizationData: value.authorizationData ?? none()
        })
      )
    ]
  ]);
}
function getUpdateArgsDecoder() {
  return getDataEnumDecoder([
    [
      "V1",
      getStructDecoder([
        ["newUpdateAuthority", getOptionDecoder(getAddressDecoder())],
        ["data", getOptionDecoder(getDataDecoder())],
        ["primarySaleHappened", getOptionDecoder(getBooleanDecoder())],
        ["isMutable", getOptionDecoder(getBooleanDecoder())],
        ["collection", getCollectionToggleDecoder()],
        ["collectionDetails", getCollectionDetailsToggleDecoder()],
        ["uses", getUsesToggleDecoder()],
        ["ruleSet", getRuleSetToggleDecoder()],
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "AsUpdateAuthorityV2",
      getStructDecoder([
        ["newUpdateAuthority", getOptionDecoder(getAddressDecoder())],
        ["data", getOptionDecoder(getDataDecoder())],
        ["primarySaleHappened", getOptionDecoder(getBooleanDecoder())],
        ["isMutable", getOptionDecoder(getBooleanDecoder())],
        ["collection", getCollectionToggleDecoder()],
        ["collectionDetails", getCollectionDetailsToggleDecoder()],
        ["uses", getUsesToggleDecoder()],
        ["ruleSet", getRuleSetToggleDecoder()],
        ["tokenStandard", getOptionDecoder(getTokenStandardDecoder())],
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "AsAuthorityItemDelegateV2",
      getStructDecoder([
        ["newUpdateAuthority", getOptionDecoder(getAddressDecoder())],
        ["primarySaleHappened", getOptionDecoder(getBooleanDecoder())],
        ["isMutable", getOptionDecoder(getBooleanDecoder())],
        ["tokenStandard", getOptionDecoder(getTokenStandardDecoder())],
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "AsCollectionDelegateV2",
      getStructDecoder([
        ["collection", getCollectionToggleDecoder()],
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "AsDataDelegateV2",
      getStructDecoder([
        ["data", getOptionDecoder(getDataDecoder())],
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "AsProgrammableConfigDelegateV2",
      getStructDecoder([
        ["ruleSet", getRuleSetToggleDecoder()],
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "AsDataItemDelegateV2",
      getStructDecoder([
        ["data", getOptionDecoder(getDataDecoder())],
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "AsCollectionItemDelegateV2",
      getStructDecoder([
        ["collection", getCollectionToggleDecoder()],
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "AsProgrammableConfigItemDelegateV2",
      getStructDecoder([
        ["ruleSet", getRuleSetToggleDecoder()],
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ]
  ]);
}
function getUpdateArgsCodec() {
  return combineCodec(getUpdateArgsEncoder(), getUpdateArgsDecoder());
}
function updateArgs(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isUpdateArgs(kind, value) {
  return value.__kind === kind;
}
function getUseArgsEncoder() {
  return getDataEnumEncoder([
    [
      "V1",
      mapEncoder(
        getStructEncoder([
          [
            "authorizationData",
            getOptionEncoder(getAuthorizationDataEncoder())
          ]
        ]),
        (value) => ({
          ...value,
          authorizationData: value.authorizationData ?? none()
        })
      )
    ]
  ]);
}
function getUseArgsDecoder() {
  return getDataEnumDecoder([
    [
      "V1",
      getStructDecoder([
        ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ]
  ]);
}
function getUseArgsCodec() {
  return combineCodec(getUseArgsEncoder(), getUseArgsDecoder());
}
function useArgs(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isUseArgs(kind, value) {
  return value.__kind === kind;
}
var UseMethod = /* @__PURE__ */ ((UseMethod3) => {
  UseMethod3[UseMethod3["Burn"] = 0] = "Burn";
  UseMethod3[UseMethod3["Multiple"] = 1] = "Multiple";
  UseMethod3[UseMethod3["Single"] = 2] = "Single";
  return UseMethod3;
})(UseMethod || {});
function getUseMethodEncoder() {
  return getScalarEnumEncoder(UseMethod);
}
function getUseMethodDecoder() {
  return getScalarEnumDecoder(UseMethod);
}
function getUseMethodCodec() {
  return combineCodec(getUseMethodEncoder(), getUseMethodDecoder());
}
function getUsesEncoder() {
  return getStructEncoder([
    ["useMethod", getUseMethodEncoder()],
    ["remaining", getU64Encoder()],
    ["total", getU64Encoder()]
  ]);
}
function getUsesDecoder() {
  return getStructDecoder([
    ["useMethod", getUseMethodDecoder()],
    ["remaining", getU64Decoder()],
    ["total", getU64Decoder()]
  ]);
}
function getUsesCodec() {
  return combineCodec(getUsesEncoder(), getUsesDecoder());
}
function getUsesToggleEncoder() {
  return getDataEnumEncoder([
    ["None", getUnitEncoder()],
    ["Clear", getUnitEncoder()],
    [
      "Set",
      getStructEncoder([["fields", getTupleEncoder([getUsesEncoder()])]])
    ]
  ]);
}
function getUsesToggleDecoder() {
  return getDataEnumDecoder([
    ["None", getUnitDecoder()],
    ["Clear", getUnitDecoder()],
    [
      "Set",
      getStructDecoder([["fields", getTupleDecoder([getUsesDecoder()])]])
    ]
  ]);
}
function getUsesToggleCodec() {
  return combineCodec(getUsesToggleEncoder(), getUsesToggleDecoder());
}
function usesToggle(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isUsesToggle(kind, value) {
  return value.__kind === kind;
}
var VerificationArgs = /* @__PURE__ */ ((VerificationArgs2) => {
  VerificationArgs2[VerificationArgs2["CreatorV1"] = 0] = "CreatorV1";
  VerificationArgs2[VerificationArgs2["CollectionV1"] = 1] = "CollectionV1";
  return VerificationArgs2;
})(VerificationArgs || {});
function getVerificationArgsEncoder() {
  return getScalarEnumEncoder(VerificationArgs);
}
function getVerificationArgsDecoder() {
  return getScalarEnumDecoder(VerificationArgs);
}
function getVerificationArgsCodec() {
  return combineCodec(
    getVerificationArgsEncoder(),
    getVerificationArgsDecoder()
  );
}

// src/generated/accounts/collectionAuthorityRecord.ts
function getCollectionAuthorityRecordAccountDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["key", getKeyEncoder()],
      ["bump", getU8Encoder()],
      ["updateAuthority", getOptionEncoder(getAddressEncoder())]
    ]),
    (value) => ({ ...value, key: 9 /* CollectionAuthorityRecord */ })
  );
}
function getCollectionAuthorityRecordAccountDataDecoder() {
  return getStructDecoder([
    ["key", getKeyDecoder()],
    ["bump", getU8Decoder()],
    ["updateAuthority", getOptionDecoder(getAddressDecoder())]
  ]);
}
function getCollectionAuthorityRecordAccountDataCodec() {
  return combineCodec(
    getCollectionAuthorityRecordAccountDataEncoder(),
    getCollectionAuthorityRecordAccountDataDecoder()
  );
}
function decodeCollectionAuthorityRecord(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getCollectionAuthorityRecordAccountDataDecoder()
  );
}
async function fetchCollectionAuthorityRecord(rpc, address, config) {
  const maybeAccount = await fetchMaybeCollectionAuthorityRecord(
    rpc,
    address,
    config
  );
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeCollectionAuthorityRecord(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeCollectionAuthorityRecord(maybeAccount);
}
async function fetchAllCollectionAuthorityRecord(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeCollectionAuthorityRecord(
    rpc,
    addresses,
    config
  );
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeCollectionAuthorityRecord(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeCollectionAuthorityRecord(maybeAccount)
  );
}
async function fetchCollectionAuthorityRecordFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeCollectionAuthorityRecordFromSeeds(
    rpc,
    seeds,
    config
  );
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeCollectionAuthorityRecordFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findCollectionAuthorityRecordPda(seeds, {
    programAddress
  });
  return fetchMaybeCollectionAuthorityRecord(rpc, address, fetchConfig);
}
function getEditionAccountDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["key", getKeyEncoder()],
      ["parent", getAddressEncoder()],
      ["edition", getU64Encoder()]
    ]),
    (value) => ({ ...value, key: 1 /* EditionV1 */ })
  );
}
function getEditionAccountDataDecoder() {
  return getStructDecoder([
    ["key", getKeyDecoder()],
    ["parent", getAddressDecoder()],
    ["edition", getU64Decoder()]
  ]);
}
function getEditionAccountDataCodec() {
  return combineCodec(
    getEditionAccountDataEncoder(),
    getEditionAccountDataDecoder()
  );
}
function decodeEdition(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getEditionAccountDataDecoder()
  );
}
async function fetchEdition(rpc, address, config) {
  const maybeAccount = await fetchMaybeEdition(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeEdition(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeEdition(maybeAccount);
}
async function fetchAllEdition(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeEdition(rpc, addresses, config);
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeEdition(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeEdition(maybeAccount));
}
function getEditionSize() {
  return 41;
}
function getEditionMarkerAccountDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["key", getKeyEncoder()],
      ["ledger", getArrayEncoder(getU8Encoder(), { size: 31 })]
    ]),
    (value) => ({ ...value, key: 7 /* EditionMarker */ })
  );
}
function getEditionMarkerAccountDataDecoder() {
  return getStructDecoder([
    ["key", getKeyDecoder()],
    ["ledger", getArrayDecoder(getU8Decoder(), { size: 31 })]
  ]);
}
function getEditionMarkerAccountDataCodec() {
  return combineCodec(
    getEditionMarkerAccountDataEncoder(),
    getEditionMarkerAccountDataDecoder()
  );
}
function decodeEditionMarker(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getEditionMarkerAccountDataDecoder()
  );
}
async function fetchEditionMarker(rpc, address, config) {
  const maybeAccount = await fetchMaybeEditionMarker(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeEditionMarker(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeEditionMarker(maybeAccount);
}
async function fetchAllEditionMarker(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeEditionMarker(
    rpc,
    addresses,
    config
  );
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeEditionMarker(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeEditionMarker(maybeAccount));
}
function getEditionMarkerSize() {
  return 32;
}
async function fetchEditionMarkerFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeEditionMarkerFromSeeds(
    rpc,
    seeds,
    config
  );
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeEditionMarkerFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findEditionMarkerPda(seeds, { programAddress });
  return fetchMaybeEditionMarker(rpc, address, fetchConfig);
}
function getEditionMarkerV2AccountDataEncoder() {
  return getStructEncoder([
    ["key", getKeyEncoder()],
    ["ledger", getBytesEncoder({ size: getU32Encoder() })]
  ]);
}
function getEditionMarkerV2AccountDataDecoder() {
  return getStructDecoder([
    ["key", getKeyDecoder()],
    ["ledger", getBytesDecoder({ size: getU32Decoder() })]
  ]);
}
function getEditionMarkerV2AccountDataCodec() {
  return combineCodec(
    getEditionMarkerV2AccountDataEncoder(),
    getEditionMarkerV2AccountDataDecoder()
  );
}
function decodeEditionMarkerV2(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getEditionMarkerV2AccountDataDecoder()
  );
}
async function fetchEditionMarkerV2(rpc, address, config) {
  const maybeAccount = await fetchMaybeEditionMarkerV2(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeEditionMarkerV2(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeEditionMarkerV2(maybeAccount);
}
async function fetchAllEditionMarkerV2(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeEditionMarkerV2(
    rpc,
    addresses,
    config
  );
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeEditionMarkerV2(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeEditionMarkerV2(maybeAccount)
  );
}
async function fetchEditionMarkerV2FromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeEditionMarkerV2FromSeeds(
    rpc,
    seeds,
    config
  );
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeEditionMarkerV2FromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findEditionMarkerV2Pda(seeds, { programAddress });
  return fetchMaybeEditionMarkerV2(rpc, address, fetchConfig);
}
function getMasterEditionAccountDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["key", getKeyEncoder()],
      ["supply", getU64Encoder()],
      ["maxSupply", getOptionEncoder(getU64Encoder())]
    ]),
    (value) => ({ ...value, key: 6 /* MasterEditionV2 */ })
  );
}
function getMasterEditionAccountDataDecoder() {
  return getStructDecoder([
    ["key", getKeyDecoder()],
    ["supply", getU64Decoder()],
    ["maxSupply", getOptionDecoder(getU64Decoder())]
  ]);
}
function getMasterEditionAccountDataCodec() {
  return combineCodec(
    getMasterEditionAccountDataEncoder(),
    getMasterEditionAccountDataDecoder()
  );
}
function decodeMasterEdition(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getMasterEditionAccountDataDecoder()
  );
}
async function fetchMasterEdition(rpc, address, config) {
  const maybeAccount = await fetchMaybeMasterEdition(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMasterEdition(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeMasterEdition(maybeAccount);
}
async function fetchAllMasterEdition(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeMasterEdition(
    rpc,
    addresses,
    config
  );
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeMasterEdition(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeMasterEdition(maybeAccount));
}
async function fetchMasterEditionFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeMasterEditionFromSeeds(
    rpc,
    seeds,
    config
  );
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMasterEditionFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findMasterEditionPda(seeds, { programAddress });
  return fetchMaybeMasterEdition(rpc, address, fetchConfig);
}
function getMetadataAccountDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["key", getKeyEncoder()],
      ["updateAuthority", getAddressEncoder()],
      ["mint", getAddressEncoder()],
      ["name", getStringEncoder()],
      ["symbol", getStringEncoder()],
      ["uri", getStringEncoder()],
      ["sellerFeeBasisPoints", getU16Encoder()],
      ["creators", getOptionEncoder(getArrayEncoder(getCreatorEncoder()))],
      ["primarySaleHappened", getBooleanEncoder()],
      ["isMutable", getBooleanEncoder()],
      ["editionNonce", getOptionEncoder(getU8Encoder())],
      ["tokenStandard", getOptionEncoder(getTokenStandardEncoder())],
      ["collection", getOptionEncoder(getCollectionEncoder())],
      ["uses", getOptionEncoder(getUsesEncoder())],
      ["collectionDetails", getOptionEncoder(getCollectionDetailsEncoder())],
      ["programmableConfig", getOptionEncoder(getProgrammableConfigEncoder())]
    ]),
    (value) => ({ ...value, key: 4 /* MetadataV1 */ })
  );
}
function getMetadataAccountDataDecoder() {
  return getStructDecoder([
    ["key", getKeyDecoder()],
    ["updateAuthority", getAddressDecoder()],
    ["mint", getAddressDecoder()],
    ["name", getStringDecoder()],
    ["symbol", getStringDecoder()],
    ["uri", getStringDecoder()],
    ["sellerFeeBasisPoints", getU16Decoder()],
    ["creators", getOptionDecoder(getArrayDecoder(getCreatorDecoder()))],
    ["primarySaleHappened", getBooleanDecoder()],
    ["isMutable", getBooleanDecoder()],
    ["editionNonce", getOptionDecoder(getU8Decoder())],
    ["tokenStandard", getOptionDecoder(getTokenStandardDecoder())],
    ["collection", getOptionDecoder(getCollectionDecoder())],
    ["uses", getOptionDecoder(getUsesDecoder())],
    ["collectionDetails", getOptionDecoder(getCollectionDetailsDecoder())],
    ["programmableConfig", getOptionDecoder(getProgrammableConfigDecoder())]
  ]);
}
function getMetadataAccountDataCodec() {
  return combineCodec(
    getMetadataAccountDataEncoder(),
    getMetadataAccountDataDecoder()
  );
}
function decodeMetadata(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getMetadataAccountDataDecoder()
  );
}
async function fetchMetadata(rpc, address, config) {
  const maybeAccount = await fetchMaybeMetadata(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMetadata(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeMetadata(maybeAccount);
}
async function fetchAllMetadata(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeMetadata(rpc, addresses, config);
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeMetadata(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeMetadata(maybeAccount));
}
async function fetchMetadataFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeMetadataFromSeeds(rpc, seeds, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMetadataFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findMetadataPda(seeds, { programAddress });
  return fetchMaybeMetadata(rpc, address, fetchConfig);
}
function getMetadataDelegateRecordAccountDataEncoder() {
  return getStructEncoder([
    ["key", getKeyEncoder()],
    ["bump", getU8Encoder()],
    ["mint", getAddressEncoder()],
    ["delegate", getAddressEncoder()],
    ["updateAuthority", getAddressEncoder()]
  ]);
}
function getMetadataDelegateRecordAccountDataDecoder() {
  return getStructDecoder([
    ["key", getKeyDecoder()],
    ["bump", getU8Decoder()],
    ["mint", getAddressDecoder()],
    ["delegate", getAddressDecoder()],
    ["updateAuthority", getAddressDecoder()]
  ]);
}
function getMetadataDelegateRecordAccountDataCodec() {
  return combineCodec(
    getMetadataDelegateRecordAccountDataEncoder(),
    getMetadataDelegateRecordAccountDataDecoder()
  );
}
function decodeMetadataDelegateRecord(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getMetadataDelegateRecordAccountDataDecoder()
  );
}
async function fetchMetadataDelegateRecord(rpc, address, config) {
  const maybeAccount = await fetchMaybeMetadataDelegateRecord(
    rpc,
    address,
    config
  );
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMetadataDelegateRecord(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeMetadataDelegateRecord(maybeAccount);
}
async function fetchAllMetadataDelegateRecord(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeMetadataDelegateRecord(
    rpc,
    addresses,
    config
  );
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeMetadataDelegateRecord(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeMetadataDelegateRecord(maybeAccount)
  );
}
function getMetadataDelegateRecordSize() {
  return 98;
}
function getTokenOwnedEscrowAccountDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["key", getKeyEncoder()],
      ["baseToken", getAddressEncoder()],
      ["authority", getEscrowAuthorityEncoder()],
      ["bump", getU8Encoder()]
    ]),
    (value) => ({ ...value, key: 10 /* TokenOwnedEscrow */ })
  );
}
function getTokenOwnedEscrowAccountDataDecoder() {
  return getStructDecoder([
    ["key", getKeyDecoder()],
    ["baseToken", getAddressDecoder()],
    ["authority", getEscrowAuthorityDecoder()],
    ["bump", getU8Decoder()]
  ]);
}
function getTokenOwnedEscrowAccountDataCodec() {
  return combineCodec(
    getTokenOwnedEscrowAccountDataEncoder(),
    getTokenOwnedEscrowAccountDataDecoder()
  );
}
function decodeTokenOwnedEscrow(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getTokenOwnedEscrowAccountDataDecoder()
  );
}
async function fetchTokenOwnedEscrow(rpc, address, config) {
  const maybeAccount = await fetchMaybeTokenOwnedEscrow(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeTokenOwnedEscrow(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeTokenOwnedEscrow(maybeAccount);
}
async function fetchAllTokenOwnedEscrow(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeTokenOwnedEscrow(
    rpc,
    addresses,
    config
  );
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeTokenOwnedEscrow(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeTokenOwnedEscrow(maybeAccount)
  );
}
function getTokenRecordAccountDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["key", getKeyEncoder()],
      ["bump", getU8Encoder()],
      ["state", getTokenStateEncoder()],
      ["ruleSetRevision", getOptionEncoder(getU64Encoder())],
      ["delegate", getOptionEncoder(getAddressEncoder())],
      ["delegateRole", getOptionEncoder(getTokenDelegateRoleEncoder())],
      ["lockedTransfer", getOptionEncoder(getAddressEncoder())]
    ]),
    (value) => ({ ...value, key: 11 /* TokenRecord */ })
  );
}
function getTokenRecordAccountDataDecoder() {
  return getStructDecoder([
    ["key", getKeyDecoder()],
    ["bump", getU8Decoder()],
    ["state", getTokenStateDecoder()],
    ["ruleSetRevision", getOptionDecoder(getU64Decoder())],
    ["delegate", getOptionDecoder(getAddressDecoder())],
    ["delegateRole", getOptionDecoder(getTokenDelegateRoleDecoder())],
    ["lockedTransfer", getOptionDecoder(getAddressDecoder())]
  ]);
}
function getTokenRecordAccountDataCodec() {
  return combineCodec(
    getTokenRecordAccountDataEncoder(),
    getTokenRecordAccountDataDecoder()
  );
}
function decodeTokenRecord(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getTokenRecordAccountDataDecoder()
  );
}
async function fetchTokenRecord(rpc, address, config) {
  const maybeAccount = await fetchMaybeTokenRecord(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeTokenRecord(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeTokenRecord(maybeAccount);
}
async function fetchAllTokenRecord(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeTokenRecord(rpc, addresses, config);
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeTokenRecord(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeTokenRecord(maybeAccount));
}
function getTokenRecordSize() {
  return 80;
}
async function fetchTokenRecordFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeTokenRecordFromSeeds(rpc, seeds, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeTokenRecordFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findTokenRecordPda(seeds, { programAddress });
  return fetchMaybeTokenRecord(rpc, address, fetchConfig);
}
function getUseAuthorityRecordAccountDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["key", getKeyEncoder()],
      ["allowedUses", getU64Encoder()],
      ["bump", getU8Encoder()]
    ]),
    (value) => ({ ...value, key: 8 /* UseAuthorityRecord */ })
  );
}
function getUseAuthorityRecordAccountDataDecoder() {
  return getStructDecoder([
    ["key", getKeyDecoder()],
    ["allowedUses", getU64Decoder()],
    ["bump", getU8Decoder()]
  ]);
}
function getUseAuthorityRecordAccountDataCodec() {
  return combineCodec(
    getUseAuthorityRecordAccountDataEncoder(),
    getUseAuthorityRecordAccountDataDecoder()
  );
}
function decodeUseAuthorityRecord(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getUseAuthorityRecordAccountDataDecoder()
  );
}
async function fetchUseAuthorityRecord(rpc, address, config) {
  const maybeAccount = await fetchMaybeUseAuthorityRecord(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeUseAuthorityRecord(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeUseAuthorityRecord(maybeAccount);
}
async function fetchAllUseAuthorityRecord(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeUseAuthorityRecord(
    rpc,
    addresses,
    config
  );
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeUseAuthorityRecord(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeUseAuthorityRecord(maybeAccount)
  );
}
function getUseAuthorityRecordSize() {
  return 10;
}
async function fetchUseAuthorityRecordFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeUseAuthorityRecordFromSeeds(
    rpc,
    seeds,
    config
  );
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeUseAuthorityRecordFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findUseAuthorityRecordPda(seeds, { programAddress });
  return fetchMaybeUseAuthorityRecord(rpc, address, fetchConfig);
}

// src/generated/errors/mplTokenMetadata.ts
var MplTokenMetadataProgramErrorCode = /* @__PURE__ */ ((MplTokenMetadataProgramErrorCode3) => {
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INSTRUCTION_UNPACK_ERROR"] = 0] = "INSTRUCTION_UNPACK_ERROR";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INSTRUCTION_PACK_ERROR"] = 1] = "INSTRUCTION_PACK_ERROR";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["NOT_RENT_EXEMPT"] = 2] = "NOT_RENT_EXEMPT";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["ALREADY_INITIALIZED"] = 3] = "ALREADY_INITIALIZED";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["UNINITIALIZED"] = 4] = "UNINITIALIZED";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_METADATA_KEY"] = 5] = "INVALID_METADATA_KEY";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_EDITION_KEY"] = 6] = "INVALID_EDITION_KEY";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["UPDATE_AUTHORITY_INCORRECT"] = 7] = "UPDATE_AUTHORITY_INCORRECT";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["UPDATE_AUTHORITY_IS_NOT_SIGNER"] = 8] = "UPDATE_AUTHORITY_IS_NOT_SIGNER";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["NOT_MINT_AUTHORITY"] = 9] = "NOT_MINT_AUTHORITY";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_MINT_AUTHORITY"] = 10] = "INVALID_MINT_AUTHORITY";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["NAME_TOO_LONG"] = 11] = "NAME_TOO_LONG";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["SYMBOL_TOO_LONG"] = 12] = "SYMBOL_TOO_LONG";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["URI_TOO_LONG"] = 13] = "URI_TOO_LONG";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["UPDATE_AUTHORITY_MUST_BE_EQUAL_TO_METADATA_AUTHORITY_AND_SIGNER"] = 14] = "UPDATE_AUTHORITY_MUST_BE_EQUAL_TO_METADATA_AUTHORITY_AND_SIGNER";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MINT_MISMATCH"] = 15] = "MINT_MISMATCH";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["EDITIONS_MUST_HAVE_EXACTLY_ONE_TOKEN"] = 16] = "EDITIONS_MUST_HAVE_EXACTLY_ONE_TOKEN";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MAX_EDITIONS_MINTED_ALREADY"] = 17] = "MAX_EDITIONS_MINTED_ALREADY";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["TOKEN_MINT_TO_FAILED"] = 18] = "TOKEN_MINT_TO_FAILED";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MASTER_RECORD_MISMATCH"] = 19] = "MASTER_RECORD_MISMATCH";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["DESTINATION_MINT_MISMATCH"] = 20] = "DESTINATION_MINT_MISMATCH";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["EDITION_ALREADY_MINTED"] = 21] = "EDITION_ALREADY_MINTED";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["PRINTING_MINT_DECIMALS_SHOULD_BE_ZERO"] = 22] = "PRINTING_MINT_DECIMALS_SHOULD_BE_ZERO";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["ONE_TIME_PRINTING_AUTHORIZATION_MINT_DECIMALS_SHOULD_BE_ZERO"] = 23] = "ONE_TIME_PRINTING_AUTHORIZATION_MINT_DECIMALS_SHOULD_BE_ZERO";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["EDITION_MINT_DECIMALS_SHOULD_BE_ZERO"] = 24] = "EDITION_MINT_DECIMALS_SHOULD_BE_ZERO";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["TOKEN_BURN_FAILED"] = 25] = "TOKEN_BURN_FAILED";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["TOKEN_ACCOUNT_ONE_TIME_AUTH_MINT_MISMATCH"] = 26] = "TOKEN_ACCOUNT_ONE_TIME_AUTH_MINT_MISMATCH";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["DERIVED_KEY_INVALID"] = 27] = "DERIVED_KEY_INVALID";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["PRINTING_MINT_MISMATCH"] = 28] = "PRINTING_MINT_MISMATCH";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["ONE_TIME_PRINTING_AUTH_MINT_MISMATCH"] = 29] = "ONE_TIME_PRINTING_AUTH_MINT_MISMATCH";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["TOKEN_ACCOUNT_MINT_MISMATCH"] = 30] = "TOKEN_ACCOUNT_MINT_MISMATCH";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["TOKEN_ACCOUNT_MINT_MISMATCH_V2"] = 31] = "TOKEN_ACCOUNT_MINT_MISMATCH_V2";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["NOT_ENOUGH_TOKENS"] = 32] = "NOT_ENOUGH_TOKENS";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["PRINTING_MINT_AUTHORIZATION_ACCOUNT_MISMATCH"] = 33] = "PRINTING_MINT_AUTHORIZATION_ACCOUNT_MISMATCH";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["AUTHORIZATION_TOKEN_ACCOUNT_OWNER_MISMATCH"] = 34] = "AUTHORIZATION_TOKEN_ACCOUNT_OWNER_MISMATCH";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["DISABLED"] = 35] = "DISABLED";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["CREATORS_TOO_LONG"] = 36] = "CREATORS_TOO_LONG";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["CREATORS_MUST_BE_ATLEAST_ONE"] = 37] = "CREATORS_MUST_BE_ATLEAST_ONE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MUST_BE_ONE_OF_CREATORS"] = 38] = "MUST_BE_ONE_OF_CREATORS";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["NO_CREATORS_PRESENT_ON_METADATA"] = 39] = "NO_CREATORS_PRESENT_ON_METADATA";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["CREATOR_NOT_FOUND"] = 40] = "CREATOR_NOT_FOUND";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_BASIS_POINTS"] = 41] = "INVALID_BASIS_POINTS";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["PRIMARY_SALE_CAN_ONLY_BE_FLIPPED_TO_TRUE"] = 42] = "PRIMARY_SALE_CAN_ONLY_BE_FLIPPED_TO_TRUE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["OWNER_MISMATCH"] = 43] = "OWNER_MISMATCH";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["NO_BALANCE_IN_ACCOUNT_FOR_AUTHORIZATION"] = 44] = "NO_BALANCE_IN_ACCOUNT_FOR_AUTHORIZATION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["SHARE_TOTAL_MUST_BE100"] = 45] = "SHARE_TOTAL_MUST_BE100";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["RESERVATION_EXISTS"] = 46] = "RESERVATION_EXISTS";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["RESERVATION_DOES_NOT_EXIST"] = 47] = "RESERVATION_DOES_NOT_EXIST";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["RESERVATION_NOT_SET"] = 48] = "RESERVATION_NOT_SET";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["RESERVATION_ALREADY_MADE"] = 49] = "RESERVATION_ALREADY_MADE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["BEYOND_MAX_ADDRESS_SIZE"] = 50] = "BEYOND_MAX_ADDRESS_SIZE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["NUMERICAL_OVERFLOW_ERROR"] = 51] = "NUMERICAL_OVERFLOW_ERROR";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["RESERVATION_BREACHES_MAXIMUM_SUPPLY"] = 52] = "RESERVATION_BREACHES_MAXIMUM_SUPPLY";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["ADDRESS_NOT_IN_RESERVATION"] = 53] = "ADDRESS_NOT_IN_RESERVATION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["CANNOT_VERIFY_ANOTHER_CREATOR"] = 54] = "CANNOT_VERIFY_ANOTHER_CREATOR";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["CANNOT_UNVERIFY_ANOTHER_CREATOR"] = 55] = "CANNOT_UNVERIFY_ANOTHER_CREATOR";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["SPOT_MISMATCH"] = 56] = "SPOT_MISMATCH";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INCORRECT_OWNER"] = 57] = "INCORRECT_OWNER";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["PRINTING_WOULD_BREACH_MAXIMUM_SUPPLY"] = 58] = "PRINTING_WOULD_BREACH_MAXIMUM_SUPPLY";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["DATA_IS_IMMUTABLE"] = 59] = "DATA_IS_IMMUTABLE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["DUPLICATE_CREATOR_ADDRESS"] = 60] = "DUPLICATE_CREATOR_ADDRESS";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["RESERVATION_SPOTS_REMAINING_SHOULD_MATCH_TOTAL_SPOTS_AT_START"] = 61] = "RESERVATION_SPOTS_REMAINING_SHOULD_MATCH_TOTAL_SPOTS_AT_START";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_TOKEN_PROGRAM"] = 62] = "INVALID_TOKEN_PROGRAM";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["DATA_TYPE_MISMATCH"] = 63] = "DATA_TYPE_MISMATCH";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["BEYOND_ALOTTED_ADDRESS_SIZE"] = 64] = "BEYOND_ALOTTED_ADDRESS_SIZE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["RESERVATION_NOT_COMPLETE"] = 65] = "RESERVATION_NOT_COMPLETE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["TRIED_TO_REPLACE_AN_EXISTING_RESERVATION"] = 66] = "TRIED_TO_REPLACE_AN_EXISTING_RESERVATION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_OPERATION"] = 67] = "INVALID_OPERATION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_OWNER"] = 68] = "INVALID_OWNER";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["PRINTING_MINT_SUPPLY_MUST_BE_ZERO_FOR_CONVERSION"] = 69] = "PRINTING_MINT_SUPPLY_MUST_BE_ZERO_FOR_CONVERSION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["ONE_TIME_AUTH_MINT_SUPPLY_MUST_BE_ZERO_FOR_CONVERSION"] = 70] = "ONE_TIME_AUTH_MINT_SUPPLY_MUST_BE_ZERO_FOR_CONVERSION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_EDITION_INDEX"] = 71] = "INVALID_EDITION_INDEX";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["RESERVATION_ARRAY_SHOULD_BE_SIZE_ONE"] = 72] = "RESERVATION_ARRAY_SHOULD_BE_SIZE_ONE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["IS_MUTABLE_CAN_ONLY_BE_FLIPPED_TO_FALSE"] = 73] = "IS_MUTABLE_CAN_ONLY_BE_FLIPPED_TO_FALSE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["COLLECTION_CANNOT_BE_VERIFIED_IN_THIS_INSTRUCTION"] = 74] = "COLLECTION_CANNOT_BE_VERIFIED_IN_THIS_INSTRUCTION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["REMOVED"] = 75] = "REMOVED";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MUST_BE_BURNED"] = 76] = "MUST_BE_BURNED";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_USE_METHOD"] = 77] = "INVALID_USE_METHOD";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["CANNOT_CHANGE_USE_METHOD_AFTER_FIRST_USE"] = 78] = "CANNOT_CHANGE_USE_METHOD_AFTER_FIRST_USE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["CANNOT_CHANGE_USES_AFTER_FIRST_USE"] = 79] = "CANNOT_CHANGE_USES_AFTER_FIRST_USE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["COLLECTION_NOT_FOUND"] = 80] = "COLLECTION_NOT_FOUND";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_COLLECTION_UPDATE_AUTHORITY"] = 81] = "INVALID_COLLECTION_UPDATE_AUTHORITY";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["COLLECTION_MUST_BE_A_UNIQUE_MASTER_EDITION"] = 82] = "COLLECTION_MUST_BE_A_UNIQUE_MASTER_EDITION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["USE_AUTHORITY_RECORD_ALREADY_EXISTS"] = 83] = "USE_AUTHORITY_RECORD_ALREADY_EXISTS";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["USE_AUTHORITY_RECORD_ALREADY_REVOKED"] = 84] = "USE_AUTHORITY_RECORD_ALREADY_REVOKED";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["UNUSABLE"] = 85] = "UNUSABLE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["NOT_ENOUGH_USES"] = 86] = "NOT_ENOUGH_USES";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["COLLECTION_AUTHORITY_RECORD_ALREADY_EXISTS"] = 87] = "COLLECTION_AUTHORITY_RECORD_ALREADY_EXISTS";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["COLLECTION_AUTHORITY_DOES_NOT_EXIST"] = 88] = "COLLECTION_AUTHORITY_DOES_NOT_EXIST";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_USE_AUTHORITY_RECORD"] = 89] = "INVALID_USE_AUTHORITY_RECORD";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_COLLECTION_AUTHORITY_RECORD"] = 90] = "INVALID_COLLECTION_AUTHORITY_RECORD";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_FREEZE_AUTHORITY"] = 91] = "INVALID_FREEZE_AUTHORITY";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_DELEGATE"] = 92] = "INVALID_DELEGATE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["CANNOT_ADJUST_VERIFIED_CREATOR"] = 93] = "CANNOT_ADJUST_VERIFIED_CREATOR";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["CANNOT_REMOVE_VERIFIED_CREATOR"] = 94] = "CANNOT_REMOVE_VERIFIED_CREATOR";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["CANNOT_WIPE_VERIFIED_CREATORS"] = 95] = "CANNOT_WIPE_VERIFIED_CREATORS";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["NOT_ALLOWED_TO_CHANGE_SELLER_FEE_BASIS_POINTS"] = 96] = "NOT_ALLOWED_TO_CHANGE_SELLER_FEE_BASIS_POINTS";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["EDITION_OVERRIDE_CANNOT_BE_ZERO"] = 97] = "EDITION_OVERRIDE_CANNOT_BE_ZERO";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_USER"] = 98] = "INVALID_USER";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["REVOKE_COLLECTION_AUTHORITY_SIGNER_INCORRECT"] = 99] = "REVOKE_COLLECTION_AUTHORITY_SIGNER_INCORRECT";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["TOKEN_CLOSE_FAILED"] = 100] = "TOKEN_CLOSE_FAILED";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["UNSIZED_COLLECTION"] = 101] = "UNSIZED_COLLECTION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["SIZED_COLLECTION"] = 102] = "SIZED_COLLECTION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_COLLECTION_METADATA"] = 103] = "MISSING_COLLECTION_METADATA";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["NOT_A_MEMBER_OF_COLLECTION"] = 104] = "NOT_A_MEMBER_OF_COLLECTION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["NOT_VERIFIED_MEMBER_OF_COLLECTION"] = 105] = "NOT_VERIFIED_MEMBER_OF_COLLECTION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["NOT_A_COLLECTION_PARENT"] = 106] = "NOT_A_COLLECTION_PARENT";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["COULD_NOT_DETERMINE_TOKEN_STANDARD"] = 107] = "COULD_NOT_DETERMINE_TOKEN_STANDARD";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_EDITION_ACCOUNT"] = 108] = "MISSING_EDITION_ACCOUNT";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["NOT_A_MASTER_EDITION"] = 109] = "NOT_A_MASTER_EDITION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MASTER_EDITION_HAS_PRINTS"] = 110] = "MASTER_EDITION_HAS_PRINTS";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["BORSH_DESERIALIZATION_ERROR"] = 111] = "BORSH_DESERIALIZATION_ERROR";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["CANNOT_UPDATE_VERIFIED_COLLECTION"] = 112] = "CANNOT_UPDATE_VERIFIED_COLLECTION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["COLLECTION_MASTER_EDITION_ACCOUNT_INVALID"] = 113] = "COLLECTION_MASTER_EDITION_ACCOUNT_INVALID";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["ALREADY_VERIFIED"] = 114] = "ALREADY_VERIFIED";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["ALREADY_UNVERIFIED"] = 115] = "ALREADY_UNVERIFIED";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["NOT_A_PRINT_EDITION"] = 116] = "NOT_A_PRINT_EDITION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_MASTER_EDITION"] = 117] = "INVALID_MASTER_EDITION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_PRINT_EDITION"] = 118] = "INVALID_PRINT_EDITION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_EDITION_MARKER"] = 119] = "INVALID_EDITION_MARKER";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["RESERVATION_LIST_DEPRECATED"] = 120] = "RESERVATION_LIST_DEPRECATED";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["PRINT_EDITION_DOES_NOT_MATCH_MASTER_EDITION"] = 121] = "PRINT_EDITION_DOES_NOT_MATCH_MASTER_EDITION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["EDITION_NUMBER_GREATER_THAN_MAX_SUPPLY"] = 122] = "EDITION_NUMBER_GREATER_THAN_MAX_SUPPLY";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MUST_UNVERIFY"] = 123] = "MUST_UNVERIFY";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_ESCROW_BUMP_SEED"] = 124] = "INVALID_ESCROW_BUMP_SEED";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MUST_BE_ESCROW_AUTHORITY"] = 125] = "MUST_BE_ESCROW_AUTHORITY";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_SYSTEM_PROGRAM"] = 126] = "INVALID_SYSTEM_PROGRAM";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MUST_BE_NON_FUNGIBLE"] = 127] = "MUST_BE_NON_FUNGIBLE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INSUFFICIENT_TOKENS"] = 128] = "INSUFFICIENT_TOKENS";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["BORSH_SERIALIZATION_ERROR"] = 129] = "BORSH_SERIALIZATION_ERROR";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["NO_FREEZE_AUTHORITY_SET"] = 130] = "NO_FREEZE_AUTHORITY_SET";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_COLLECTION_SIZE_CHANGE"] = 131] = "INVALID_COLLECTION_SIZE_CHANGE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_BUBBLEGUM_SIGNER"] = 132] = "INVALID_BUBBLEGUM_SIGNER";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["ESCROW_PARENT_HAS_DELEGATE"] = 133] = "ESCROW_PARENT_HAS_DELEGATE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MINT_IS_NOT_SIGNER"] = 134] = "MINT_IS_NOT_SIGNER";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_TOKEN_STANDARD"] = 135] = "INVALID_TOKEN_STANDARD";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_MINT_FOR_TOKEN_STANDARD"] = 136] = "INVALID_MINT_FOR_TOKEN_STANDARD";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_AUTHORIZATION_RULES"] = 137] = "INVALID_AUTHORIZATION_RULES";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_AUTHORIZATION_RULES"] = 138] = "MISSING_AUTHORIZATION_RULES";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_PROGRAMMABLE_CONFIG"] = 139] = "MISSING_PROGRAMMABLE_CONFIG";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_PROGRAMMABLE_CONFIG"] = 140] = "INVALID_PROGRAMMABLE_CONFIG";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["DELEGATE_ALREADY_EXISTS"] = 141] = "DELEGATE_ALREADY_EXISTS";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["DELEGATE_NOT_FOUND"] = 142] = "DELEGATE_NOT_FOUND";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_ACCOUNT_IN_BUILDER"] = 143] = "MISSING_ACCOUNT_IN_BUILDER";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_ARGUMENT_IN_BUILDER"] = 144] = "MISSING_ARGUMENT_IN_BUILDER";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["FEATURE_NOT_SUPPORTED"] = 145] = "FEATURE_NOT_SUPPORTED";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_SYSTEM_WALLET"] = 146] = "INVALID_SYSTEM_WALLET";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["ONLY_SALE_DELEGATE_CAN_TRANSFER"] = 147] = "ONLY_SALE_DELEGATE_CAN_TRANSFER";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_TOKEN_ACCOUNT"] = 148] = "MISSING_TOKEN_ACCOUNT";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_SPL_TOKEN_PROGRAM"] = 149] = "MISSING_SPL_TOKEN_PROGRAM";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_AUTHORIZATION_RULES_PROGRAM"] = 150] = "MISSING_AUTHORIZATION_RULES_PROGRAM";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_DELEGATE_ROLE_FOR_TRANSFER"] = 151] = "INVALID_DELEGATE_ROLE_FOR_TRANSFER";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_TRANSFER_AUTHORITY"] = 152] = "INVALID_TRANSFER_AUTHORITY";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INSTRUCTION_NOT_SUPPORTED"] = 153] = "INSTRUCTION_NOT_SUPPORTED";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["KEY_MISMATCH"] = 154] = "KEY_MISMATCH";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["LOCKED_TOKEN"] = 155] = "LOCKED_TOKEN";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["UNLOCKED_TOKEN"] = 156] = "UNLOCKED_TOKEN";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_DELEGATE_ROLE"] = 157] = "MISSING_DELEGATE_ROLE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_AUTHORITY_TYPE"] = 158] = "INVALID_AUTHORITY_TYPE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_TOKEN_RECORD"] = 159] = "MISSING_TOKEN_RECORD";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MINT_SUPPLY_MUST_BE_ZERO"] = 160] = "MINT_SUPPLY_MUST_BE_ZERO";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["DATA_IS_EMPTY_OR_ZEROED"] = 161] = "DATA_IS_EMPTY_OR_ZEROED";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_TOKEN_OWNER_ACCOUNT"] = 162] = "MISSING_TOKEN_OWNER_ACCOUNT";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_MASTER_EDITION_ACCOUNT_LENGTH"] = 163] = "INVALID_MASTER_EDITION_ACCOUNT_LENGTH";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INCORRECT_TOKEN_STATE"] = 164] = "INCORRECT_TOKEN_STATE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_DELEGATE_ROLE"] = 165] = "INVALID_DELEGATE_ROLE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_PRINT_SUPPLY"] = 166] = "MISSING_PRINT_SUPPLY";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_MASTER_EDITION_ACCOUNT"] = 167] = "MISSING_MASTER_EDITION_ACCOUNT";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["AMOUNT_MUST_BE_GREATER_THAN_ZERO"] = 168] = "AMOUNT_MUST_BE_GREATER_THAN_ZERO";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_DELEGATE_ARGS"] = 169] = "INVALID_DELEGATE_ARGS";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_LOCKED_TRANSFER_ADDRESS"] = 170] = "MISSING_LOCKED_TRANSFER_ADDRESS";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_LOCKED_TRANSFER_ADDRESS"] = 171] = "INVALID_LOCKED_TRANSFER_ADDRESS";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["DATA_INCREMENT_LIMIT_EXCEEDED"] = 172] = "DATA_INCREMENT_LIMIT_EXCEEDED";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["CANNOT_UPDATE_ASSET_WITH_DELEGATE"] = 173] = "CANNOT_UPDATE_ASSET_WITH_DELEGATE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_AMOUNT"] = 174] = "INVALID_AMOUNT";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_MASTER_EDITION_MINT_ACCOUNT"] = 175] = "MISSING_MASTER_EDITION_MINT_ACCOUNT";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_MASTER_EDITION_TOKEN_ACCOUNT"] = 176] = "MISSING_MASTER_EDITION_TOKEN_ACCOUNT";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_EDITION_MARKER_ACCOUNT"] = 177] = "MISSING_EDITION_MARKER_ACCOUNT";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["CANNOT_BURN_WITH_DELEGATE"] = 178] = "CANNOT_BURN_WITH_DELEGATE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_EDITION"] = 179] = "MISSING_EDITION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_ASSOCIATED_TOKEN_ACCOUNT_PROGRAM"] = 180] = "INVALID_ASSOCIATED_TOKEN_ACCOUNT_PROGRAM";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_INSTRUCTIONS_SYSVAR"] = 181] = "INVALID_INSTRUCTIONS_SYSVAR";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_PARENT_ACCOUNTS"] = 182] = "INVALID_PARENT_ACCOUNTS";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_UPDATE_ARGS"] = 183] = "INVALID_UPDATE_ARGS";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INSUFFICIENT_TOKEN_BALANCE"] = 184] = "INSUFFICIENT_TOKEN_BALANCE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_COLLECTION_MINT"] = 185] = "MISSING_COLLECTION_MINT";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_COLLECTION_MASTER_EDITION"] = 186] = "MISSING_COLLECTION_MASTER_EDITION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_TOKEN_RECORD"] = 187] = "INVALID_TOKEN_RECORD";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_CLOSE_AUTHORITY"] = 188] = "INVALID_CLOSE_AUTHORITY";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_INSTRUCTION"] = 189] = "INVALID_INSTRUCTION";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_DELEGATE_RECORD"] = 190] = "MISSING_DELEGATE_RECORD";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_FEE_ACCOUNT"] = 191] = "INVALID_FEE_ACCOUNT";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_METADATA_FLAGS"] = 192] = "INVALID_METADATA_FLAGS";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["CANNOT_CHANGE_UPDATE_AUTHORITY_WITH_DELEGATE"] = 193] = "CANNOT_CHANGE_UPDATE_AUTHORITY_WITH_DELEGATE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_MINT_EXTENSION_TYPE"] = 194] = "INVALID_MINT_EXTENSION_TYPE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_MINT_CLOSE_AUTHORITY"] = 195] = "INVALID_MINT_CLOSE_AUTHORITY";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_METADATA_POINTER"] = 196] = "INVALID_METADATA_POINTER";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["INVALID_TOKEN_EXTENSION_TYPE"] = 197] = "INVALID_TOKEN_EXTENSION_TYPE";
  MplTokenMetadataProgramErrorCode3[MplTokenMetadataProgramErrorCode3["MISSING_IMMUTABLE_OWNER_EXTENSION"] = 198] = "MISSING_IMMUTABLE_OWNER_EXTENSION";
  return MplTokenMetadataProgramErrorCode3;
})(MplTokenMetadataProgramErrorCode || {});
var MplTokenMetadataProgramError = class extends Error {
  name = "MplTokenMetadataProgramError";
  code;
  cause;
  constructor(code, name, message, cause) {
    super(`${name} (${code}): ${message}`);
    this.code = code;
    this.cause = cause;
  }
};
var mplTokenMetadataProgramErrorCodeMap;
if (__DEV__) {
  mplTokenMetadataProgramErrorCodeMap = {
    [0 /* INSTRUCTION_UNPACK_ERROR */]: [
      "InstructionUnpackError",
      ``
    ],
    [1 /* INSTRUCTION_PACK_ERROR */]: [
      "InstructionPackError",
      ``
    ],
    [2 /* NOT_RENT_EXEMPT */]: [
      "NotRentExempt",
      `Lamport balance below rent-exempt threshold`
    ],
    [3 /* ALREADY_INITIALIZED */]: [
      "AlreadyInitialized",
      `Already initialized`
    ],
    [4 /* UNINITIALIZED */]: [
      "Uninitialized",
      `Uninitialized`
    ],
    [5 /* INVALID_METADATA_KEY */]: [
      "InvalidMetadataKey",
      ` Metadata's key must match seed of ['metadata', program id, mint] provided`
    ],
    [6 /* INVALID_EDITION_KEY */]: [
      "InvalidEditionKey",
      `Edition's key must match seed of ['metadata', program id, name, 'edition'] provided`
    ],
    [7 /* UPDATE_AUTHORITY_INCORRECT */]: [
      "UpdateAuthorityIncorrect",
      `Update Authority given does not match`
    ],
    [8 /* UPDATE_AUTHORITY_IS_NOT_SIGNER */]: [
      "UpdateAuthorityIsNotSigner",
      `Update Authority needs to be signer to update metadata`
    ],
    [9 /* NOT_MINT_AUTHORITY */]: [
      "NotMintAuthority",
      `You must be the mint authority and signer on this transaction`
    ],
    [10 /* INVALID_MINT_AUTHORITY */]: [
      "InvalidMintAuthority",
      `Mint authority provided does not match the authority on the mint`
    ],
    [11 /* NAME_TOO_LONG */]: [
      "NameTooLong",
      `Name too long`
    ],
    [12 /* SYMBOL_TOO_LONG */]: [
      "SymbolTooLong",
      `Symbol too long`
    ],
    [13 /* URI_TOO_LONG */]: [
      "UriTooLong",
      `URI too long`
    ],
    [14 /* UPDATE_AUTHORITY_MUST_BE_EQUAL_TO_METADATA_AUTHORITY_AND_SIGNER */]: ["UpdateAuthorityMustBeEqualToMetadataAuthorityAndSigner", ``],
    [15 /* MINT_MISMATCH */]: [
      "MintMismatch",
      `Mint given does not match mint on Metadata`
    ],
    [16 /* EDITIONS_MUST_HAVE_EXACTLY_ONE_TOKEN */]: [
      "EditionsMustHaveExactlyOneToken",
      `Editions must have exactly one token`
    ],
    [17 /* MAX_EDITIONS_MINTED_ALREADY */]: [
      "MaxEditionsMintedAlready",
      ``
    ],
    [18 /* TOKEN_MINT_TO_FAILED */]: [
      "TokenMintToFailed",
      ``
    ],
    [19 /* MASTER_RECORD_MISMATCH */]: [
      "MasterRecordMismatch",
      ``
    ],
    [20 /* DESTINATION_MINT_MISMATCH */]: [
      "DestinationMintMismatch",
      ``
    ],
    [21 /* EDITION_ALREADY_MINTED */]: [
      "EditionAlreadyMinted",
      ``
    ],
    [22 /* PRINTING_MINT_DECIMALS_SHOULD_BE_ZERO */]: [
      "PrintingMintDecimalsShouldBeZero",
      ``
    ],
    [23 /* ONE_TIME_PRINTING_AUTHORIZATION_MINT_DECIMALS_SHOULD_BE_ZERO */]: ["OneTimePrintingAuthorizationMintDecimalsShouldBeZero", ``],
    [24 /* EDITION_MINT_DECIMALS_SHOULD_BE_ZERO */]: [
      "EditionMintDecimalsShouldBeZero",
      `EditionMintDecimalsShouldBeZero`
    ],
    [25 /* TOKEN_BURN_FAILED */]: [
      "TokenBurnFailed",
      ``
    ],
    [26 /* TOKEN_ACCOUNT_ONE_TIME_AUTH_MINT_MISMATCH */]: ["TokenAccountOneTimeAuthMintMismatch", ``],
    [27 /* DERIVED_KEY_INVALID */]: [
      "DerivedKeyInvalid",
      `Derived key invalid`
    ],
    [28 /* PRINTING_MINT_MISMATCH */]: [
      "PrintingMintMismatch",
      `The Printing mint does not match that on the master edition!`
    ],
    [29 /* ONE_TIME_PRINTING_AUTH_MINT_MISMATCH */]: [
      "OneTimePrintingAuthMintMismatch",
      `The One Time Printing Auth mint does not match that on the master edition!`
    ],
    [30 /* TOKEN_ACCOUNT_MINT_MISMATCH */]: [
      "TokenAccountMintMismatch",
      `The mint of the token account does not match the Printing mint!`
    ],
    [31 /* TOKEN_ACCOUNT_MINT_MISMATCH_V2 */]: [
      "TokenAccountMintMismatchV2",
      `The mint of the token account does not match the master metadata mint!`
    ],
    [32 /* NOT_ENOUGH_TOKENS */]: [
      "NotEnoughTokens",
      `Not enough tokens to mint a limited edition`
    ],
    [33 /* PRINTING_MINT_AUTHORIZATION_ACCOUNT_MISMATCH */]: ["PrintingMintAuthorizationAccountMismatch", ``],
    [34 /* AUTHORIZATION_TOKEN_ACCOUNT_OWNER_MISMATCH */]: ["AuthorizationTokenAccountOwnerMismatch", ``],
    [35 /* DISABLED */]: ["Disabled", ``],
    [36 /* CREATORS_TOO_LONG */]: [
      "CreatorsTooLong",
      `Creators list too long`
    ],
    [37 /* CREATORS_MUST_BE_ATLEAST_ONE */]: [
      "CreatorsMustBeAtleastOne",
      `Creators must be at least one if set`
    ],
    [38 /* MUST_BE_ONE_OF_CREATORS */]: [
      "MustBeOneOfCreators",
      ``
    ],
    [39 /* NO_CREATORS_PRESENT_ON_METADATA */]: [
      "NoCreatorsPresentOnMetadata",
      `This metadata does not have creators`
    ],
    [40 /* CREATOR_NOT_FOUND */]: [
      "CreatorNotFound",
      `This creator address was not found`
    ],
    [41 /* INVALID_BASIS_POINTS */]: [
      "InvalidBasisPoints",
      `Basis points cannot be more than 10000`
    ],
    [42 /* PRIMARY_SALE_CAN_ONLY_BE_FLIPPED_TO_TRUE */]: [
      "PrimarySaleCanOnlyBeFlippedToTrue",
      `Primary sale can only be flipped to true and is immutable`
    ],
    [43 /* OWNER_MISMATCH */]: [
      "OwnerMismatch",
      `Owner does not match that on the account given`
    ],
    [44 /* NO_BALANCE_IN_ACCOUNT_FOR_AUTHORIZATION */]: [
      "NoBalanceInAccountForAuthorization",
      `This account has no tokens to be used for authorization`
    ],
    [45 /* SHARE_TOTAL_MUST_BE100 */]: [
      "ShareTotalMustBe100",
      `Share total must equal 100 for creator array`
    ],
    [46 /* RESERVATION_EXISTS */]: [
      "ReservationExists",
      ``
    ],
    [47 /* RESERVATION_DOES_NOT_EXIST */]: [
      "ReservationDoesNotExist",
      ``
    ],
    [48 /* RESERVATION_NOT_SET */]: [
      "ReservationNotSet",
      ``
    ],
    [49 /* RESERVATION_ALREADY_MADE */]: [
      "ReservationAlreadyMade",
      ``
    ],
    [50 /* BEYOND_MAX_ADDRESS_SIZE */]: [
      "BeyondMaxAddressSize",
      ``
    ],
    [51 /* NUMERICAL_OVERFLOW_ERROR */]: [
      "NumericalOverflowError",
      `NumericalOverflowError`
    ],
    [52 /* RESERVATION_BREACHES_MAXIMUM_SUPPLY */]: [
      "ReservationBreachesMaximumSupply",
      ``
    ],
    [53 /* ADDRESS_NOT_IN_RESERVATION */]: [
      "AddressNotInReservation",
      ``
    ],
    [54 /* CANNOT_VERIFY_ANOTHER_CREATOR */]: [
      "CannotVerifyAnotherCreator",
      `You cannot unilaterally verify another creator, they must sign`
    ],
    [55 /* CANNOT_UNVERIFY_ANOTHER_CREATOR */]: [
      "CannotUnverifyAnotherCreator",
      `You cannot unilaterally unverify another creator`
    ],
    [56 /* SPOT_MISMATCH */]: ["SpotMismatch", ``],
    [57 /* INCORRECT_OWNER */]: [
      "IncorrectOwner",
      `Incorrect account owner`
    ],
    [58 /* PRINTING_WOULD_BREACH_MAXIMUM_SUPPLY */]: [
      "PrintingWouldBreachMaximumSupply",
      ``
    ],
    [59 /* DATA_IS_IMMUTABLE */]: [
      "DataIsImmutable",
      `Data is immutable`
    ],
    [60 /* DUPLICATE_CREATOR_ADDRESS */]: [
      "DuplicateCreatorAddress",
      `No duplicate creator addresses`
    ],
    [61 /* RESERVATION_SPOTS_REMAINING_SHOULD_MATCH_TOTAL_SPOTS_AT_START */]: ["ReservationSpotsRemainingShouldMatchTotalSpotsAtStart", ``],
    [62 /* INVALID_TOKEN_PROGRAM */]: [
      "InvalidTokenProgram",
      `Invalid token program`
    ],
    [63 /* DATA_TYPE_MISMATCH */]: [
      "DataTypeMismatch",
      `Data type mismatch`
    ],
    [64 /* BEYOND_ALOTTED_ADDRESS_SIZE */]: [
      "BeyondAlottedAddressSize",
      ``
    ],
    [65 /* RESERVATION_NOT_COMPLETE */]: [
      "ReservationNotComplete",
      ``
    ],
    [66 /* TRIED_TO_REPLACE_AN_EXISTING_RESERVATION */]: ["TriedToReplaceAnExistingReservation", ``],
    [67 /* INVALID_OPERATION */]: [
      "InvalidOperation",
      `Invalid operation`
    ],
    [68 /* INVALID_OWNER */]: [
      "InvalidOwner",
      `Invalid Owner`
    ],
    [69 /* PRINTING_MINT_SUPPLY_MUST_BE_ZERO_FOR_CONVERSION */]: [
      "PrintingMintSupplyMustBeZeroForConversion",
      `Printing mint supply must be zero for conversion`
    ],
    [70 /* ONE_TIME_AUTH_MINT_SUPPLY_MUST_BE_ZERO_FOR_CONVERSION */]: [
      "OneTimeAuthMintSupplyMustBeZeroForConversion",
      `One Time Auth mint supply must be zero for conversion`
    ],
    [71 /* INVALID_EDITION_INDEX */]: [
      "InvalidEditionIndex",
      `You tried to insert one edition too many into an edition mark pda`
    ],
    [72 /* RESERVATION_ARRAY_SHOULD_BE_SIZE_ONE */]: [
      "ReservationArrayShouldBeSizeOne",
      ``
    ],
    [73 /* IS_MUTABLE_CAN_ONLY_BE_FLIPPED_TO_FALSE */]: [
      "IsMutableCanOnlyBeFlippedToFalse",
      `Is Mutable can only be flipped to false`
    ],
    [74 /* COLLECTION_CANNOT_BE_VERIFIED_IN_THIS_INSTRUCTION */]: [
      "CollectionCannotBeVerifiedInThisInstruction",
      `Collection cannot be verified in this instruction`
    ],
    [75 /* REMOVED */]: [
      "Removed",
      `This instruction was deprecated in a previous release and is now removed`
    ],
    [76 /* MUST_BE_BURNED */]: ["MustBeBurned", ``],
    [77 /* INVALID_USE_METHOD */]: [
      "InvalidUseMethod",
      `This use method is invalid`
    ],
    [78 /* CANNOT_CHANGE_USE_METHOD_AFTER_FIRST_USE */]: [
      "CannotChangeUseMethodAfterFirstUse",
      `Cannot Change Use Method after the first use`
    ],
    [79 /* CANNOT_CHANGE_USES_AFTER_FIRST_USE */]: [
      "CannotChangeUsesAfterFirstUse",
      `Cannot Change Remaining or Available uses after the first use`
    ],
    [80 /* COLLECTION_NOT_FOUND */]: [
      "CollectionNotFound",
      `Collection Not Found on Metadata`
    ],
    [81 /* INVALID_COLLECTION_UPDATE_AUTHORITY */]: [
      "InvalidCollectionUpdateAuthority",
      `Collection Update Authority is invalid`
    ],
    [82 /* COLLECTION_MUST_BE_A_UNIQUE_MASTER_EDITION */]: [
      "CollectionMustBeAUniqueMasterEdition",
      `Collection Must Be a Unique Master Edition v2`
    ],
    [83 /* USE_AUTHORITY_RECORD_ALREADY_EXISTS */]: [
      "UseAuthorityRecordAlreadyExists",
      `The Use Authority Record Already Exists, to modify it Revoke, then Approve`
    ],
    [84 /* USE_AUTHORITY_RECORD_ALREADY_REVOKED */]: [
      "UseAuthorityRecordAlreadyRevoked",
      `The Use Authority Record is empty or already revoked`
    ],
    [85 /* UNUSABLE */]: [
      "Unusable",
      `This token has no uses`
    ],
    [86 /* NOT_ENOUGH_USES */]: [
      "NotEnoughUses",
      `There are not enough Uses left on this token.`
    ],
    [87 /* COLLECTION_AUTHORITY_RECORD_ALREADY_EXISTS */]: [
      "CollectionAuthorityRecordAlreadyExists",
      `This Collection Authority Record Already Exists.`
    ],
    [88 /* COLLECTION_AUTHORITY_DOES_NOT_EXIST */]: [
      "CollectionAuthorityDoesNotExist",
      `This Collection Authority Record Does Not Exist.`
    ],
    [89 /* INVALID_USE_AUTHORITY_RECORD */]: [
      "InvalidUseAuthorityRecord",
      `This Use Authority Record is invalid.`
    ],
    [90 /* INVALID_COLLECTION_AUTHORITY_RECORD */]: [
      "InvalidCollectionAuthorityRecord",
      ``
    ],
    [91 /* INVALID_FREEZE_AUTHORITY */]: [
      "InvalidFreezeAuthority",
      `Metadata does not match the freeze authority on the mint`
    ],
    [92 /* INVALID_DELEGATE */]: [
      "InvalidDelegate",
      `All tokens in this account have not been delegated to this user.`
    ],
    [93 /* CANNOT_ADJUST_VERIFIED_CREATOR */]: [
      "CannotAdjustVerifiedCreator",
      ``
    ],
    [94 /* CANNOT_REMOVE_VERIFIED_CREATOR */]: [
      "CannotRemoveVerifiedCreator",
      `Verified creators cannot be removed.`
    ],
    [95 /* CANNOT_WIPE_VERIFIED_CREATORS */]: [
      "CannotWipeVerifiedCreators",
      ``
    ],
    [96 /* NOT_ALLOWED_TO_CHANGE_SELLER_FEE_BASIS_POINTS */]: ["NotAllowedToChangeSellerFeeBasisPoints", ``],
    [97 /* EDITION_OVERRIDE_CANNOT_BE_ZERO */]: [
      "EditionOverrideCannotBeZero",
      `Edition override cannot be zero`
    ],
    [98 /* INVALID_USER */]: [
      "InvalidUser",
      `Invalid User`
    ],
    [99 /* REVOKE_COLLECTION_AUTHORITY_SIGNER_INCORRECT */]: [
      "RevokeCollectionAuthoritySignerIncorrect",
      `Revoke Collection Authority signer is incorrect`
    ],
    [100 /* TOKEN_CLOSE_FAILED */]: [
      "TokenCloseFailed",
      ``
    ],
    [101 /* UNSIZED_COLLECTION */]: [
      "UnsizedCollection",
      `Can't use this function on unsized collection`
    ],
    [102 /* SIZED_COLLECTION */]: [
      "SizedCollection",
      `Can't use this function on a sized collection`
    ],
    [103 /* MISSING_COLLECTION_METADATA */]: [
      "MissingCollectionMetadata",
      `Missing collection metadata account`
    ],
    [104 /* NOT_A_MEMBER_OF_COLLECTION */]: [
      "NotAMemberOfCollection",
      `This NFT is not a member of the specified collection.`
    ],
    [105 /* NOT_VERIFIED_MEMBER_OF_COLLECTION */]: [
      "NotVerifiedMemberOfCollection",
      `This NFT is not a verified member of the specified collection.`
    ],
    [106 /* NOT_A_COLLECTION_PARENT */]: [
      "NotACollectionParent",
      `This NFT is not a collection parent NFT.`
    ],
    [107 /* COULD_NOT_DETERMINE_TOKEN_STANDARD */]: [
      "CouldNotDetermineTokenStandard",
      `Could not determine a TokenStandard type.`
    ],
    [108 /* MISSING_EDITION_ACCOUNT */]: [
      "MissingEditionAccount",
      `This mint account has an edition but none was provided.`
    ],
    [109 /* NOT_A_MASTER_EDITION */]: [
      "NotAMasterEdition",
      `This edition is not a Master Edition`
    ],
    [110 /* MASTER_EDITION_HAS_PRINTS */]: [
      "MasterEditionHasPrints",
      `This Master Edition has existing prints`
    ],
    [111 /* BORSH_DESERIALIZATION_ERROR */]: [
      "BorshDeserializationError",
      ``
    ],
    [112 /* CANNOT_UPDATE_VERIFIED_COLLECTION */]: [
      "CannotUpdateVerifiedCollection",
      `Cannot update a verified collection in this command`
    ],
    [113 /* COLLECTION_MASTER_EDITION_ACCOUNT_INVALID */]: [
      "CollectionMasterEditionAccountInvalid",
      `Edition account doesnt match collection `
    ],
    [114 /* ALREADY_VERIFIED */]: [
      "AlreadyVerified",
      `Item is already verified.`
    ],
    [115 /* ALREADY_UNVERIFIED */]: [
      "AlreadyUnverified",
      ``
    ],
    [116 /* NOT_A_PRINT_EDITION */]: [
      "NotAPrintEdition",
      `This edition is not a Print Edition`
    ],
    [117 /* INVALID_MASTER_EDITION */]: [
      "InvalidMasterEdition",
      `Invalid Master Edition`
    ],
    [118 /* INVALID_PRINT_EDITION */]: [
      "InvalidPrintEdition",
      `Invalid Print Edition`
    ],
    [119 /* INVALID_EDITION_MARKER */]: [
      "InvalidEditionMarker",
      `Invalid Edition Marker`
    ],
    [120 /* RESERVATION_LIST_DEPRECATED */]: [
      "ReservationListDeprecated",
      `Reservation List is Deprecated`
    ],
    [121 /* PRINT_EDITION_DOES_NOT_MATCH_MASTER_EDITION */]: [
      "PrintEditionDoesNotMatchMasterEdition",
      `Print Edition does not match Master Edition`
    ],
    [122 /* EDITION_NUMBER_GREATER_THAN_MAX_SUPPLY */]: [
      "EditionNumberGreaterThanMaxSupply",
      `Edition Number greater than max supply`
    ],
    [123 /* MUST_UNVERIFY */]: [
      "MustUnverify",
      `Must unverify before migrating collections.`
    ],
    [124 /* INVALID_ESCROW_BUMP_SEED */]: [
      "InvalidEscrowBumpSeed",
      `Invalid Escrow Account Bump Seed`
    ],
    [125 /* MUST_BE_ESCROW_AUTHORITY */]: [
      "MustBeEscrowAuthority",
      `Must Escrow Authority`
    ],
    [126 /* INVALID_SYSTEM_PROGRAM */]: [
      "InvalidSystemProgram",
      `Invalid System Program`
    ],
    [127 /* MUST_BE_NON_FUNGIBLE */]: [
      "MustBeNonFungible",
      `Must be a Non Fungible Token`
    ],
    [128 /* INSUFFICIENT_TOKENS */]: [
      "InsufficientTokens",
      `Insufficient tokens for transfer`
    ],
    [129 /* BORSH_SERIALIZATION_ERROR */]: [
      "BorshSerializationError",
      `Borsh Serialization Error`
    ],
    [130 /* NO_FREEZE_AUTHORITY_SET */]: [
      "NoFreezeAuthoritySet",
      `Cannot create NFT with no Freeze Authority.`
    ],
    [131 /* INVALID_COLLECTION_SIZE_CHANGE */]: [
      "InvalidCollectionSizeChange",
      `Invalid collection size change`
    ],
    [132 /* INVALID_BUBBLEGUM_SIGNER */]: [
      "InvalidBubblegumSigner",
      `Invalid bubblegum signer`
    ],
    [133 /* ESCROW_PARENT_HAS_DELEGATE */]: [
      "EscrowParentHasDelegate",
      `Escrow parent cannot have a delegate`
    ],
    [134 /* MINT_IS_NOT_SIGNER */]: [
      "MintIsNotSigner",
      `Mint needs to be signer to initialize the account`
    ],
    [135 /* INVALID_TOKEN_STANDARD */]: [
      "InvalidTokenStandard",
      `Invalid token standard`
    ],
    [136 /* INVALID_MINT_FOR_TOKEN_STANDARD */]: [
      "InvalidMintForTokenStandard",
      `Invalid mint account for specified token standard`
    ],
    [137 /* INVALID_AUTHORIZATION_RULES */]: [
      "InvalidAuthorizationRules",
      `Invalid authorization rules account`
    ],
    [138 /* MISSING_AUTHORIZATION_RULES */]: [
      "MissingAuthorizationRules",
      `Missing authorization rules account`
    ],
    [139 /* MISSING_PROGRAMMABLE_CONFIG */]: [
      "MissingProgrammableConfig",
      `Missing programmable configuration`
    ],
    [140 /* INVALID_PROGRAMMABLE_CONFIG */]: [
      "InvalidProgrammableConfig",
      `Invalid programmable configuration`
    ],
    [141 /* DELEGATE_ALREADY_EXISTS */]: [
      "DelegateAlreadyExists",
      `Delegate already exists`
    ],
    [142 /* DELEGATE_NOT_FOUND */]: [
      "DelegateNotFound",
      `Delegate not found`
    ],
    [143 /* MISSING_ACCOUNT_IN_BUILDER */]: [
      "MissingAccountInBuilder",
      `Required account not set in instruction builder`
    ],
    [144 /* MISSING_ARGUMENT_IN_BUILDER */]: [
      "MissingArgumentInBuilder",
      `Required argument not set in instruction builder`
    ],
    [145 /* FEATURE_NOT_SUPPORTED */]: [
      "FeatureNotSupported",
      `Feature not supported currently`
    ],
    [146 /* INVALID_SYSTEM_WALLET */]: [
      "InvalidSystemWallet",
      `Invalid system wallet`
    ],
    [147 /* ONLY_SALE_DELEGATE_CAN_TRANSFER */]: [
      "OnlySaleDelegateCanTransfer",
      `Only the sale delegate can transfer while its set`
    ],
    [148 /* MISSING_TOKEN_ACCOUNT */]: [
      "MissingTokenAccount",
      `Missing token account`
    ],
    [149 /* MISSING_SPL_TOKEN_PROGRAM */]: [
      "MissingSplTokenProgram",
      `Missing SPL token program`
    ],
    [150 /* MISSING_AUTHORIZATION_RULES_PROGRAM */]: [
      "MissingAuthorizationRulesProgram",
      `Missing authorization rules program`
    ],
    [151 /* INVALID_DELEGATE_ROLE_FOR_TRANSFER */]: [
      "InvalidDelegateRoleForTransfer",
      `Invalid delegate role for transfer`
    ],
    [152 /* INVALID_TRANSFER_AUTHORITY */]: [
      "InvalidTransferAuthority",
      `Invalid transfer authority`
    ],
    [153 /* INSTRUCTION_NOT_SUPPORTED */]: [
      "InstructionNotSupported",
      `Instruction not supported for ProgrammableNonFungible assets`
    ],
    [154 /* KEY_MISMATCH */]: [
      "KeyMismatch",
      `Public key does not match expected value`
    ],
    [155 /* LOCKED_TOKEN */]: [
      "LockedToken",
      `Token is locked`
    ],
    [156 /* UNLOCKED_TOKEN */]: [
      "UnlockedToken",
      `Token is unlocked`
    ],
    [157 /* MISSING_DELEGATE_ROLE */]: [
      "MissingDelegateRole",
      `Missing delegate role`
    ],
    [158 /* INVALID_AUTHORITY_TYPE */]: [
      "InvalidAuthorityType",
      `Invalid authority type`
    ],
    [159 /* MISSING_TOKEN_RECORD */]: [
      "MissingTokenRecord",
      `Missing token record account`
    ],
    [160 /* MINT_SUPPLY_MUST_BE_ZERO */]: [
      "MintSupplyMustBeZero",
      `Mint supply must be zero for programmable assets`
    ],
    [161 /* DATA_IS_EMPTY_OR_ZEROED */]: [
      "DataIsEmptyOrZeroed",
      `Data is empty or zeroed`
    ],
    [162 /* MISSING_TOKEN_OWNER_ACCOUNT */]: [
      "MissingTokenOwnerAccount",
      `Missing token owner`
    ],
    [163 /* INVALID_MASTER_EDITION_ACCOUNT_LENGTH */]: [
      "InvalidMasterEditionAccountLength",
      `Master edition account has an invalid length`
    ],
    [164 /* INCORRECT_TOKEN_STATE */]: [
      "IncorrectTokenState",
      `Incorrect token state`
    ],
    [165 /* INVALID_DELEGATE_ROLE */]: [
      "InvalidDelegateRole",
      `Invalid delegate role`
    ],
    [166 /* MISSING_PRINT_SUPPLY */]: [
      "MissingPrintSupply",
      `Print supply is required for non-fungibles`
    ],
    [167 /* MISSING_MASTER_EDITION_ACCOUNT */]: [
      "MissingMasterEditionAccount",
      `Missing master edition account`
    ],
    [168 /* AMOUNT_MUST_BE_GREATER_THAN_ZERO */]: [
      "AmountMustBeGreaterThanZero",
      `Amount must be greater than zero`
    ],
    [169 /* INVALID_DELEGATE_ARGS */]: [
      "InvalidDelegateArgs",
      `Invalid delegate args`
    ],
    [170 /* MISSING_LOCKED_TRANSFER_ADDRESS */]: [
      "MissingLockedTransferAddress",
      `Missing address for locked transfer`
    ],
    [171 /* INVALID_LOCKED_TRANSFER_ADDRESS */]: [
      "InvalidLockedTransferAddress",
      `Invalid destination address for locked transfer`
    ],
    [172 /* DATA_INCREMENT_LIMIT_EXCEEDED */]: [
      "DataIncrementLimitExceeded",
      `Exceeded account realloc increase limit`
    ],
    [173 /* CANNOT_UPDATE_ASSET_WITH_DELEGATE */]: [
      "CannotUpdateAssetWithDelegate",
      `Cannot update the rule set of a programmable asset that has a delegate`
    ],
    [174 /* INVALID_AMOUNT */]: [
      "InvalidAmount",
      `Invalid token amount for this operation or token standard`
    ],
    [175 /* MISSING_MASTER_EDITION_MINT_ACCOUNT */]: [
      "MissingMasterEditionMintAccount",
      `Missing master edition mint account`
    ],
    [176 /* MISSING_MASTER_EDITION_TOKEN_ACCOUNT */]: [
      "MissingMasterEditionTokenAccount",
      `Missing master edition token account`
    ],
    [177 /* MISSING_EDITION_MARKER_ACCOUNT */]: [
      "MissingEditionMarkerAccount",
      `Missing edition marker account`
    ],
    [178 /* CANNOT_BURN_WITH_DELEGATE */]: [
      "CannotBurnWithDelegate",
      `Cannot burn while persistent delegate is set`
    ],
    [179 /* MISSING_EDITION */]: [
      "MissingEdition",
      `Missing edition account`
    ],
    [180 /* INVALID_ASSOCIATED_TOKEN_ACCOUNT_PROGRAM */]: [
      "InvalidAssociatedTokenAccountProgram",
      `Invalid Associated Token Account Program`
    ],
    [181 /* INVALID_INSTRUCTIONS_SYSVAR */]: [
      "InvalidInstructionsSysvar",
      `Invalid InstructionsSysvar`
    ],
    [182 /* INVALID_PARENT_ACCOUNTS */]: [
      "InvalidParentAccounts",
      `Invalid or Unneeded parent accounts`
    ],
    [183 /* INVALID_UPDATE_ARGS */]: [
      "InvalidUpdateArgs",
      `Authority cannot apply all update args`
    ],
    [184 /* INSUFFICIENT_TOKEN_BALANCE */]: [
      "InsufficientTokenBalance",
      `Token account does not have enough tokens`
    ],
    [185 /* MISSING_COLLECTION_MINT */]: [
      "MissingCollectionMint",
      `Missing collection account`
    ],
    [186 /* MISSING_COLLECTION_MASTER_EDITION */]: [
      "MissingCollectionMasterEdition",
      `Missing collection master edition account`
    ],
    [187 /* INVALID_TOKEN_RECORD */]: [
      "InvalidTokenRecord",
      `Invalid token record account`
    ],
    [188 /* INVALID_CLOSE_AUTHORITY */]: [
      "InvalidCloseAuthority",
      `The close authority needs to be revoked by the Utility Delegate`
    ],
    [189 /* INVALID_INSTRUCTION */]: [
      "InvalidInstruction",
      `Invalid or removed instruction`
    ],
    [190 /* MISSING_DELEGATE_RECORD */]: [
      "MissingDelegateRecord",
      `Missing delegate record`
    ],
    [191 /* INVALID_FEE_ACCOUNT */]: [
      "InvalidFeeAccount",
      ``
    ],
    [192 /* INVALID_METADATA_FLAGS */]: [
      "InvalidMetadataFlags",
      ``
    ],
    [193 /* CANNOT_CHANGE_UPDATE_AUTHORITY_WITH_DELEGATE */]: [
      "CannotChangeUpdateAuthorityWithDelegate",
      `Cannot change the update authority with a delegate`
    ],
    [194 /* INVALID_MINT_EXTENSION_TYPE */]: [
      "InvalidMintExtensionType",
      `Invalid mint extension type`
    ],
    [195 /* INVALID_MINT_CLOSE_AUTHORITY */]: [
      "InvalidMintCloseAuthority",
      `Invalid mint close authority`
    ],
    [196 /* INVALID_METADATA_POINTER */]: [
      "InvalidMetadataPointer",
      `Invalid metadata pointer`
    ],
    [197 /* INVALID_TOKEN_EXTENSION_TYPE */]: [
      "InvalidTokenExtensionType",
      `Invalid token extension type`
    ],
    [198 /* MISSING_IMMUTABLE_OWNER_EXTENSION */]: [
      "MissingImmutableOwnerExtension",
      `Missing immutable owner extension`
    ]
  };
}
function getMplTokenMetadataProgramErrorFromCode(code, cause) {
  if (__DEV__) {
    return new MplTokenMetadataProgramError(
      code,
      ...mplTokenMetadataProgramErrorCodeMap[code],
      cause
    );
  }
  return new MplTokenMetadataProgramError(
    code,
    "Unknown",
    "Error message not available in production bundles. Compile with __DEV__ set to true to see more information.",
    cause
  );
}
function expectSome(value) {
  if (value == null) {
    throw new Error("Expected a value but received null or undefined.");
  }
  return value;
}
function expectAddress(value) {
  if (!value) {
    throw new Error("Expected a Address.");
  }
  if (typeof value === "object" && "address" in value) {
    return value.address;
  }
  if (Array.isArray(value)) {
    return value[0];
  }
  return value;
}
function expectProgramDerivedAddress(value) {
  if (!value || !Array.isArray(value) || !isProgramDerivedAddress(value)) {
    throw new Error("Expected a ProgramDerivedAddress.");
  }
  return value;
}
function expectTransactionSigner(value) {
  if (!value || !isTransactionSigner(value)) {
    throw new Error("Expected a TransactionSigner.");
  }
  return value;
}
function accountMetaWithDefault(account, role) {
  if (account === void 0)
    return void 0;
  return typeof account === "string" ? { address: account, role } : account;
}
function getAccountMetasWithSigners(accounts, optionalAccountStrategy, programAddress) {
  const accountMetas = {};
  Object.keys(accounts).forEach((key) => {
    const account = accounts[key];
    if (!account.value) {
      if (optionalAccountStrategy === "omitted")
        return;
      accountMetas[key] = {
        address: programAddress,
        role: AccountRole.READONLY
      };
      return;
    }
    const writableRole = account.isWritable ? AccountRole.WRITABLE : AccountRole.READONLY;
    accountMetas[key] = Object.freeze({
      address: expectAddress(account.value),
      role: isTransactionSigner(account.value) ? upgradeRoleToSigner(writableRole) : writableRole,
      ...isTransactionSigner(account.value) ? { signer: account.value } : {}
    });
  });
  return accountMetas;
}
function isTransactionSigner(value) {
  return !!value && typeof value === "object" && "address" in value && isTransactionSigner$1(value);
}
function memcmp(data, bytes, offset) {
  const slice = data.slice(offset, offset + bytes.length);
  if (slice.length !== bytes.length)
    return false;
  return bytes.every((b, i) => b === slice[i]);
}

// src/generated/instructions/approveCollectionAuthority.ts
function getApproveCollectionAuthorityInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 23 })
  );
}
function getApproveCollectionAuthorityInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getApproveCollectionAuthorityInstructionDataCodec() {
  return combineCodec(
    getApproveCollectionAuthorityInstructionDataEncoder(),
    getApproveCollectionAuthorityInstructionDataDecoder()
  );
}
async function getApproveCollectionAuthorityInstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    collectionAuthorityRecord: {
      value: input.collectionAuthorityRecord ?? null,
      isWritable: true
    },
    newCollectionAuthority: {
      value: input.newCollectionAuthority ?? null,
      isWritable: false
    },
    updateAuthority: { value: input.updateAuthority ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    metadata: { value: input.metadata ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  if (!accounts.metadata.value) {
    accounts.metadata.value = await findMetadataPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getApproveCollectionAuthorityInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getApproveCollectionAuthorityInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    collectionAuthorityRecord: {
      value: input.collectionAuthorityRecord ?? null,
      isWritable: true
    },
    newCollectionAuthority: {
      value: input.newCollectionAuthority ?? null,
      isWritable: false
    },
    updateAuthority: { value: input.updateAuthority ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    metadata: { value: input.metadata ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getApproveCollectionAuthorityInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getApproveCollectionAuthorityInstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(
        accounts.collectionAuthorityRecord,
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(
        accounts.newCollectionAuthority,
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.updateAuthority,
        AccountRole.WRITABLE_SIGNER
      ),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(accounts.metadata, AccountRole.READONLY),
      accountMetaWithDefault(accounts.mint, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.rent, AccountRole.READONLY),
      ...remainingAccounts ?? []
    ].filter((x) => x !== void 0),
    data: getApproveCollectionAuthorityInstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseApproveCollectionAuthorityInstruction(instruction) {
  if (instruction.accounts.length < 7) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 7;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0)
      return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      collectionAuthorityRecord: getNextAccount(),
      newCollectionAuthority: getNextAccount(),
      updateAuthority: getNextAccount(),
      payer: getNextAccount(),
      metadata: getNextAccount(),
      mint: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextOptionalAccount()
    },
    data: getApproveCollectionAuthorityInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getApproveUseAuthorityInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["numberOfUses", getU64Encoder()]
    ]),
    (value) => ({ ...value, discriminator: 20 })
  );
}
function getApproveUseAuthorityInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["numberOfUses", getU64Decoder()]
  ]);
}
function getApproveUseAuthorityInstructionDataCodec() {
  return combineCodec(
    getApproveUseAuthorityInstructionDataEncoder(),
    getApproveUseAuthorityInstructionDataDecoder()
  );
}
async function getApproveUseAuthorityInstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    useAuthorityRecord: {
      value: input.useAuthorityRecord ?? null,
      isWritable: true
    },
    owner: { value: input.owner ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    user: { value: input.user ?? null, isWritable: false },
    ownerTokenAccount: {
      value: input.ownerTokenAccount ?? null,
      isWritable: true
    },
    metadata: { value: input.metadata ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    burner: { value: input.burner ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  const args = { ...input };
  if (!accounts.metadata.value) {
    accounts.metadata.value = await findMetadataPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getApproveUseAuthorityInstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getApproveUseAuthorityInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    useAuthorityRecord: {
      value: input.useAuthorityRecord ?? null,
      isWritable: true
    },
    owner: { value: input.owner ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    user: { value: input.user ?? null, isWritable: false },
    ownerTokenAccount: {
      value: input.ownerTokenAccount ?? null,
      isWritable: true
    },
    metadata: { value: input.metadata ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    burner: { value: input.burner ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getApproveUseAuthorityInstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getApproveUseAuthorityInstructionRaw(accounts, args, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.useAuthorityRecord, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.owner, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(accounts.user, AccountRole.READONLY),
      accountMetaWithDefault(accounts.ownerTokenAccount, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.metadata, AccountRole.READONLY),
      accountMetaWithDefault(accounts.mint, AccountRole.READONLY),
      accountMetaWithDefault(accounts.burner, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.tokenProgram ?? "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.rent, AccountRole.READONLY),
      ...remainingAccounts ?? []
    ].filter((x) => x !== void 0),
    data: getApproveUseAuthorityInstructionDataEncoder().encode(args),
    programAddress
  };
}
function parseApproveUseAuthorityInstruction(instruction) {
  if (instruction.accounts.length < 10) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 10;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0)
      return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      useAuthorityRecord: getNextAccount(),
      owner: getNextAccount(),
      payer: getNextAccount(),
      user: getNextAccount(),
      ownerTokenAccount: getNextAccount(),
      metadata: getNextAccount(),
      mint: getNextAccount(),
      burner: getNextAccount(),
      tokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextOptionalAccount()
    },
    data: getApproveUseAuthorityInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getBubblegumSetCollectionSizeInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["setCollectionSizeArgs", getSetCollectionSizeArgsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 36 })
  );
}
function getBubblegumSetCollectionSizeInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["setCollectionSizeArgs", getSetCollectionSizeArgsDecoder()]
  ]);
}
function getBubblegumSetCollectionSizeInstructionDataCodec() {
  return combineCodec(
    getBubblegumSetCollectionSizeInstructionDataEncoder(),
    getBubblegumSetCollectionSizeInstructionDataDecoder()
  );
}
function getBubblegumSetCollectionSizeInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: true
    },
    collectionAuthority: {
      value: input.collectionAuthority ?? null,
      isWritable: false
    },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    bubblegumSigner: {
      value: input.bubblegumSigner ?? null,
      isWritable: false
    },
    collectionAuthorityRecord: {
      value: input.collectionAuthorityRecord ?? null,
      isWritable: false
    }
  };
  const args = { ...input };
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getBubblegumSetCollectionSizeInstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getBubblegumSetCollectionSizeInstructionRaw(accounts, args, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.collectionMetadata, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.collectionAuthority,
        AccountRole.READONLY_SIGNER
      ),
      accountMetaWithDefault(accounts.collectionMint, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.bubblegumSigner,
        AccountRole.READONLY_SIGNER
      ),
      accountMetaWithDefault(
        accounts.collectionAuthorityRecord,
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ].filter((x) => x !== void 0),
    data: getBubblegumSetCollectionSizeInstructionDataEncoder().encode(args),
    programAddress
  };
}
function parseBubblegumSetCollectionSizeInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 4;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0)
      return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      collectionMetadata: getNextAccount(),
      collectionAuthority: getNextAccount(),
      collectionMint: getNextAccount(),
      bubblegumSigner: getNextAccount(),
      collectionAuthorityRecord: getNextOptionalAccount()
    },
    data: getBubblegumSetCollectionSizeInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getBurnEditionNftInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 37 })
  );
}
function getBurnEditionNftInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getBurnEditionNftInstructionDataCodec() {
  return combineCodec(
    getBurnEditionNftInstructionDataEncoder(),
    getBurnEditionNftInstructionDataDecoder()
  );
}
function getBurnEditionNftInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    printEditionMint: {
      value: input.printEditionMint ?? null,
      isWritable: true
    },
    masterEditionMint: {
      value: input.masterEditionMint ?? null,
      isWritable: false
    },
    printEditionTokenAccount: {
      value: input.printEditionTokenAccount ?? null,
      isWritable: true
    },
    masterEditionTokenAccount: {
      value: input.masterEditionTokenAccount ?? null,
      isWritable: false
    },
    masterEditionAccount: {
      value: input.masterEditionAccount ?? null,
      isWritable: true
    },
    printEditionAccount: {
      value: input.printEditionAccount ?? null,
      isWritable: true
    },
    editionMarkerAccount: {
      value: input.editionMarkerAccount ?? null,
      isWritable: true
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    }
  };
  if (!accounts.splTokenProgram.value) {
    accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getBurnEditionNftInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getBurnEditionNftInstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.owner, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(accounts.printEditionMint, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.masterEditionMint, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.printEditionTokenAccount,
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(
        accounts.masterEditionTokenAccount,
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.masterEditionAccount,
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(
        accounts.printEditionAccount,
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(
        accounts.editionMarkerAccount,
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(
        accounts.splTokenProgram ?? "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA",
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ],
    data: getBurnEditionNftInstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseBurnEditionNftInstruction(instruction) {
  if (instruction.accounts.length < 10) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      owner: getNextAccount(),
      printEditionMint: getNextAccount(),
      masterEditionMint: getNextAccount(),
      printEditionTokenAccount: getNextAccount(),
      masterEditionTokenAccount: getNextAccount(),
      masterEditionAccount: getNextAccount(),
      printEditionAccount: getNextAccount(),
      editionMarkerAccount: getNextAccount(),
      splTokenProgram: getNextAccount()
    },
    data: getBurnEditionNftInstructionDataDecoder().decode(instruction.data)
  };
}
function getBurnNftInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 29 })
  );
}
function getBurnNftInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getBurnNftInstructionDataCodec() {
  return combineCodec(
    getBurnNftInstructionDataEncoder(),
    getBurnNftInstructionDataDecoder()
  );
}
async function getBurnNftInstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    tokenAccount: { value: input.tokenAccount ?? null, isWritable: true },
    masterEditionAccount: {
      value: input.masterEditionAccount ?? null,
      isWritable: true
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: true
    }
  };
  if (!accounts.metadata.value) {
    accounts.metadata.value = await findMetadataPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.splTokenProgram.value) {
    accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getBurnNftInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getBurnNftInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    tokenAccount: { value: input.tokenAccount ?? null, isWritable: true },
    masterEditionAccount: {
      value: input.masterEditionAccount ?? null,
      isWritable: true
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: true
    }
  };
  if (!accounts.splTokenProgram.value) {
    accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getBurnNftInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getBurnNftInstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.owner, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(accounts.mint, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.tokenAccount, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.masterEditionAccount,
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(
        accounts.splTokenProgram ?? "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.collectionMetadata, AccountRole.WRITABLE),
      ...remainingAccounts ?? []
    ].filter((x) => x !== void 0),
    data: getBurnNftInstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseBurnNftInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 6;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0)
      return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      owner: getNextAccount(),
      mint: getNextAccount(),
      tokenAccount: getNextAccount(),
      masterEditionAccount: getNextAccount(),
      splTokenProgram: getNextAccount(),
      collectionMetadata: getNextOptionalAccount()
    },
    data: getBurnNftInstructionDataDecoder().decode(instruction.data)
  };
}
function getBurnV1InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["burnV1Discriminator", getU8Encoder()],
      ["amount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: 41,
      burnV1Discriminator: 0,
      amount: value.amount ?? 1
    })
  );
}
function getBurnV1InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["burnV1Discriminator", getU8Decoder()],
    ["amount", getU64Decoder()]
  ]);
}
function getBurnV1InstructionDataCodec() {
  return combineCodec(
    getBurnV1InstructionDataEncoder(),
    getBurnV1InstructionDataDecoder()
  );
}
async function getBurnV1InstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    authority: { value: input.authority ?? null, isWritable: true },
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: true
    },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    token: { value: input.token ?? null, isWritable: true },
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    masterEditionMint: {
      value: input.masterEditionMint ?? null,
      isWritable: false
    },
    masterEditionToken: {
      value: input.masterEditionToken ?? null,
      isWritable: false
    },
    editionMarker: { value: input.editionMarker ?? null, isWritable: true },
    tokenRecord: { value: input.tokenRecord ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    }
  };
  const args = { ...input };
  if (!accounts.metadata.value) {
    accounts.metadata.value = await findMetadataPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.masterEdition.value) {
    if (accounts.masterEditionMint.value) {
      accounts.masterEdition.value = await findMasterEditionPda({
        mint: expectAddress(accounts.masterEditionMint.value)
      });
    }
  }
  if (!accounts.tokenRecord.value) {
    if (args.tokenStandard === 4 /* ProgrammableNonFungible */) {
      accounts.tokenRecord.value = await findTokenRecordPda({
        mint: expectAddress(accounts.mint.value),
        token: expectAddress(accounts.token.value)
      });
    }
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.splTokenProgram.value) {
    accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getBurnV1InstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getBurnV1Instruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    authority: { value: input.authority ?? null, isWritable: true },
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: true
    },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    token: { value: input.token ?? null, isWritable: true },
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    masterEditionMint: {
      value: input.masterEditionMint ?? null,
      isWritable: false
    },
    masterEditionToken: {
      value: input.masterEditionToken ?? null,
      isWritable: false
    },
    editionMarker: { value: input.editionMarker ?? null, isWritable: true },
    tokenRecord: { value: input.tokenRecord ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    }
  };
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.splTokenProgram.value) {
    accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getBurnV1InstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getBurnV1InstructionRaw(accounts, args, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.authority, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(
        accounts.collectionMetadata ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.edition ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(accounts.mint, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.token, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.masterEdition ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(
        accounts.masterEditionMint ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.masterEditionToken ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.editionMarker ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(
        accounts.tokenRecord ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.sysvarInstructions ?? "Sysvar1nstructions1111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.splTokenProgram ?? "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA",
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ],
    data: getBurnV1InstructionDataEncoder().encode(args),
    programAddress
  };
}
function parseBurnV1Instruction(instruction) {
  if (instruction.accounts.length < 14) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s" ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      authority: getNextAccount(),
      collectionMetadata: getNextOptionalAccount(),
      metadata: getNextAccount(),
      edition: getNextOptionalAccount(),
      mint: getNextAccount(),
      token: getNextAccount(),
      masterEdition: getNextOptionalAccount(),
      masterEditionMint: getNextOptionalAccount(),
      masterEditionToken: getNextOptionalAccount(),
      editionMarker: getNextOptionalAccount(),
      tokenRecord: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      splTokenProgram: getNextAccount()
    },
    data: getBurnV1InstructionDataDecoder().decode(instruction.data)
  };
}
function getCloseEscrowAccountInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 39 })
  );
}
function getCloseEscrowAccountInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getCloseEscrowAccountInstructionDataCodec() {
  return combineCodec(
    getCloseEscrowAccountInstructionDataEncoder(),
    getCloseEscrowAccountInstructionDataDecoder()
  );
}
async function getCloseEscrowAccountInstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    escrow: { value: input.escrow ?? null, isWritable: true },
    metadata: { value: input.metadata ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    tokenAccount: { value: input.tokenAccount ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    }
  };
  if (!accounts.metadata.value) {
    accounts.metadata.value = await findMetadataPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.edition.value) {
    accounts.edition.value = await findMasterEditionPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getCloseEscrowAccountInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getCloseEscrowAccountInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    escrow: { value: input.escrow ?? null, isWritable: true },
    metadata: { value: input.metadata ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    tokenAccount: { value: input.tokenAccount ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    }
  };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getCloseEscrowAccountInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getCloseEscrowAccountInstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.escrow, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.mint, AccountRole.READONLY),
      accountMetaWithDefault(accounts.tokenAccount, AccountRole.READONLY),
      accountMetaWithDefault(accounts.edition, AccountRole.READONLY),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.sysvarInstructions ?? "Sysvar1nstructions1111111111111111111111111",
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ],
    data: getCloseEscrowAccountInstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseCloseEscrowAccountInstruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      escrow: getNextAccount(),
      metadata: getNextAccount(),
      mint: getNextAccount(),
      tokenAccount: getNextAccount(),
      edition: getNextAccount(),
      payer: getNextAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount()
    },
    data: getCloseEscrowAccountInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCollectInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 54 })
  );
}
function getCollectInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getCollectInstructionDataCodec() {
  return combineCodec(
    getCollectInstructionDataEncoder(),
    getCollectInstructionDataDecoder()
  );
}
function getCollectInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    authority: { value: input.authority ?? null, isWritable: false },
    recipient: { value: input.recipient ?? null, isWritable: false }
  };
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getCollectInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getCollectInstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.authority, AccountRole.READONLY_SIGNER),
      accountMetaWithDefault(accounts.recipient, AccountRole.READONLY),
      ...remainingAccounts ?? []
    ],
    data: getCollectInstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseCollectInstruction(instruction) {
  if (instruction.accounts.length < 2) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      authority: getNextAccount(),
      recipient: getNextAccount()
    },
    data: getCollectInstructionDataDecoder().decode(instruction.data)
  };
}
function getConvertMasterEditionV1ToV2InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 12 })
  );
}
function getConvertMasterEditionV1ToV2InstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getConvertMasterEditionV1ToV2InstructionDataCodec() {
  return combineCodec(
    getConvertMasterEditionV1ToV2InstructionDataEncoder(),
    getConvertMasterEditionV1ToV2InstructionDataDecoder()
  );
}
function getConvertMasterEditionV1ToV2Instruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    oneTimeAuth: { value: input.oneTimeAuth ?? null, isWritable: true },
    printingMint: { value: input.printingMint ?? null, isWritable: true }
  };
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getConvertMasterEditionV1ToV2InstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getConvertMasterEditionV1ToV2InstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.masterEdition, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.oneTimeAuth, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.printingMint, AccountRole.WRITABLE),
      ...remainingAccounts ?? []
    ],
    data: getConvertMasterEditionV1ToV2InstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseConvertMasterEditionV1ToV2Instruction(instruction) {
  if (instruction.accounts.length < 3) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      masterEdition: getNextAccount(),
      oneTimeAuth: getNextAccount(),
      printingMint: getNextAccount()
    },
    data: getConvertMasterEditionV1ToV2InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCreateEscrowAccountInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 38 })
  );
}
function getCreateEscrowAccountInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getCreateEscrowAccountInstructionDataCodec() {
  return combineCodec(
    getCreateEscrowAccountInstructionDataEncoder(),
    getCreateEscrowAccountInstructionDataDecoder()
  );
}
async function getCreateEscrowAccountInstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    escrow: { value: input.escrow ?? null, isWritable: true },
    metadata: { value: input.metadata ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    tokenAccount: { value: input.tokenAccount ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authority: { value: input.authority ?? null, isWritable: false }
  };
  if (!accounts.metadata.value) {
    accounts.metadata.value = await findMetadataPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.edition.value) {
    accounts.edition.value = await findMasterEditionPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getCreateEscrowAccountInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getCreateEscrowAccountInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    escrow: { value: input.escrow ?? null, isWritable: true },
    metadata: { value: input.metadata ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    tokenAccount: { value: input.tokenAccount ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authority: { value: input.authority ?? null, isWritable: false }
  };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getCreateEscrowAccountInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getCreateEscrowAccountInstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.escrow, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.mint, AccountRole.READONLY),
      accountMetaWithDefault(accounts.tokenAccount, AccountRole.READONLY),
      accountMetaWithDefault(accounts.edition, AccountRole.READONLY),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.sysvarInstructions ?? "Sysvar1nstructions1111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.authority, AccountRole.READONLY_SIGNER),
      ...remainingAccounts ?? []
    ].filter((x) => x !== void 0),
    data: getCreateEscrowAccountInstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseCreateEscrowAccountInstruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 8;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0)
      return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      escrow: getNextAccount(),
      metadata: getNextAccount(),
      mint: getNextAccount(),
      tokenAccount: getNextAccount(),
      edition: getNextAccount(),
      payer: getNextAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      authority: getNextOptionalAccount()
    },
    data: getCreateEscrowAccountInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCreateMasterEditionV3InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["maxSupply", getOptionEncoder(getU64Encoder())]
    ]),
    (value) => ({ ...value, discriminator: 17 })
  );
}
function getCreateMasterEditionV3InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["maxSupply", getOptionDecoder(getU64Decoder())]
  ]);
}
function getCreateMasterEditionV3InstructionDataCodec() {
  return combineCodec(
    getCreateMasterEditionV3InstructionDataEncoder(),
    getCreateMasterEditionV3InstructionDataDecoder()
  );
}
async function getCreateMasterEditionV3InstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    edition: { value: input.edition ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    mintAuthority: { value: input.mintAuthority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    metadata: { value: input.metadata ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  const args = { ...input };
  if (!accounts.edition.value) {
    accounts.edition.value = await findMasterEditionPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.metadata.value) {
    accounts.metadata.value = await findMetadataPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getCreateMasterEditionV3InstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getCreateMasterEditionV3Instruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    edition: { value: input.edition ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    mintAuthority: { value: input.mintAuthority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    metadata: { value: input.metadata ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getCreateMasterEditionV3InstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getCreateMasterEditionV3InstructionRaw(accounts, args, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.edition, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.mint, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.updateAuthority,
        AccountRole.READONLY_SIGNER
      ),
      accountMetaWithDefault(
        accounts.mintAuthority,
        AccountRole.READONLY_SIGNER
      ),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.tokenProgram ?? "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.rent, AccountRole.READONLY),
      ...remainingAccounts ?? []
    ].filter((x) => x !== void 0),
    data: getCreateMasterEditionV3InstructionDataEncoder().encode(args),
    programAddress
  };
}
function parseCreateMasterEditionV3Instruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 8;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0)
      return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      edition: getNextAccount(),
      mint: getNextAccount(),
      updateAuthority: getNextAccount(),
      mintAuthority: getNextAccount(),
      payer: getNextAccount(),
      metadata: getNextAccount(),
      tokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextOptionalAccount()
    },
    data: getCreateMasterEditionV3InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCreateMetadataAccountV3InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["data", getDataV2Encoder()],
      ["isMutable", getBooleanEncoder()],
      ["collectionDetails", getOptionEncoder(getCollectionDetailsEncoder())]
    ]),
    (value) => ({ ...value, discriminator: 33 })
  );
}
function getCreateMetadataAccountV3InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["data", getDataV2Decoder()],
    ["isMutable", getBooleanDecoder()],
    ["collectionDetails", getOptionDecoder(getCollectionDetailsDecoder())]
  ]);
}
function getCreateMetadataAccountV3InstructionDataCodec() {
  return combineCodec(
    getCreateMetadataAccountV3InstructionDataEncoder(),
    getCreateMetadataAccountV3InstructionDataDecoder()
  );
}
async function getCreateMetadataAccountV3InstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    mintAuthority: { value: input.mintAuthority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  const args = { ...input };
  if (!accounts.metadata.value) {
    accounts.metadata.value = await findMetadataPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getCreateMetadataAccountV3InstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getCreateMetadataAccountV3Instruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    mintAuthority: { value: input.mintAuthority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getCreateMetadataAccountV3InstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getCreateMetadataAccountV3InstructionRaw(accounts, args, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.mint, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.mintAuthority,
        AccountRole.READONLY_SIGNER
      ),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(accounts.updateAuthority, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.rent, AccountRole.READONLY),
      ...remainingAccounts ?? []
    ].filter((x) => x !== void 0),
    data: getCreateMetadataAccountV3InstructionDataEncoder().encode(args),
    programAddress
  };
}
function parseCreateMetadataAccountV3Instruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 6;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0)
      return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      mint: getNextAccount(),
      mintAuthority: getNextAccount(),
      payer: getNextAccount(),
      updateAuthority: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextOptionalAccount()
    },
    data: getCreateMetadataAccountV3InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCreateV1InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["createV1Discriminator", getU8Encoder()],
      ["name", getStringEncoder()],
      ["symbol", getStringEncoder()],
      ["uri", getStringEncoder()],
      ["sellerFeeBasisPoints", getU16Encoder()],
      ["creators", getOptionEncoder(getArrayEncoder(getCreatorEncoder()))],
      ["primarySaleHappened", getBooleanEncoder()],
      ["isMutable", getBooleanEncoder()],
      ["tokenStandard", getTokenStandardEncoder()],
      ["collection", getOptionEncoder(getCollectionEncoder())],
      ["uses", getOptionEncoder(getUsesEncoder())],
      ["collectionDetails", getOptionEncoder(getCollectionDetailsEncoder())],
      ["ruleSet", getOptionEncoder(getAddressEncoder())],
      ["decimals", getOptionEncoder(getU8Encoder())],
      ["printSupply", getOptionEncoder(getPrintSupplyEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: 42,
      createV1Discriminator: 0,
      symbol: value.symbol ?? "",
      primarySaleHappened: value.primarySaleHappened ?? false,
      isMutable: value.isMutable ?? true,
      tokenStandard: value.tokenStandard ?? 0 /* NonFungible */,
      collection: value.collection ?? none(),
      uses: value.uses ?? none(),
      collectionDetails: value.collectionDetails ?? none(),
      ruleSet: value.ruleSet ?? none(),
      decimals: value.decimals ?? none(),
      printSupply: value.printSupply ?? none()
    })
  );
}
function getCreateV1InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["createV1Discriminator", getU8Decoder()],
    ["name", getStringDecoder()],
    ["symbol", getStringDecoder()],
    ["uri", getStringDecoder()],
    ["sellerFeeBasisPoints", getU16Decoder()],
    ["creators", getOptionDecoder(getArrayDecoder(getCreatorDecoder()))],
    ["primarySaleHappened", getBooleanDecoder()],
    ["isMutable", getBooleanDecoder()],
    ["tokenStandard", getTokenStandardDecoder()],
    ["collection", getOptionDecoder(getCollectionDecoder())],
    ["uses", getOptionDecoder(getUsesDecoder())],
    ["collectionDetails", getOptionDecoder(getCollectionDetailsDecoder())],
    ["ruleSet", getOptionDecoder(getAddressDecoder())],
    ["decimals", getOptionDecoder(getU8Decoder())],
    ["printSupply", getOptionDecoder(getPrintSupplyDecoder())]
  ]);
}
function getCreateV1InstructionDataCodec() {
  return combineCodec(
    getCreateV1InstructionDataEncoder(),
    getCreateV1InstructionDataDecoder()
  );
}
async function getCreateV1InstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    }
  };
  const args = { ...input };
  if (!accounts.metadata.value) {
    accounts.metadata.value = await findMetadataPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.updateAuthority.value) {
    accounts.updateAuthority.value = expectSome(accounts.authority.value);
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!args.isCollection) {
    args.isCollection = false;
  }
  const byteDelta = [1427].reduce((a, b) => a + b, 0);
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getCreateV1InstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return Object.freeze({ ...instruction, byteDelta });
}
function getCreateV1Instruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    }
  };
  const args = { ...input };
  if (!accounts.updateAuthority.value) {
    accounts.updateAuthority.value = expectSome(accounts.authority.value);
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!args.isCollection) {
    args.isCollection = false;
  }
  const byteDelta = [1427].reduce((a, b) => a + b, 0);
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getCreateV1InstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return Object.freeze({ ...instruction, byteDelta });
}
function getCreateV1InstructionRaw(accounts, args, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.masterEdition ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(accounts.mint, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.authority, AccountRole.READONLY_SIGNER),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(accounts.updateAuthority, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.sysvarInstructions ?? "Sysvar1nstructions1111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.splTokenProgram ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ],
    data: getCreateV1InstructionDataEncoder().encode(args),
    programAddress
  };
}
function parseCreateV1Instruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s" ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      masterEdition: getNextOptionalAccount(),
      mint: getNextAccount(),
      authority: getNextAccount(),
      payer: getNextAccount(),
      updateAuthority: getNextAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      splTokenProgram: getNextOptionalAccount()
    },
    data: getCreateV1InstructionDataDecoder().decode(instruction.data)
  };
}
function getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 3 })
  );
}
function getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataCodec() {
  return combineCodec(
    getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataEncoder(),
    getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataDecoder()
  );
}
async function getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: true },
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    mintAuthority: { value: input.mintAuthority ?? null, isWritable: false },
    printingMint: { value: input.printingMint ?? null, isWritable: true },
    masterTokenAccount: {
      value: input.masterTokenAccount ?? null,
      isWritable: true
    },
    editionMarker: { value: input.editionMarker ?? null, isWritable: true },
    burnAuthority: { value: input.burnAuthority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: false },
    masterUpdateAuthority: {
      value: input.masterUpdateAuthority ?? null,
      isWritable: false
    },
    masterMetadata: { value: input.masterMetadata ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false },
    reservationList: { value: input.reservationList ?? null, isWritable: true }
  };
  if (!accounts.metadata.value) {
    accounts.metadata.value = await findMetadataPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.edition.value) {
    accounts.edition.value = await findMasterEditionPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.masterEdition.value) {
    accounts.masterEdition.value = await findMasterEditionPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.editionMarker.value) {
    accounts.editionMarker.value = await findMasterEditionPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: true },
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    mintAuthority: { value: input.mintAuthority ?? null, isWritable: false },
    printingMint: { value: input.printingMint ?? null, isWritable: true },
    masterTokenAccount: {
      value: input.masterTokenAccount ?? null,
      isWritable: true
    },
    editionMarker: { value: input.editionMarker ?? null, isWritable: true },
    burnAuthority: { value: input.burnAuthority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: false },
    masterUpdateAuthority: {
      value: input.masterUpdateAuthority ?? null,
      isWritable: false
    },
    masterMetadata: { value: input.masterMetadata ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false },
    reservationList: { value: input.reservationList ?? null, isWritable: true }
  };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.edition, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.masterEdition, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.mint, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.mintAuthority,
        AccountRole.READONLY_SIGNER
      ),
      accountMetaWithDefault(accounts.printingMint, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.masterTokenAccount, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.editionMarker, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.burnAuthority,
        AccountRole.READONLY_SIGNER
      ),
      accountMetaWithDefault(accounts.payer, AccountRole.READONLY_SIGNER),
      accountMetaWithDefault(
        accounts.masterUpdateAuthority,
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.masterMetadata, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.tokenProgram ?? "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.rent ?? "SysvarRent111111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.reservationList, AccountRole.WRITABLE),
      ...remainingAccounts ?? []
    ].filter((x) => x !== void 0),
    data: getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataEncoder().encode(
      {}
    ),
    programAddress
  };
}
function parseDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstruction(instruction) {
  if (instruction.accounts.length < 15) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 15;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0)
      return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      edition: getNextAccount(),
      masterEdition: getNextAccount(),
      mint: getNextAccount(),
      mintAuthority: getNextAccount(),
      printingMint: getNextAccount(),
      masterTokenAccount: getNextAccount(),
      editionMarker: getNextAccount(),
      burnAuthority: getNextAccount(),
      payer: getNextAccount(),
      masterUpdateAuthority: getNextAccount(),
      masterMetadata: getNextAccount(),
      tokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextAccount(),
      reservationList: getNextOptionalAccount()
    },
    data: getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getFreezeDelegatedAccountInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 26 })
  );
}
function getFreezeDelegatedAccountInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getFreezeDelegatedAccountInstructionDataCodec() {
  return combineCodec(
    getFreezeDelegatedAccountInstructionDataEncoder(),
    getFreezeDelegatedAccountInstructionDataDecoder()
  );
}
async function getFreezeDelegatedAccountInstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    delegate: { value: input.delegate ?? null, isWritable: true },
    tokenAccount: { value: input.tokenAccount ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  if (!accounts.edition.value) {
    accounts.edition.value = await findMasterEditionPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getFreezeDelegatedAccountInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getFreezeDelegatedAccountInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    delegate: { value: input.delegate ?? null, isWritable: true },
    tokenAccount: { value: input.tokenAccount ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getFreezeDelegatedAccountInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getFreezeDelegatedAccountInstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.delegate, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(accounts.tokenAccount, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.edition, AccountRole.READONLY),
      accountMetaWithDefault(accounts.mint, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.tokenProgram ?? "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA",
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ],
    data: getFreezeDelegatedAccountInstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseFreezeDelegatedAccountInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      delegate: getNextAccount(),
      tokenAccount: getNextAccount(),
      edition: getNextAccount(),
      mint: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getFreezeDelegatedAccountInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getLockV1InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["lockV1Discriminator", getU8Encoder()],
      ["authorizationData", getOptionEncoder(getAuthorizationDataEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: 46,
      lockV1Discriminator: 0,
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getLockV1InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["lockV1Discriminator", getU8Decoder()],
    ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
  ]);
}
function getLockV1InstructionDataCodec() {
  return combineCodec(
    getLockV1InstructionDataEncoder(),
    getLockV1InstructionDataDecoder()
  );
}
async function getLockV1InstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    authority: { value: input.authority ?? null, isWritable: false },
    tokenOwner: { value: input.tokenOwner ?? null, isWritable: false },
    token: { value: input.token ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    tokenRecord: { value: input.tokenRecord ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    }
  };
  const args = { ...input };
  if (!accounts.metadata.value) {
    accounts.metadata.value = await findMetadataPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.tokenRecord.value) {
    if (args.tokenStandard === 4 /* ProgrammableNonFungible */) {
      accounts.tokenRecord.value = await findTokenRecordPda({
        mint: expectAddress(accounts.mint.value),
        token: expectAddress(accounts.token.value)
      });
    }
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.splTokenProgram.value) {
    if (args.tokenStandard !== 4 /* ProgrammableNonFungible */) {
      accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
    }
  }
  if (!accounts.authorizationRulesProgram.value) {
    if (accounts.authorizationRules.value) {
      accounts.authorizationRulesProgram.value = "auth9SigNpDKz4sJJ1DfCTuZrZNSAgh9sFD3rboVmgg";
    }
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getLockV1InstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getLockV1Instruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    authority: { value: input.authority ?? null, isWritable: false },
    tokenOwner: { value: input.tokenOwner ?? null, isWritable: false },
    token: { value: input.token ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    tokenRecord: { value: input.tokenRecord ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    }
  };
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.splTokenProgram.value) {
    if (args.tokenStandard !== 4 /* ProgrammableNonFungible */) {
      accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
    }
  }
  if (!accounts.authorizationRulesProgram.value) {
    if (accounts.authorizationRules.value) {
      accounts.authorizationRulesProgram.value = "auth9SigNpDKz4sJJ1DfCTuZrZNSAgh9sFD3rboVmgg";
    }
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getLockV1InstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getLockV1InstructionRaw(accounts, args, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.authority, AccountRole.READONLY_SIGNER),
      accountMetaWithDefault(
        accounts.tokenOwner ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.token, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.mint, AccountRole.READONLY),
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.edition ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.tokenRecord ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.sysvarInstructions ?? "Sysvar1nstructions1111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.splTokenProgram ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.authorizationRulesProgram ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.authorizationRules ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ],
    data: getLockV1InstructionDataEncoder().encode(args),
    programAddress
  };
}
function parseLockV1Instruction(instruction) {
  if (instruction.accounts.length < 13) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s" ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      authority: getNextAccount(),
      tokenOwner: getNextOptionalAccount(),
      token: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextOptionalAccount(),
      tokenRecord: getNextOptionalAccount(),
      payer: getNextAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      splTokenProgram: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount()
    },
    data: getLockV1InstructionDataDecoder().decode(instruction.data)
  };
}
function getMigrateInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 48 })
  );
}
function getMigrateInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getMigrateInstructionDataCodec() {
  return combineCodec(
    getMigrateInstructionDataEncoder(),
    getMigrateInstructionDataDecoder()
  );
}
async function getMigrateInstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: true },
    token: { value: input.token ?? null, isWritable: true },
    tokenOwner: { value: input.tokenOwner ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: false
    },
    delegateRecord: { value: input.delegateRecord ?? null, isWritable: false },
    tokenRecord: { value: input.tokenRecord ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    }
  };
  if (!accounts.metadata.value) {
    accounts.metadata.value = await findMetadataPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.edition.value) {
    accounts.edition.value = await findMasterEditionPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.tokenRecord.value) {
    accounts.tokenRecord.value = await findTokenRecordPda({
      mint: expectAddress(accounts.mint.value),
      token: expectAddress(accounts.token.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.splTokenProgram.value) {
    accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.authorizationRulesProgram.value) {
    if (accounts.authorizationRules.value) {
      accounts.authorizationRulesProgram.value = "auth9SigNpDKz4sJJ1DfCTuZrZNSAgh9sFD3rboVmgg";
    }
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getMigrateInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getMigrateInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: true },
    token: { value: input.token ?? null, isWritable: true },
    tokenOwner: { value: input.tokenOwner ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: false
    },
    delegateRecord: { value: input.delegateRecord ?? null, isWritable: false },
    tokenRecord: { value: input.tokenRecord ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    }
  };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.splTokenProgram.value) {
    accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.authorizationRulesProgram.value) {
    if (accounts.authorizationRules.value) {
      accounts.authorizationRulesProgram.value = "auth9SigNpDKz4sJJ1DfCTuZrZNSAgh9sFD3rboVmgg";
    }
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getMigrateInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getMigrateInstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.edition, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.token, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.tokenOwner, AccountRole.READONLY),
      accountMetaWithDefault(accounts.mint, AccountRole.READONLY),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(accounts.authority, AccountRole.READONLY_SIGNER),
      accountMetaWithDefault(accounts.collectionMetadata, AccountRole.READONLY),
      accountMetaWithDefault(accounts.delegateRecord, AccountRole.READONLY),
      accountMetaWithDefault(accounts.tokenRecord, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.sysvarInstructions ?? "Sysvar1nstructions1111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.splTokenProgram ?? "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.authorizationRulesProgram ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.authorizationRules ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ],
    data: getMigrateInstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseMigrateInstruction(instruction) {
  if (instruction.accounts.length < 15) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s" ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      edition: getNextAccount(),
      token: getNextAccount(),
      tokenOwner: getNextAccount(),
      mint: getNextAccount(),
      payer: getNextAccount(),
      authority: getNextAccount(),
      collectionMetadata: getNextAccount(),
      delegateRecord: getNextAccount(),
      tokenRecord: getNextAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      splTokenProgram: getNextAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount()
    },
    data: getMigrateInstructionDataDecoder().decode(instruction.data)
  };
}
function getMintNewEditionFromMasterEditionViaTokenInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      [
        "mintNewEditionFromMasterEditionViaTokenArgs",
        getMintNewEditionFromMasterEditionViaTokenArgsEncoder()
      ]
    ]),
    (value) => ({ ...value, discriminator: 11 })
  );
}
function getMintNewEditionFromMasterEditionViaTokenInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    [
      "mintNewEditionFromMasterEditionViaTokenArgs",
      getMintNewEditionFromMasterEditionViaTokenArgsDecoder()
    ]
  ]);
}
function getMintNewEditionFromMasterEditionViaTokenInstructionDataCodec() {
  return combineCodec(
    getMintNewEditionFromMasterEditionViaTokenInstructionDataEncoder(),
    getMintNewEditionFromMasterEditionViaTokenInstructionDataDecoder()
  );
}
function getMintNewEditionFromMasterEditionViaTokenInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    newMetadata: { value: input.newMetadata ?? null, isWritable: true },
    newEdition: { value: input.newEdition ?? null, isWritable: true },
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    newMint: { value: input.newMint ?? null, isWritable: true },
    editionMarkPda: { value: input.editionMarkPda ?? null, isWritable: true },
    newMintAuthority: {
      value: input.newMintAuthority ?? null,
      isWritable: false
    },
    payer: { value: input.payer ?? null, isWritable: true },
    tokenAccountOwner: {
      value: input.tokenAccountOwner ?? null,
      isWritable: false
    },
    tokenAccount: { value: input.tokenAccount ?? null, isWritable: false },
    newMetadataUpdateAuthority: {
      value: input.newMetadataUpdateAuthority ?? null,
      isWritable: false
    },
    metadata: { value: input.metadata ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getMintNewEditionFromMasterEditionViaTokenInstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getMintNewEditionFromMasterEditionViaTokenInstructionRaw(accounts, args, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.newMetadata, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.newEdition, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.masterEdition, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.newMint, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.editionMarkPda, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.newMintAuthority,
        AccountRole.READONLY_SIGNER
      ),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(
        accounts.tokenAccountOwner,
        AccountRole.READONLY_SIGNER
      ),
      accountMetaWithDefault(accounts.tokenAccount, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.newMetadataUpdateAuthority,
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.metadata, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.tokenProgram ?? "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.rent, AccountRole.READONLY),
      ...remainingAccounts ?? []
    ].filter((x) => x !== void 0),
    data: getMintNewEditionFromMasterEditionViaTokenInstructionDataEncoder().encode(
      args
    ),
    programAddress
  };
}
function parseMintNewEditionFromMasterEditionViaTokenInstruction(instruction) {
  if (instruction.accounts.length < 13) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 13;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0)
      return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      newMetadata: getNextAccount(),
      newEdition: getNextAccount(),
      masterEdition: getNextAccount(),
      newMint: getNextAccount(),
      editionMarkPda: getNextAccount(),
      newMintAuthority: getNextAccount(),
      payer: getNextAccount(),
      tokenAccountOwner: getNextAccount(),
      tokenAccount: getNextAccount(),
      newMetadataUpdateAuthority: getNextAccount(),
      metadata: getNextAccount(),
      tokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextOptionalAccount()
    },
    data: getMintNewEditionFromMasterEditionViaTokenInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      [
        "mintNewEditionFromMasterEditionViaTokenArgs",
        getMintNewEditionFromMasterEditionViaTokenArgsEncoder()
      ]
    ]),
    (value) => ({ ...value, discriminator: 13 })
  );
}
function getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    [
      "mintNewEditionFromMasterEditionViaTokenArgs",
      getMintNewEditionFromMasterEditionViaTokenArgsDecoder()
    ]
  ]);
}
function getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataCodec() {
  return combineCodec(
    getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataEncoder(),
    getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataDecoder()
  );
}
function getMintNewEditionFromMasterEditionViaVaultProxyInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    newMetadata: { value: input.newMetadata ?? null, isWritable: true },
    newEdition: { value: input.newEdition ?? null, isWritable: true },
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    newMint: { value: input.newMint ?? null, isWritable: true },
    editionMarkPda: { value: input.editionMarkPda ?? null, isWritable: true },
    newMintAuthority: {
      value: input.newMintAuthority ?? null,
      isWritable: false
    },
    payer: { value: input.payer ?? null, isWritable: true },
    vaultAuthority: { value: input.vaultAuthority ?? null, isWritable: false },
    safetyDepositStore: {
      value: input.safetyDepositStore ?? null,
      isWritable: false
    },
    safetyDepositBox: {
      value: input.safetyDepositBox ?? null,
      isWritable: false
    },
    vault: { value: input.vault ?? null, isWritable: false },
    newMetadataUpdateAuthority: {
      value: input.newMetadataUpdateAuthority ?? null,
      isWritable: false
    },
    metadata: { value: input.metadata ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    tokenVaultProgram: {
      value: input.tokenVaultProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getMintNewEditionFromMasterEditionViaVaultProxyInstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getMintNewEditionFromMasterEditionViaVaultProxyInstructionRaw(accounts, args, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.newMetadata, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.newEdition, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.masterEdition, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.newMint, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.editionMarkPda, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.newMintAuthority,
        AccountRole.READONLY_SIGNER
      ),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(
        accounts.vaultAuthority,
        AccountRole.READONLY_SIGNER
      ),
      accountMetaWithDefault(accounts.safetyDepositStore, AccountRole.READONLY),
      accountMetaWithDefault(accounts.safetyDepositBox, AccountRole.READONLY),
      accountMetaWithDefault(accounts.vault, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.newMetadataUpdateAuthority,
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.metadata, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.tokenProgram ?? "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.tokenVaultProgram, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.rent, AccountRole.READONLY),
      ...remainingAccounts ?? []
    ].filter((x) => x !== void 0),
    data: getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataEncoder().encode(
      args
    ),
    programAddress
  };
}
function parseMintNewEditionFromMasterEditionViaVaultProxyInstruction(instruction) {
  if (instruction.accounts.length < 16) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 16;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0)
      return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      newMetadata: getNextAccount(),
      newEdition: getNextAccount(),
      masterEdition: getNextAccount(),
      newMint: getNextAccount(),
      editionMarkPda: getNextAccount(),
      newMintAuthority: getNextAccount(),
      payer: getNextAccount(),
      vaultAuthority: getNextAccount(),
      safetyDepositStore: getNextAccount(),
      safetyDepositBox: getNextAccount(),
      vault: getNextAccount(),
      newMetadataUpdateAuthority: getNextAccount(),
      metadata: getNextAccount(),
      tokenProgram: getNextAccount(),
      tokenVaultProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextOptionalAccount()
    },
    data: getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getMintV1InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["mintV1Discriminator", getU8Encoder()],
      ["amount", getU64Encoder()],
      ["authorizationData", getOptionEncoder(getAuthorizationDataEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: 43,
      mintV1Discriminator: 0,
      amount: value.amount ?? 1,
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getMintV1InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["mintV1Discriminator", getU8Decoder()],
    ["amount", getU64Decoder()],
    ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
  ]);
}
function getMintV1InstructionDataCodec() {
  return combineCodec(
    getMintV1InstructionDataEncoder(),
    getMintV1InstructionDataDecoder()
  );
}
async function getMintV1InstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    token: { value: input.token ?? null, isWritable: true },
    tokenOwner: { value: input.tokenOwner ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: false },
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    tokenRecord: { value: input.tokenRecord ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    delegateRecord: { value: input.delegateRecord ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    splAtaProgram: { value: input.splAtaProgram ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    }
  };
  const args = { ...input };
  if (!accounts.metadata.value) {
    accounts.metadata.value = await findMetadataPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.tokenRecord.value) {
    if (args.tokenStandard === 4 /* ProgrammableNonFungible */) {
      accounts.tokenRecord.value = await findTokenRecordPda({
        mint: expectAddress(accounts.mint.value),
        token: expectAddress(accounts.token.value)
      });
    }
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.splTokenProgram.value) {
    accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.splAtaProgram.value) {
    accounts.splAtaProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.authorizationRulesProgram.value) {
    if (accounts.authorizationRules.value) {
      accounts.authorizationRulesProgram.value = "auth9SigNpDKz4sJJ1DfCTuZrZNSAgh9sFD3rboVmgg";
    }
  }
  const byteDelta = [468].reduce((a, b) => a + b, 0);
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getMintV1InstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return Object.freeze({ ...instruction, byteDelta });
}
function getMintV1Instruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    token: { value: input.token ?? null, isWritable: true },
    tokenOwner: { value: input.tokenOwner ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: false },
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    tokenRecord: { value: input.tokenRecord ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    delegateRecord: { value: input.delegateRecord ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    splAtaProgram: { value: input.splAtaProgram ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    }
  };
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.splTokenProgram.value) {
    accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.splAtaProgram.value) {
    accounts.splAtaProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.authorizationRulesProgram.value) {
    if (accounts.authorizationRules.value) {
      accounts.authorizationRulesProgram.value = "auth9SigNpDKz4sJJ1DfCTuZrZNSAgh9sFD3rboVmgg";
    }
  }
  const byteDelta = [468].reduce((a, b) => a + b, 0);
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getMintV1InstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return Object.freeze({ ...instruction, byteDelta });
}
function getMintV1InstructionRaw(accounts, args, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.token, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.tokenOwner ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.metadata, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.masterEdition ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(
        accounts.tokenRecord ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(accounts.mint, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.authority, AccountRole.READONLY_SIGNER),
      accountMetaWithDefault(
        accounts.delegateRecord ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.sysvarInstructions ?? "Sysvar1nstructions1111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.splTokenProgram ?? "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.splAtaProgram ?? "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.authorizationRulesProgram ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.authorizationRules ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ],
    data: getMintV1InstructionDataEncoder().encode(args),
    programAddress
  };
}
function parseMintV1Instruction(instruction) {
  if (instruction.accounts.length < 15) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s" ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      token: getNextAccount(),
      tokenOwner: getNextOptionalAccount(),
      metadata: getNextAccount(),
      masterEdition: getNextOptionalAccount(),
      tokenRecord: getNextOptionalAccount(),
      mint: getNextAccount(),
      authority: getNextAccount(),
      delegateRecord: getNextOptionalAccount(),
      payer: getNextAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      splTokenProgram: getNextAccount(),
      splAtaProgram: getNextAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount()
    },
    data: getMintV1InstructionDataDecoder().decode(instruction.data)
  };
}
function getPrintV1InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["printV1Discriminator", getU8Encoder()],
      ["editionNumber", getU64Encoder()]
    ]),
    (value) => ({ ...value, discriminator: 55, printV1Discriminator: 0 })
  );
}
function getPrintV1InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["printV1Discriminator", getU8Decoder()],
    ["editionNumber", getU64Decoder()]
  ]);
}
function getPrintV1InstructionDataCodec() {
  return combineCodec(
    getPrintV1InstructionDataEncoder(),
    getPrintV1InstructionDataDecoder()
  );
}
async function getPrintV1InstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    editionMetadata: { value: input.editionMetadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: true },
    editionMint: { value: input.editionMint ?? null, isWritable: true },
    editionTokenAccountOwner: {
      value: input.editionTokenAccountOwner ?? null,
      isWritable: false
    },
    editionTokenAccount: {
      value: input.editionTokenAccount ?? null,
      isWritable: true
    },
    editionMintAuthority: {
      value: input.editionMintAuthority ?? null,
      isWritable: false
    },
    editionTokenRecord: {
      value: input.editionTokenRecord ?? null,
      isWritable: true
    },
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    editionMarkerPda: {
      value: input.editionMarkerPda ?? null,
      isWritable: true
    },
    payer: { value: input.payer ?? null, isWritable: true },
    masterTokenAccountOwner: {
      value: input.masterTokenAccountOwner ?? null,
      isWritable: false
    },
    masterTokenAccount: {
      value: input.masterTokenAccount ?? null,
      isWritable: false
    },
    masterMetadata: { value: input.masterMetadata ?? null, isWritable: false },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    splAtaProgram: { value: input.splAtaProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const args = { ...input };
  if (!accounts.editionMetadata.value) {
    accounts.editionMetadata.value = await findMetadataPda({
      mint: expectAddress(accounts.editionMint.value)
    });
  }
  if (!accounts.edition.value) {
    accounts.edition.value = await findMasterEditionPda({
      mint: expectAddress(accounts.editionMint.value)
    });
  }
  if (!accounts.editionMintAuthority.value) {
    accounts.editionMintAuthority.value = expectSome(
      accounts.masterTokenAccountOwner.value
    );
  }
  if (!accounts.editionTokenRecord.value) {
    if (args.tokenStandard === 4 /* ProgrammableNonFungible */) {
      accounts.editionTokenRecord.value = await findTokenRecordPda({
        mint: expectAddress(accounts.editionMint.value),
        token: expectAddress(accounts.editionTokenAccount.value)
      });
    }
  }
  if (!accounts.masterEdition.value) {
    accounts.masterEdition.value = await findMasterEditionPda({
      mint: expectSome(args.masterEditionMint)
    });
  }
  if (!accounts.masterMetadata.value) {
    accounts.masterMetadata.value = await findMetadataPda({
      mint: expectSome(args.masterEditionMint)
    });
  }
  if (!accounts.splTokenProgram.value) {
    accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.splAtaProgram.value) {
    accounts.splAtaProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getPrintV1InstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getPrintV1Instruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    editionMetadata: { value: input.editionMetadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: true },
    editionMint: { value: input.editionMint ?? null, isWritable: true },
    editionTokenAccountOwner: {
      value: input.editionTokenAccountOwner ?? null,
      isWritable: false
    },
    editionTokenAccount: {
      value: input.editionTokenAccount ?? null,
      isWritable: true
    },
    editionMintAuthority: {
      value: input.editionMintAuthority ?? null,
      isWritable: false
    },
    editionTokenRecord: {
      value: input.editionTokenRecord ?? null,
      isWritable: true
    },
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    editionMarkerPda: {
      value: input.editionMarkerPda ?? null,
      isWritable: true
    },
    payer: { value: input.payer ?? null, isWritable: true },
    masterTokenAccountOwner: {
      value: input.masterTokenAccountOwner ?? null,
      isWritable: false
    },
    masterTokenAccount: {
      value: input.masterTokenAccount ?? null,
      isWritable: false
    },
    masterMetadata: { value: input.masterMetadata ?? null, isWritable: false },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    splAtaProgram: { value: input.splAtaProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const args = { ...input };
  if (!accounts.editionMintAuthority.value) {
    accounts.editionMintAuthority.value = expectSome(
      accounts.masterTokenAccountOwner.value
    );
  }
  if (!accounts.splTokenProgram.value) {
    accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.splAtaProgram.value) {
    accounts.splAtaProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getPrintV1InstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getPrintV1InstructionRaw(accounts, args, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.editionMetadata, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.edition, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.editionMint, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.editionTokenAccountOwner,
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.editionTokenAccount,
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(
        accounts.editionMintAuthority,
        AccountRole.READONLY_SIGNER
      ),
      accountMetaWithDefault(
        accounts.editionTokenRecord ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(accounts.masterEdition, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.editionMarkerPda, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(
        accounts.masterTokenAccountOwner,
        AccountRole.READONLY_SIGNER
      ),
      accountMetaWithDefault(accounts.masterTokenAccount, AccountRole.READONLY),
      accountMetaWithDefault(accounts.masterMetadata, AccountRole.READONLY),
      accountMetaWithDefault(accounts.updateAuthority, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.splTokenProgram ?? "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.splAtaProgram ?? "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.sysvarInstructions ?? "Sysvar1nstructions1111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ],
    data: getPrintV1InstructionDataEncoder().encode(args),
    programAddress
  };
}
function parsePrintV1Instruction(instruction) {
  if (instruction.accounts.length < 18) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s" ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      editionMetadata: getNextAccount(),
      edition: getNextAccount(),
      editionMint: getNextAccount(),
      editionTokenAccountOwner: getNextAccount(),
      editionTokenAccount: getNextAccount(),
      editionMintAuthority: getNextAccount(),
      editionTokenRecord: getNextOptionalAccount(),
      masterEdition: getNextAccount(),
      editionMarkerPda: getNextAccount(),
      payer: getNextAccount(),
      masterTokenAccountOwner: getNextAccount(),
      masterTokenAccount: getNextAccount(),
      masterMetadata: getNextAccount(),
      updateAuthority: getNextAccount(),
      splTokenProgram: getNextAccount(),
      splAtaProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getPrintV1InstructionDataDecoder().decode(instruction.data)
  };
}
function getPuffMetadataInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 14 })
  );
}
function getPuffMetadataInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getPuffMetadataInstructionDataCodec() {
  return combineCodec(
    getPuffMetadataInstructionDataEncoder(),
    getPuffMetadataInstructionDataDecoder()
  );
}
function getPuffMetadataInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true }
  };
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getPuffMetadataInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getPuffMetadataInstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      ...remainingAccounts ?? []
    ],
    data: getPuffMetadataInstructionDataEncoder().encode({}),
    programAddress
  };
}
function parsePuffMetadataInstruction(instruction) {
  if (instruction.accounts.length < 1) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount()
    },
    data: getPuffMetadataInstructionDataDecoder().decode(instruction.data)
  };
}
function getRemoveCreatorVerificationInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 28 })
  );
}
function getRemoveCreatorVerificationInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getRemoveCreatorVerificationInstructionDataCodec() {
  return combineCodec(
    getRemoveCreatorVerificationInstructionDataEncoder(),
    getRemoveCreatorVerificationInstructionDataDecoder()
  );
}
function getRemoveCreatorVerificationInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    creator: { value: input.creator ?? null, isWritable: false }
  };
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getRemoveCreatorVerificationInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getRemoveCreatorVerificationInstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.creator, AccountRole.READONLY_SIGNER),
      ...remainingAccounts ?? []
    ],
    data: getRemoveCreatorVerificationInstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseRemoveCreatorVerificationInstruction(instruction) {
  if (instruction.accounts.length < 2) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      creator: getNextAccount()
    },
    data: getRemoveCreatorVerificationInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getSetAndVerifyCollectionInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 25 })
  );
}
function getSetAndVerifyCollectionInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getSetAndVerifyCollectionInstructionDataCodec() {
  return combineCodec(
    getSetAndVerifyCollectionInstructionDataEncoder(),
    getSetAndVerifyCollectionInstructionDataDecoder()
  );
}
function getSetAndVerifyCollectionInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    collectionAuthority: {
      value: input.collectionAuthority ?? null,
      isWritable: true
    },
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collection: { value: input.collection ?? null, isWritable: false },
    collectionMasterEditionAccount: {
      value: input.collectionMasterEditionAccount ?? null,
      isWritable: false
    },
    collectionAuthorityRecord: {
      value: input.collectionAuthorityRecord ?? null,
      isWritable: false
    }
  };
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getSetAndVerifyCollectionInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getSetAndVerifyCollectionInstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.collectionAuthority,
        AccountRole.WRITABLE_SIGNER
      ),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(accounts.updateAuthority, AccountRole.READONLY),
      accountMetaWithDefault(accounts.collectionMint, AccountRole.READONLY),
      accountMetaWithDefault(accounts.collection, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.collectionMasterEditionAccount,
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.collectionAuthorityRecord,
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ].filter((x) => x !== void 0),
    data: getSetAndVerifyCollectionInstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseSetAndVerifyCollectionInstruction(instruction) {
  if (instruction.accounts.length < 7) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 7;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0)
      return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      collectionAuthority: getNextAccount(),
      payer: getNextAccount(),
      updateAuthority: getNextAccount(),
      collectionMint: getNextAccount(),
      collection: getNextAccount(),
      collectionMasterEditionAccount: getNextAccount(),
      collectionAuthorityRecord: getNextOptionalAccount()
    },
    data: getSetAndVerifyCollectionInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getSetAndVerifySizedCollectionItemInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 32 })
  );
}
function getSetAndVerifySizedCollectionItemInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getSetAndVerifySizedCollectionItemInstructionDataCodec() {
  return combineCodec(
    getSetAndVerifySizedCollectionItemInstructionDataEncoder(),
    getSetAndVerifySizedCollectionItemInstructionDataDecoder()
  );
}
function getSetAndVerifySizedCollectionItemInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    collectionAuthority: {
      value: input.collectionAuthority ?? null,
      isWritable: false
    },
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collection: { value: input.collection ?? null, isWritable: true },
    collectionMasterEditionAccount: {
      value: input.collectionMasterEditionAccount ?? null,
      isWritable: false
    },
    collectionAuthorityRecord: {
      value: input.collectionAuthorityRecord ?? null,
      isWritable: false
    }
  };
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getSetAndVerifySizedCollectionItemInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getSetAndVerifySizedCollectionItemInstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.collectionAuthority,
        AccountRole.READONLY_SIGNER
      ),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(accounts.updateAuthority, AccountRole.READONLY),
      accountMetaWithDefault(accounts.collectionMint, AccountRole.READONLY),
      accountMetaWithDefault(accounts.collection, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.collectionMasterEditionAccount,
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.collectionAuthorityRecord,
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ].filter((x) => x !== void 0),
    data: getSetAndVerifySizedCollectionItemInstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseSetAndVerifySizedCollectionItemInstruction(instruction) {
  if (instruction.accounts.length < 7) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 7;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0)
      return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      collectionAuthority: getNextAccount(),
      payer: getNextAccount(),
      updateAuthority: getNextAccount(),
      collectionMint: getNextAccount(),
      collection: getNextAccount(),
      collectionMasterEditionAccount: getNextAccount(),
      collectionAuthorityRecord: getNextOptionalAccount()
    },
    data: getSetAndVerifySizedCollectionItemInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getSetCollectionSizeInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["setCollectionSizeArgs", getSetCollectionSizeArgsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 34 })
  );
}
function getSetCollectionSizeInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["setCollectionSizeArgs", getSetCollectionSizeArgsDecoder()]
  ]);
}
function getSetCollectionSizeInstructionDataCodec() {
  return combineCodec(
    getSetCollectionSizeInstructionDataEncoder(),
    getSetCollectionSizeInstructionDataDecoder()
  );
}
function getSetCollectionSizeInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: true
    },
    collectionAuthority: {
      value: input.collectionAuthority ?? null,
      isWritable: true
    },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collectionAuthorityRecord: {
      value: input.collectionAuthorityRecord ?? null,
      isWritable: false
    }
  };
  const args = { ...input };
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getSetCollectionSizeInstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getSetCollectionSizeInstructionRaw(accounts, args, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.collectionMetadata, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.collectionAuthority,
        AccountRole.WRITABLE_SIGNER
      ),
      accountMetaWithDefault(accounts.collectionMint, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.collectionAuthorityRecord,
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ].filter((x) => x !== void 0),
    data: getSetCollectionSizeInstructionDataEncoder().encode(args),
    programAddress
  };
}
function parseSetCollectionSizeInstruction(instruction) {
  if (instruction.accounts.length < 3) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 3;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0)
      return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      collectionMetadata: getNextAccount(),
      collectionAuthority: getNextAccount(),
      collectionMint: getNextAccount(),
      collectionAuthorityRecord: getNextOptionalAccount()
    },
    data: getSetCollectionSizeInstructionDataDecoder().decode(instruction.data)
  };
}
function getSetTokenStandardInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 35 })
  );
}
function getSetTokenStandardInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getSetTokenStandardInstructionDataCodec() {
  return combineCodec(
    getSetTokenStandardInstructionDataEncoder(),
    getSetTokenStandardInstructionDataDecoder()
  );
}
async function getSetTokenStandardInstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    mint: { value: input.mint ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false }
  };
  if (!accounts.metadata.value) {
    accounts.metadata.value = await findMetadataPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getSetTokenStandardInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getSetTokenStandardInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    mint: { value: input.mint ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false }
  };
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getSetTokenStandardInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getSetTokenStandardInstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.updateAuthority,
        AccountRole.READONLY_SIGNER
      ),
      accountMetaWithDefault(accounts.mint, AccountRole.READONLY),
      accountMetaWithDefault(accounts.edition, AccountRole.READONLY),
      ...remainingAccounts ?? []
    ].filter((x) => x !== void 0),
    data: getSetTokenStandardInstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseSetTokenStandardInstruction(instruction) {
  if (instruction.accounts.length < 3) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 3;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0)
      return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      updateAuthority: getNextAccount(),
      mint: getNextAccount(),
      edition: getNextOptionalAccount()
    },
    data: getSetTokenStandardInstructionDataDecoder().decode(instruction.data)
  };
}
function getSignMetadataInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 7 })
  );
}
function getSignMetadataInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getSignMetadataInstructionDataCodec() {
  return combineCodec(
    getSignMetadataInstructionDataEncoder(),
    getSignMetadataInstructionDataDecoder()
  );
}
function getSignMetadataInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    creator: { value: input.creator ?? null, isWritable: false }
  };
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getSignMetadataInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getSignMetadataInstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.creator, AccountRole.READONLY_SIGNER),
      ...remainingAccounts ?? []
    ],
    data: getSignMetadataInstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseSignMetadataInstruction(instruction) {
  if (instruction.accounts.length < 2) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      creator: getNextAccount()
    },
    data: getSignMetadataInstructionDataDecoder().decode(instruction.data)
  };
}
function getThawDelegatedAccountInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 27 })
  );
}
function getThawDelegatedAccountInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getThawDelegatedAccountInstructionDataCodec() {
  return combineCodec(
    getThawDelegatedAccountInstructionDataEncoder(),
    getThawDelegatedAccountInstructionDataDecoder()
  );
}
async function getThawDelegatedAccountInstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    delegate: { value: input.delegate ?? null, isWritable: true },
    tokenAccount: { value: input.tokenAccount ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  if (!accounts.edition.value) {
    accounts.edition.value = await findMasterEditionPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getThawDelegatedAccountInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getThawDelegatedAccountInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    delegate: { value: input.delegate ?? null, isWritable: true },
    tokenAccount: { value: input.tokenAccount ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getThawDelegatedAccountInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getThawDelegatedAccountInstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.delegate, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(accounts.tokenAccount, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.edition, AccountRole.READONLY),
      accountMetaWithDefault(accounts.mint, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.tokenProgram ?? "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA",
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ],
    data: getThawDelegatedAccountInstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseThawDelegatedAccountInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      delegate: getNextAccount(),
      tokenAccount: getNextAccount(),
      edition: getNextAccount(),
      mint: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getThawDelegatedAccountInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTransferOutOfEscrowInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["amount", getU64Encoder()]
    ]),
    (value) => ({ ...value, discriminator: 40, amount: value.amount ?? 1 })
  );
}
function getTransferOutOfEscrowInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["amount", getU64Decoder()]
  ]);
}
function getTransferOutOfEscrowInstructionDataCodec() {
  return combineCodec(
    getTransferOutOfEscrowInstructionDataEncoder(),
    getTransferOutOfEscrowInstructionDataDecoder()
  );
}
function getTransferOutOfEscrowInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    escrow: { value: input.escrow ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    attributeMint: { value: input.attributeMint ?? null, isWritable: false },
    attributeSrc: { value: input.attributeSrc ?? null, isWritable: true },
    attributeDst: { value: input.attributeDst ?? null, isWritable: true },
    escrowMint: { value: input.escrowMint ?? null, isWritable: false },
    escrowAccount: { value: input.escrowAccount ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    ataProgram: { value: input.ataProgram ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authority: { value: input.authority ?? null, isWritable: false }
  };
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.ataProgram.value) {
    accounts.ataProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getTransferOutOfEscrowInstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getTransferOutOfEscrowInstructionRaw(accounts, args, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.escrow, AccountRole.READONLY),
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(accounts.attributeMint, AccountRole.READONLY),
      accountMetaWithDefault(accounts.attributeSrc, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.attributeDst, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.escrowMint, AccountRole.READONLY),
      accountMetaWithDefault(accounts.escrowAccount, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.ataProgram ?? "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.tokenProgram ?? "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.sysvarInstructions ?? "Sysvar1nstructions1111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.authority, AccountRole.READONLY_SIGNER),
      ...remainingAccounts ?? []
    ].filter((x) => x !== void 0),
    data: getTransferOutOfEscrowInstructionDataEncoder().encode(args),
    programAddress
  };
}
function parseTransferOutOfEscrowInstruction(instruction) {
  if (instruction.accounts.length < 12) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 12;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0)
      return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      escrow: getNextAccount(),
      metadata: getNextAccount(),
      payer: getNextAccount(),
      attributeMint: getNextAccount(),
      attributeSrc: getNextAccount(),
      attributeDst: getNextAccount(),
      escrowMint: getNextAccount(),
      escrowAccount: getNextAccount(),
      systemProgram: getNextAccount(),
      ataProgram: getNextAccount(),
      tokenProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      authority: getNextOptionalAccount()
    },
    data: getTransferOutOfEscrowInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTransferV1InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["transferV1Discriminator", getU8Encoder()],
      ["amount", getU64Encoder()],
      ["authorizationData", getOptionEncoder(getAuthorizationDataEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: 49,
      transferV1Discriminator: 0,
      amount: value.amount ?? 1,
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getTransferV1InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["transferV1Discriminator", getU8Decoder()],
    ["amount", getU64Decoder()],
    ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
  ]);
}
function getTransferV1InstructionDataCodec() {
  return combineCodec(
    getTransferV1InstructionDataEncoder(),
    getTransferV1InstructionDataDecoder()
  );
}
async function getTransferV1InstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    token: { value: input.token ?? null, isWritable: true },
    tokenOwner: { value: input.tokenOwner ?? null, isWritable: false },
    destinationToken: {
      value: input.destinationToken ?? null,
      isWritable: true
    },
    destinationOwner: {
      value: input.destinationOwner ?? null,
      isWritable: false
    },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    tokenRecord: { value: input.tokenRecord ?? null, isWritable: true },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    authority: { value: input.authority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    splAtaProgram: { value: input.splAtaProgram ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    }
  };
  const args = { ...input };
  if (!accounts.metadata.value) {
    accounts.metadata.value = await findMetadataPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.edition.value) {
    if (args.tokenStandard === 4 /* ProgrammableNonFungible */) {
      accounts.edition.value = await findMasterEditionPda({
        mint: expectAddress(accounts.mint.value)
      });
    }
  }
  if (!accounts.tokenRecord.value) {
    if (args.tokenStandard === 4 /* ProgrammableNonFungible */) {
      accounts.tokenRecord.value = await findTokenRecordPda({
        mint: expectAddress(accounts.mint.value),
        token: expectAddress(accounts.token.value)
      });
    }
  }
  if (!accounts.destinationTokenRecord.value) {
    if (args.tokenStandard === 4 /* ProgrammableNonFungible */) {
      accounts.destinationTokenRecord.value = await findTokenRecordPda({
        token: expectAddress(accounts.destinationToken.value),
        mint: expectAddress(accounts.mint.value)
      });
    }
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.splTokenProgram.value) {
    accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.splAtaProgram.value) {
    accounts.splAtaProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.authorizationRulesProgram.value) {
    if (accounts.authorizationRules.value) {
      accounts.authorizationRulesProgram.value = "auth9SigNpDKz4sJJ1DfCTuZrZNSAgh9sFD3rboVmgg";
    }
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getTransferV1InstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getTransferV1Instruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    token: { value: input.token ?? null, isWritable: true },
    tokenOwner: { value: input.tokenOwner ?? null, isWritable: false },
    destinationToken: {
      value: input.destinationToken ?? null,
      isWritable: true
    },
    destinationOwner: {
      value: input.destinationOwner ?? null,
      isWritable: false
    },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    tokenRecord: { value: input.tokenRecord ?? null, isWritable: true },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    authority: { value: input.authority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    splAtaProgram: { value: input.splAtaProgram ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    }
  };
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.splTokenProgram.value) {
    accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.splAtaProgram.value) {
    accounts.splAtaProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.authorizationRulesProgram.value) {
    if (accounts.authorizationRules.value) {
      accounts.authorizationRulesProgram.value = "auth9SigNpDKz4sJJ1DfCTuZrZNSAgh9sFD3rboVmgg";
    }
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getTransferV1InstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getTransferV1InstructionRaw(accounts, args, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.token, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.tokenOwner, AccountRole.READONLY),
      accountMetaWithDefault(accounts.destinationToken, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.destinationOwner, AccountRole.READONLY),
      accountMetaWithDefault(accounts.mint, AccountRole.READONLY),
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.edition ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.tokenRecord ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(
        accounts.destinationTokenRecord ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(accounts.authority, AccountRole.READONLY_SIGNER),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.sysvarInstructions ?? "Sysvar1nstructions1111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.splTokenProgram ?? "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.splAtaProgram ?? "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.authorizationRulesProgram ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.authorizationRules ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ],
    data: getTransferV1InstructionDataEncoder().encode(args),
    programAddress
  };
}
function parseTransferV1Instruction(instruction) {
  if (instruction.accounts.length < 17) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s" ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      token: getNextAccount(),
      tokenOwner: getNextAccount(),
      destinationToken: getNextAccount(),
      destinationOwner: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextOptionalAccount(),
      tokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      authority: getNextAccount(),
      payer: getNextAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      splTokenProgram: getNextAccount(),
      splAtaProgram: getNextAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount()
    },
    data: getTransferV1InstructionDataDecoder().decode(instruction.data)
  };
}
function getUnlockV1InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["unlockV1Discriminator", getU8Encoder()],
      ["authorizationData", getOptionEncoder(getAuthorizationDataEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: 47,
      unlockV1Discriminator: 0,
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getUnlockV1InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["unlockV1Discriminator", getU8Decoder()],
    ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
  ]);
}
function getUnlockV1InstructionDataCodec() {
  return combineCodec(
    getUnlockV1InstructionDataEncoder(),
    getUnlockV1InstructionDataDecoder()
  );
}
async function getUnlockV1InstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    authority: { value: input.authority ?? null, isWritable: false },
    tokenOwner: { value: input.tokenOwner ?? null, isWritable: false },
    token: { value: input.token ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    tokenRecord: { value: input.tokenRecord ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    }
  };
  const args = { ...input };
  if (!accounts.metadata.value) {
    accounts.metadata.value = await findMetadataPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.tokenRecord.value) {
    if (args.tokenStandard === 4 /* ProgrammableNonFungible */) {
      accounts.tokenRecord.value = await findTokenRecordPda({
        mint: expectAddress(accounts.mint.value),
        token: expectAddress(accounts.token.value)
      });
    }
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.splTokenProgram.value) {
    if (args.tokenStandard !== 4 /* ProgrammableNonFungible */) {
      accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
    }
  }
  if (!accounts.authorizationRulesProgram.value) {
    if (accounts.authorizationRules.value) {
      accounts.authorizationRulesProgram.value = "auth9SigNpDKz4sJJ1DfCTuZrZNSAgh9sFD3rboVmgg";
    }
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getUnlockV1InstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getUnlockV1Instruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    authority: { value: input.authority ?? null, isWritable: false },
    tokenOwner: { value: input.tokenOwner ?? null, isWritable: false },
    token: { value: input.token ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    tokenRecord: { value: input.tokenRecord ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    }
  };
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.splTokenProgram.value) {
    if (args.tokenStandard !== 4 /* ProgrammableNonFungible */) {
      accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
    }
  }
  if (!accounts.authorizationRulesProgram.value) {
    if (accounts.authorizationRules.value) {
      accounts.authorizationRulesProgram.value = "auth9SigNpDKz4sJJ1DfCTuZrZNSAgh9sFD3rboVmgg";
    }
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getUnlockV1InstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getUnlockV1InstructionRaw(accounts, args, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.authority, AccountRole.READONLY_SIGNER),
      accountMetaWithDefault(
        accounts.tokenOwner ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.token, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.mint, AccountRole.READONLY),
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.edition ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.tokenRecord ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.sysvarInstructions ?? "Sysvar1nstructions1111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.splTokenProgram ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.authorizationRulesProgram ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.authorizationRules ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ],
    data: getUnlockV1InstructionDataEncoder().encode(args),
    programAddress
  };
}
function parseUnlockV1Instruction(instruction) {
  if (instruction.accounts.length < 13) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s" ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      authority: getNextAccount(),
      tokenOwner: getNextOptionalAccount(),
      token: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextOptionalAccount(),
      tokenRecord: getNextOptionalAccount(),
      payer: getNextAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      splTokenProgram: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount()
    },
    data: getUnlockV1InstructionDataDecoder().decode(instruction.data)
  };
}
function getUnverifyCollectionInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 22 })
  );
}
function getUnverifyCollectionInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getUnverifyCollectionInstructionDataCodec() {
  return combineCodec(
    getUnverifyCollectionInstructionDataEncoder(),
    getUnverifyCollectionInstructionDataDecoder()
  );
}
function getUnverifyCollectionInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    collectionAuthority: {
      value: input.collectionAuthority ?? null,
      isWritable: true
    },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collection: { value: input.collection ?? null, isWritable: false },
    collectionMasterEditionAccount: {
      value: input.collectionMasterEditionAccount ?? null,
      isWritable: false
    },
    collectionAuthorityRecord: {
      value: input.collectionAuthorityRecord ?? null,
      isWritable: false
    }
  };
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getUnverifyCollectionInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getUnverifyCollectionInstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.collectionAuthority,
        AccountRole.WRITABLE_SIGNER
      ),
      accountMetaWithDefault(accounts.collectionMint, AccountRole.READONLY),
      accountMetaWithDefault(accounts.collection, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.collectionMasterEditionAccount,
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.collectionAuthorityRecord,
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ].filter((x) => x !== void 0),
    data: getUnverifyCollectionInstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseUnverifyCollectionInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 5;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0)
      return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      collectionAuthority: getNextAccount(),
      collectionMint: getNextAccount(),
      collection: getNextAccount(),
      collectionMasterEditionAccount: getNextAccount(),
      collectionAuthorityRecord: getNextOptionalAccount()
    },
    data: getUnverifyCollectionInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getUnverifyCollectionV1InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["unverifyCollectionV1Discriminator", getU8Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: 53,
      unverifyCollectionV1Discriminator: 1
    })
  );
}
function getUnverifyCollectionV1InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["unverifyCollectionV1Discriminator", getU8Decoder()]
  ]);
}
function getUnverifyCollectionV1InstructionDataCodec() {
  return combineCodec(
    getUnverifyCollectionV1InstructionDataEncoder(),
    getUnverifyCollectionV1InstructionDataDecoder()
  );
}
async function getUnverifyCollectionV1InstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    authority: { value: input.authority ?? null, isWritable: false },
    delegateRecord: { value: input.delegateRecord ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: true
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    }
  };
  if (!accounts.collectionMetadata.value) {
    accounts.collectionMetadata.value = await findMetadataPda({
      mint: expectAddress(accounts.collectionMint.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getUnverifyCollectionV1InstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getUnverifyCollectionV1Instruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    authority: { value: input.authority ?? null, isWritable: false },
    delegateRecord: { value: input.delegateRecord ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: true
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    }
  };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getUnverifyCollectionV1InstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getUnverifyCollectionV1InstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.authority, AccountRole.READONLY_SIGNER),
      accountMetaWithDefault(
        accounts.delegateRecord ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.collectionMint, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.collectionMetadata ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.sysvarInstructions ?? "Sysvar1nstructions1111111111111111111111111",
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ],
    data: getUnverifyCollectionV1InstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseUnverifyCollectionV1Instruction(instruction) {
  if (instruction.accounts.length < 7) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s" ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      authority: getNextAccount(),
      delegateRecord: getNextOptionalAccount(),
      metadata: getNextAccount(),
      collectionMint: getNextAccount(),
      collectionMetadata: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount()
    },
    data: getUnverifyCollectionV1InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getUnverifyCreatorV1InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["unverifyCreatorV1Discriminator", getU8Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: 53,
      unverifyCreatorV1Discriminator: 0
    })
  );
}
function getUnverifyCreatorV1InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["unverifyCreatorV1Discriminator", getU8Decoder()]
  ]);
}
function getUnverifyCreatorV1InstructionDataCodec() {
  return combineCodec(
    getUnverifyCreatorV1InstructionDataEncoder(),
    getUnverifyCreatorV1InstructionDataDecoder()
  );
}
function getUnverifyCreatorV1Instruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    authority: { value: input.authority ?? null, isWritable: false },
    delegateRecord: { value: input.delegateRecord ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: true
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    }
  };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getUnverifyCreatorV1InstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getUnverifyCreatorV1InstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.authority, AccountRole.READONLY_SIGNER),
      accountMetaWithDefault(
        accounts.delegateRecord ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.collectionMint ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.collectionMetadata ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.sysvarInstructions ?? "Sysvar1nstructions1111111111111111111111111",
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ],
    data: getUnverifyCreatorV1InstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseUnverifyCreatorV1Instruction(instruction) {
  if (instruction.accounts.length < 7) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s" ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      authority: getNextAccount(),
      delegateRecord: getNextOptionalAccount(),
      metadata: getNextAccount(),
      collectionMint: getNextOptionalAccount(),
      collectionMetadata: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount()
    },
    data: getUnverifyCreatorV1InstructionDataDecoder().decode(instruction.data)
  };
}
function getUnverifySizedCollectionItemInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 31 })
  );
}
function getUnverifySizedCollectionItemInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getUnverifySizedCollectionItemInstructionDataCodec() {
  return combineCodec(
    getUnverifySizedCollectionItemInstructionDataEncoder(),
    getUnverifySizedCollectionItemInstructionDataDecoder()
  );
}
function getUnverifySizedCollectionItemInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    collectionAuthority: {
      value: input.collectionAuthority ?? null,
      isWritable: false
    },
    payer: { value: input.payer ?? null, isWritable: true },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collection: { value: input.collection ?? null, isWritable: true },
    collectionMasterEditionAccount: {
      value: input.collectionMasterEditionAccount ?? null,
      isWritable: false
    },
    collectionAuthorityRecord: {
      value: input.collectionAuthorityRecord ?? null,
      isWritable: false
    }
  };
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getUnverifySizedCollectionItemInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getUnverifySizedCollectionItemInstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.collectionAuthority,
        AccountRole.READONLY_SIGNER
      ),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(accounts.collectionMint, AccountRole.READONLY),
      accountMetaWithDefault(accounts.collection, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.collectionMasterEditionAccount,
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.collectionAuthorityRecord,
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ].filter((x) => x !== void 0),
    data: getUnverifySizedCollectionItemInstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseUnverifySizedCollectionItemInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 6;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0)
      return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      collectionAuthority: getNextAccount(),
      payer: getNextAccount(),
      collectionMint: getNextAccount(),
      collection: getNextAccount(),
      collectionMasterEditionAccount: getNextAccount(),
      collectionAuthorityRecord: getNextOptionalAccount()
    },
    data: getUnverifySizedCollectionItemInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getUseV1InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["useV1Discriminator", getU8Encoder()],
      ["authorizationData", getOptionEncoder(getAuthorizationDataEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: 51,
      useV1Discriminator: 0,
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getUseV1InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["useV1Discriminator", getU8Decoder()],
    ["authorizationData", getOptionDecoder(getAuthorizationDataDecoder())]
  ]);
}
function getUseV1InstructionDataCodec() {
  return combineCodec(
    getUseV1InstructionDataEncoder(),
    getUseV1InstructionDataDecoder()
  );
}
async function getUseV1InstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    authority: { value: input.authority ?? null, isWritable: false },
    delegateRecord: { value: input.delegateRecord ?? null, isWritable: true },
    token: { value: input.token ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    }
  };
  const args = { ...input };
  if (!accounts.metadata.value) {
    accounts.metadata.value = await findMetadataPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    if (accounts.authorizationRules.value) {
      accounts.authorizationRulesProgram.value = "auth9SigNpDKz4sJJ1DfCTuZrZNSAgh9sFD3rboVmgg";
    }
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getUseV1InstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getUseV1Instruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    authority: { value: input.authority ?? null, isWritable: false },
    delegateRecord: { value: input.delegateRecord ?? null, isWritable: true },
    token: { value: input.token ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    }
  };
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    if (accounts.authorizationRules.value) {
      accounts.authorizationRulesProgram.value = "auth9SigNpDKz4sJJ1DfCTuZrZNSAgh9sFD3rboVmgg";
    }
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getUseV1InstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getUseV1InstructionRaw(accounts, args, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.authority, AccountRole.READONLY_SIGNER),
      accountMetaWithDefault(
        accounts.delegateRecord ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(
        accounts.token ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(accounts.mint, AccountRole.READONLY),
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.edition ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(accounts.payer, AccountRole.READONLY_SIGNER),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.sysvarInstructions ?? "Sysvar1nstructions1111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.splTokenProgram ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.authorizationRulesProgram ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.authorizationRules ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ],
    data: getUseV1InstructionDataEncoder().encode(args),
    programAddress
  };
}
function parseUseV1Instruction(instruction) {
  if (instruction.accounts.length < 12) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s" ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      authority: getNextAccount(),
      delegateRecord: getNextOptionalAccount(),
      token: getNextOptionalAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextOptionalAccount(),
      payer: getNextAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      splTokenProgram: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount()
    },
    data: getUseV1InstructionDataDecoder().decode(instruction.data)
  };
}
function getUtilizeInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["numberOfUses", getU64Encoder()]
    ]),
    (value) => ({ ...value, discriminator: 19 })
  );
}
function getUtilizeInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["numberOfUses", getU64Decoder()]
  ]);
}
function getUtilizeInstructionDataCodec() {
  return combineCodec(
    getUtilizeInstructionDataEncoder(),
    getUtilizeInstructionDataDecoder()
  );
}
async function getUtilizeInstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    tokenAccount: { value: input.tokenAccount ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    useAuthority: { value: input.useAuthority ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    ataProgram: { value: input.ataProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false },
    useAuthorityRecord: {
      value: input.useAuthorityRecord ?? null,
      isWritable: true
    },
    burner: { value: input.burner ?? null, isWritable: false }
  };
  const args = { ...input };
  if (!accounts.metadata.value) {
    accounts.metadata.value = await findMetadataPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.ataProgram.value) {
    accounts.ataProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getUtilizeInstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getUtilizeInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    tokenAccount: { value: input.tokenAccount ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    useAuthority: { value: input.useAuthority ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    ataProgram: { value: input.ataProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false },
    useAuthorityRecord: {
      value: input.useAuthorityRecord ?? null,
      isWritable: true
    },
    burner: { value: input.burner ?? null, isWritable: false }
  };
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.ataProgram.value) {
    accounts.ataProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getUtilizeInstructionRaw(
    accountMetas,
    args,
    programAddress
  );
  return instruction;
}
function getUtilizeInstructionRaw(accounts, args, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.tokenAccount, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.mint, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.useAuthority,
        AccountRole.WRITABLE_SIGNER
      ),
      accountMetaWithDefault(accounts.owner, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.tokenProgram ?? "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.ataProgram ?? "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.rent ?? "SysvarRent111111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.useAuthorityRecord, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.burner, AccountRole.READONLY),
      ...remainingAccounts ?? []
    ].filter((x) => x !== void 0),
    data: getUtilizeInstructionDataEncoder().encode(args),
    programAddress
  };
}
function parseUtilizeInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 9;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0)
      return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      tokenAccount: getNextAccount(),
      mint: getNextAccount(),
      useAuthority: getNextAccount(),
      owner: getNextAccount(),
      tokenProgram: getNextAccount(),
      ataProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextAccount(),
      useAuthorityRecord: getNextOptionalAccount(),
      burner: getNextOptionalAccount()
    },
    data: getUtilizeInstructionDataDecoder().decode(instruction.data)
  };
}
function getVerifyCollectionInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 18 })
  );
}
function getVerifyCollectionInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getVerifyCollectionInstructionDataCodec() {
  return combineCodec(
    getVerifyCollectionInstructionDataEncoder(),
    getVerifyCollectionInstructionDataDecoder()
  );
}
function getVerifyCollectionInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    collectionAuthority: {
      value: input.collectionAuthority ?? null,
      isWritable: true
    },
    payer: { value: input.payer ?? null, isWritable: true },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collection: { value: input.collection ?? null, isWritable: false },
    collectionMasterEditionAccount: {
      value: input.collectionMasterEditionAccount ?? null,
      isWritable: false
    },
    collectionAuthorityRecord: {
      value: input.collectionAuthorityRecord ?? null,
      isWritable: false
    }
  };
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getVerifyCollectionInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getVerifyCollectionInstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.collectionAuthority,
        AccountRole.WRITABLE_SIGNER
      ),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(accounts.collectionMint, AccountRole.READONLY),
      accountMetaWithDefault(accounts.collection, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.collectionMasterEditionAccount,
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.collectionAuthorityRecord,
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ].filter((x) => x !== void 0),
    data: getVerifyCollectionInstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseVerifyCollectionInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 6;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0)
      return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      collectionAuthority: getNextAccount(),
      payer: getNextAccount(),
      collectionMint: getNextAccount(),
      collection: getNextAccount(),
      collectionMasterEditionAccount: getNextAccount(),
      collectionAuthorityRecord: getNextOptionalAccount()
    },
    data: getVerifyCollectionInstructionDataDecoder().decode(instruction.data)
  };
}
function getVerifyCollectionV1InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["verifyCollectionV1Discriminator", getU8Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: 52,
      verifyCollectionV1Discriminator: 1
    })
  );
}
function getVerifyCollectionV1InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["verifyCollectionV1Discriminator", getU8Decoder()]
  ]);
}
function getVerifyCollectionV1InstructionDataCodec() {
  return combineCodec(
    getVerifyCollectionV1InstructionDataEncoder(),
    getVerifyCollectionV1InstructionDataDecoder()
  );
}
async function getVerifyCollectionV1InstructionAsync(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    authority: { value: input.authority ?? null, isWritable: false },
    delegateRecord: { value: input.delegateRecord ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: true
    },
    collectionMasterEdition: {
      value: input.collectionMasterEdition ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    }
  };
  if (!accounts.collectionMetadata.value) {
    accounts.collectionMetadata.value = await findMetadataPda({
      mint: expectAddress(accounts.collectionMint.value)
    });
  }
  if (!accounts.collectionMasterEdition.value) {
    accounts.collectionMasterEdition.value = await findMasterEditionPda({
      mint: expectAddress(accounts.collectionMint.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getVerifyCollectionV1InstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getVerifyCollectionV1Instruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    authority: { value: input.authority ?? null, isWritable: false },
    delegateRecord: { value: input.delegateRecord ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: true
    },
    collectionMasterEdition: {
      value: input.collectionMasterEdition ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    }
  };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getVerifyCollectionV1InstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getVerifyCollectionV1InstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.authority, AccountRole.READONLY_SIGNER),
      accountMetaWithDefault(
        accounts.delegateRecord ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(accounts.collectionMint, AccountRole.READONLY),
      accountMetaWithDefault(
        accounts.collectionMetadata ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(
        accounts.collectionMasterEdition ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.sysvarInstructions ?? "Sysvar1nstructions1111111111111111111111111",
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ],
    data: getVerifyCollectionV1InstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseVerifyCollectionV1Instruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s" ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      authority: getNextAccount(),
      delegateRecord: getNextOptionalAccount(),
      metadata: getNextAccount(),
      collectionMint: getNextAccount(),
      collectionMetadata: getNextOptionalAccount(),
      collectionMasterEdition: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount()
    },
    data: getVerifyCollectionV1InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getVerifyCreatorV1InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["verifyCreatorV1Discriminator", getU8Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: 52,
      verifyCreatorV1Discriminator: 0
    })
  );
}
function getVerifyCreatorV1InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["verifyCreatorV1Discriminator", getU8Decoder()]
  ]);
}
function getVerifyCreatorV1InstructionDataCodec() {
  return combineCodec(
    getVerifyCreatorV1InstructionDataEncoder(),
    getVerifyCreatorV1InstructionDataDecoder()
  );
}
function getVerifyCreatorV1Instruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    authority: { value: input.authority ?? null, isWritable: false },
    delegateRecord: { value: input.delegateRecord ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: true
    },
    collectionMasterEdition: {
      value: input.collectionMasterEdition ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    }
  };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getVerifyCreatorV1InstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getVerifyCreatorV1InstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.authority, AccountRole.READONLY_SIGNER),
      accountMetaWithDefault(
        accounts.delegateRecord ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.collectionMint ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.collectionMetadata ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.WRITABLE
      ),
      accountMetaWithDefault(
        accounts.collectionMasterEdition ?? {
          address: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s",
          role: AccountRole.READONLY
        },
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.systemProgram ?? "11111111111111111111111111111111",
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.sysvarInstructions ?? "Sysvar1nstructions1111111111111111111111111",
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ],
    data: getVerifyCreatorV1InstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseVerifyCreatorV1Instruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s" ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      authority: getNextAccount(),
      delegateRecord: getNextOptionalAccount(),
      metadata: getNextAccount(),
      collectionMint: getNextOptionalAccount(),
      collectionMetadata: getNextOptionalAccount(),
      collectionMasterEdition: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount()
    },
    data: getVerifyCreatorV1InstructionDataDecoder().decode(instruction.data)
  };
}
function getVerifySizedCollectionItemInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 30 })
  );
}
function getVerifySizedCollectionItemInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getVerifySizedCollectionItemInstructionDataCodec() {
  return combineCodec(
    getVerifySizedCollectionItemInstructionDataEncoder(),
    getVerifySizedCollectionItemInstructionDataDecoder()
  );
}
function getVerifySizedCollectionItemInstruction(input) {
  const programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
  const accounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    collectionAuthority: {
      value: input.collectionAuthority ?? null,
      isWritable: false
    },
    payer: { value: input.payer ?? null, isWritable: true },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collection: { value: input.collection ?? null, isWritable: true },
    collectionMasterEditionAccount: {
      value: input.collectionMasterEditionAccount ?? null,
      isWritable: false
    },
    collectionAuthorityRecord: {
      value: input.collectionAuthorityRecord ?? null,
      isWritable: false
    }
  };
  const accountMetas = getAccountMetasWithSigners(
    accounts,
    "programId",
    programAddress
  );
  const instruction = getVerifySizedCollectionItemInstructionRaw(
    accountMetas,
    programAddress
  );
  return instruction;
}
function getVerifySizedCollectionItemInstructionRaw(accounts, programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s", remainingAccounts) {
  return {
    accounts: [
      accountMetaWithDefault(accounts.metadata, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.collectionAuthority,
        AccountRole.READONLY_SIGNER
      ),
      accountMetaWithDefault(accounts.payer, AccountRole.WRITABLE_SIGNER),
      accountMetaWithDefault(accounts.collectionMint, AccountRole.READONLY),
      accountMetaWithDefault(accounts.collection, AccountRole.WRITABLE),
      accountMetaWithDefault(
        accounts.collectionMasterEditionAccount,
        AccountRole.READONLY
      ),
      accountMetaWithDefault(
        accounts.collectionAuthorityRecord,
        AccountRole.READONLY
      ),
      ...remainingAccounts ?? []
    ].filter((x) => x !== void 0),
    data: getVerifySizedCollectionItemInstructionDataEncoder().encode({}),
    programAddress
  };
}
function parseVerifySizedCollectionItemInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 6;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0)
      return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      collectionAuthority: getNextAccount(),
      payer: getNextAccount(),
      collectionMint: getNextAccount(),
      collection: getNextAccount(),
      collectionMasterEditionAccount: getNextAccount(),
      collectionAuthorityRecord: getNextOptionalAccount()
    },
    data: getVerifySizedCollectionItemInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
var MPL_TOKEN_METADATA_PROGRAM_ADDRESS = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
function getMplTokenMetadataProgram() {
  return {
    name: "mplTokenMetadata",
    address: MPL_TOKEN_METADATA_PROGRAM_ADDRESS,
    getErrorFromCode(code, cause) {
      return getMplTokenMetadataProgramErrorFromCode(code, cause);
    }
  };
}
var MplTokenMetadataAccount = /* @__PURE__ */ ((MplTokenMetadataAccount2) => {
  MplTokenMetadataAccount2[MplTokenMetadataAccount2["CollectionAuthorityRecord"] = 0] = "CollectionAuthorityRecord";
  MplTokenMetadataAccount2[MplTokenMetadataAccount2["MetadataDelegateRecord"] = 1] = "MetadataDelegateRecord";
  MplTokenMetadataAccount2[MplTokenMetadataAccount2["Edition"] = 2] = "Edition";
  MplTokenMetadataAccount2[MplTokenMetadataAccount2["EditionMarker"] = 3] = "EditionMarker";
  MplTokenMetadataAccount2[MplTokenMetadataAccount2["EditionMarkerV2"] = 4] = "EditionMarkerV2";
  MplTokenMetadataAccount2[MplTokenMetadataAccount2["TokenOwnedEscrow"] = 5] = "TokenOwnedEscrow";
  MplTokenMetadataAccount2[MplTokenMetadataAccount2["MasterEdition"] = 6] = "MasterEdition";
  MplTokenMetadataAccount2[MplTokenMetadataAccount2["Metadata"] = 7] = "Metadata";
  MplTokenMetadataAccount2[MplTokenMetadataAccount2["TokenRecord"] = 8] = "TokenRecord";
  MplTokenMetadataAccount2[MplTokenMetadataAccount2["UseAuthorityRecord"] = 9] = "UseAuthorityRecord";
  return MplTokenMetadataAccount2;
})(MplTokenMetadataAccount || {});
function identifyMplTokenMetadataAccount(account) {
  const data = account instanceof Uint8Array ? account : account.data;
  if (memcmp(data, getKeyEncoder().encode(9 /* CollectionAuthorityRecord */), 0)) {
    return 0 /* CollectionAuthorityRecord */;
  }
  if (memcmp(data, getKeyEncoder().encode(1 /* EditionV1 */), 0)) {
    return 2 /* Edition */;
  }
  if (memcmp(data, getKeyEncoder().encode(7 /* EditionMarker */), 0)) {
    return 3 /* EditionMarker */;
  }
  if (memcmp(data, getKeyEncoder().encode(10 /* TokenOwnedEscrow */), 0)) {
    return 5 /* TokenOwnedEscrow */;
  }
  if (memcmp(data, getKeyEncoder().encode(6 /* MasterEditionV2 */), 0)) {
    return 6 /* MasterEdition */;
  }
  if (memcmp(data, getKeyEncoder().encode(4 /* MetadataV1 */), 0)) {
    return 7 /* Metadata */;
  }
  if (memcmp(data, getKeyEncoder().encode(11 /* TokenRecord */), 0)) {
    return 8 /* TokenRecord */;
  }
  if (memcmp(data, getKeyEncoder().encode(8 /* UseAuthorityRecord */), 0)) {
    return 9 /* UseAuthorityRecord */;
  }
  throw new Error(
    "The provided account could not be identified as a mplTokenMetadata account."
  );
}
var MplTokenMetadataInstruction = /* @__PURE__ */ ((MplTokenMetadataInstruction2) => {
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["DeprecatedMintNewEditionFromMasterEditionViaPrintingToken"] = 0] = "DeprecatedMintNewEditionFromMasterEditionViaPrintingToken";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["SignMetadata"] = 1] = "SignMetadata";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["MintNewEditionFromMasterEditionViaToken"] = 2] = "MintNewEditionFromMasterEditionViaToken";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["ConvertMasterEditionV1ToV2"] = 3] = "ConvertMasterEditionV1ToV2";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["MintNewEditionFromMasterEditionViaVaultProxy"] = 4] = "MintNewEditionFromMasterEditionViaVaultProxy";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["PuffMetadata"] = 5] = "PuffMetadata";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["CreateMasterEditionV3"] = 6] = "CreateMasterEditionV3";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["VerifyCollection"] = 7] = "VerifyCollection";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["Utilize"] = 8] = "Utilize";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["ApproveUseAuthority"] = 9] = "ApproveUseAuthority";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["UnverifyCollection"] = 10] = "UnverifyCollection";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["ApproveCollectionAuthority"] = 11] = "ApproveCollectionAuthority";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["SetAndVerifyCollection"] = 12] = "SetAndVerifyCollection";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["FreezeDelegatedAccount"] = 13] = "FreezeDelegatedAccount";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["ThawDelegatedAccount"] = 14] = "ThawDelegatedAccount";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["RemoveCreatorVerification"] = 15] = "RemoveCreatorVerification";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["BurnNft"] = 16] = "BurnNft";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["VerifySizedCollectionItem"] = 17] = "VerifySizedCollectionItem";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["UnverifySizedCollectionItem"] = 18] = "UnverifySizedCollectionItem";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["SetAndVerifySizedCollectionItem"] = 19] = "SetAndVerifySizedCollectionItem";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["CreateMetadataAccountV3"] = 20] = "CreateMetadataAccountV3";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["SetCollectionSize"] = 21] = "SetCollectionSize";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["SetTokenStandard"] = 22] = "SetTokenStandard";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["BubblegumSetCollectionSize"] = 23] = "BubblegumSetCollectionSize";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["BurnEditionNft"] = 24] = "BurnEditionNft";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["CreateEscrowAccount"] = 25] = "CreateEscrowAccount";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["CloseEscrowAccount"] = 26] = "CloseEscrowAccount";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["TransferOutOfEscrow"] = 27] = "TransferOutOfEscrow";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["BurnV1"] = 28] = "BurnV1";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["CreateV1"] = 29] = "CreateV1";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["MintV1"] = 30] = "MintV1";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["LockV1"] = 31] = "LockV1";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["UnlockV1"] = 32] = "UnlockV1";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["Migrate"] = 33] = "Migrate";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["TransferV1"] = 34] = "TransferV1";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["UseV1"] = 35] = "UseV1";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["VerifyCreatorV1"] = 36] = "VerifyCreatorV1";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["VerifyCollectionV1"] = 37] = "VerifyCollectionV1";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["UnverifyCreatorV1"] = 38] = "UnverifyCreatorV1";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["UnverifyCollectionV1"] = 39] = "UnverifyCollectionV1";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["Collect"] = 40] = "Collect";
  MplTokenMetadataInstruction2[MplTokenMetadataInstruction2["PrintV1"] = 41] = "PrintV1";
  return MplTokenMetadataInstruction2;
})(MplTokenMetadataInstruction || {});
function identifyMplTokenMetadataInstruction(instruction) {
  const data = instruction instanceof Uint8Array ? instruction : instruction.data;
  if (memcmp(data, getU8Encoder().encode(3), 0)) {
    return 0 /* DeprecatedMintNewEditionFromMasterEditionViaPrintingToken */;
  }
  if (memcmp(data, getU8Encoder().encode(7), 0)) {
    return 1 /* SignMetadata */;
  }
  if (memcmp(data, getU8Encoder().encode(11), 0)) {
    return 2 /* MintNewEditionFromMasterEditionViaToken */;
  }
  if (memcmp(data, getU8Encoder().encode(12), 0)) {
    return 3 /* ConvertMasterEditionV1ToV2 */;
  }
  if (memcmp(data, getU8Encoder().encode(13), 0)) {
    return 4 /* MintNewEditionFromMasterEditionViaVaultProxy */;
  }
  if (memcmp(data, getU8Encoder().encode(14), 0)) {
    return 5 /* PuffMetadata */;
  }
  if (memcmp(data, getU8Encoder().encode(17), 0)) {
    return 6 /* CreateMasterEditionV3 */;
  }
  if (memcmp(data, getU8Encoder().encode(18), 0)) {
    return 7 /* VerifyCollection */;
  }
  if (memcmp(data, getU8Encoder().encode(19), 0)) {
    return 8 /* Utilize */;
  }
  if (memcmp(data, getU8Encoder().encode(20), 0)) {
    return 9 /* ApproveUseAuthority */;
  }
  if (memcmp(data, getU8Encoder().encode(22), 0)) {
    return 10 /* UnverifyCollection */;
  }
  if (memcmp(data, getU8Encoder().encode(23), 0)) {
    return 11 /* ApproveCollectionAuthority */;
  }
  if (memcmp(data, getU8Encoder().encode(25), 0)) {
    return 12 /* SetAndVerifyCollection */;
  }
  if (memcmp(data, getU8Encoder().encode(26), 0)) {
    return 13 /* FreezeDelegatedAccount */;
  }
  if (memcmp(data, getU8Encoder().encode(27), 0)) {
    return 14 /* ThawDelegatedAccount */;
  }
  if (memcmp(data, getU8Encoder().encode(28), 0)) {
    return 15 /* RemoveCreatorVerification */;
  }
  if (memcmp(data, getU8Encoder().encode(29), 0)) {
    return 16 /* BurnNft */;
  }
  if (memcmp(data, getU8Encoder().encode(30), 0)) {
    return 17 /* VerifySizedCollectionItem */;
  }
  if (memcmp(data, getU8Encoder().encode(31), 0)) {
    return 18 /* UnverifySizedCollectionItem */;
  }
  if (memcmp(data, getU8Encoder().encode(32), 0)) {
    return 19 /* SetAndVerifySizedCollectionItem */;
  }
  if (memcmp(data, getU8Encoder().encode(33), 0)) {
    return 20 /* CreateMetadataAccountV3 */;
  }
  if (memcmp(data, getU8Encoder().encode(34), 0)) {
    return 21 /* SetCollectionSize */;
  }
  if (memcmp(data, getU8Encoder().encode(35), 0)) {
    return 22 /* SetTokenStandard */;
  }
  if (memcmp(data, getU8Encoder().encode(36), 0)) {
    return 23 /* BubblegumSetCollectionSize */;
  }
  if (memcmp(data, getU8Encoder().encode(37), 0)) {
    return 24 /* BurnEditionNft */;
  }
  if (memcmp(data, getU8Encoder().encode(38), 0)) {
    return 25 /* CreateEscrowAccount */;
  }
  if (memcmp(data, getU8Encoder().encode(39), 0)) {
    return 26 /* CloseEscrowAccount */;
  }
  if (memcmp(data, getU8Encoder().encode(40), 0)) {
    return 27 /* TransferOutOfEscrow */;
  }
  if (memcmp(data, getU8Encoder().encode(41), 0)) {
    return 28 /* BurnV1 */;
  }
  if (memcmp(data, getU8Encoder().encode(42), 0)) {
    return 29 /* CreateV1 */;
  }
  if (memcmp(data, getU8Encoder().encode(43), 0)) {
    return 30 /* MintV1 */;
  }
  if (memcmp(data, getU8Encoder().encode(46), 0)) {
    return 31 /* LockV1 */;
  }
  if (memcmp(data, getU8Encoder().encode(47), 0)) {
    return 32 /* UnlockV1 */;
  }
  if (memcmp(data, getU8Encoder().encode(48), 0)) {
    return 33 /* Migrate */;
  }
  if (memcmp(data, getU8Encoder().encode(49), 0)) {
    return 34 /* TransferV1 */;
  }
  if (memcmp(data, getU8Encoder().encode(51), 0)) {
    return 35 /* UseV1 */;
  }
  if (memcmp(data, getU8Encoder().encode(52), 0)) {
    return 36 /* VerifyCreatorV1 */;
  }
  if (memcmp(data, getU8Encoder().encode(52), 0)) {
    return 37 /* VerifyCollectionV1 */;
  }
  if (memcmp(data, getU8Encoder().encode(53), 0)) {
    return 38 /* UnverifyCreatorV1 */;
  }
  if (memcmp(data, getU8Encoder().encode(53), 0)) {
    return 39 /* UnverifyCollectionV1 */;
  }
  if (memcmp(data, getU8Encoder().encode(54), 0)) {
    return 40 /* Collect */;
  }
  if (memcmp(data, getU8Encoder().encode(55), 0)) {
    return 41 /* PrintV1 */;
  }
  throw new Error(
    "The provided instruction could not be identified as a mplTokenMetadata instruction."
  );
}
var findAtaPda = async (seeds) => {
  return await getProgramDerivedAddress$1({
    seeds: [
      getAddressEncoder$1().encode(seeds.owner),
      getAddressEncoder$1().encode(seeds.tokenProgramId ?? TOKEN_PROGRAM_ID),
      getAddressEncoder$1().encode(seeds.mint)
    ],
    programAddress: ASSOCIATED_TOKEN_ACCOUNTS_PROGRAM_ID
  });
};

// src/nft/mint.ts
var createDefaultNft = async (client, authority, owner, payer) => {
  const data = {
    name: "Example NFT",
    symbol: "EXNFT",
    uri: "https://example.com/nft",
    sellerFeeBasisPoints: 500,
    creators: [
      {
        address: authority.address,
        verified: true,
        share: 100
      }
    ],
    printSupply: printSupply("Zero")
  };
  const accounts = {
    authority,
    owner,
    payer,
    tokenProgramId: TOKEN_PROGRAM_ID
  };
  return await mintNft(client, accounts, data);
};
var createDefaultpNft = async (client, authority, owner, payer) => {
  const data = {
    name: "Example NFT",
    symbol: "EXNFT",
    uri: "https://example.com/nft",
    sellerFeeBasisPoints: 500,
    creators: [
      {
        address: authority.address,
        verified: true,
        share: 100
      }
    ],
    printSupply: printSupply("Zero"),
    tokenStandard: 4 /* ProgrammableNonFungible */
  };
  const accounts = {
    authority,
    owner,
    payer,
    tokenProgramId: TOKEN_PROGRAM_ID
  };
  return await mintNft(client, accounts, data);
};
var createDefaultToken22pNft = async (client, authority, owner, payer) => {
  const data = {
    name: "Example NFT",
    symbol: "EXNFT",
    uri: "https://example.com/nft",
    sellerFeeBasisPoints: 500,
    creators: [
      {
        address: authority.address,
        verified: true,
        share: 100
      }
    ],
    printSupply: printSupply("Zero"),
    tokenStandard: 4 /* ProgrammableNonFungible */
  };
  const accounts = {
    authority,
    owner,
    payer,
    tokenProgramId: TOKEN22_PROGRAM_ID
  };
  return await mintNft(client, accounts, data);
};
var createDefaultToken22Nft = async (client, authority, owner, payer) => {
  const data = {
    name: "Example NFT",
    symbol: "EXNFT",
    uri: "https://example.com/nft",
    sellerFeeBasisPoints: 500,
    creators: [
      {
        address: authority.address,
        verified: true,
        share: 100
      }
    ],
    printSupply: printSupply("Zero")
  };
  const accounts = {
    authority,
    owner,
    payer,
    tokenProgramId: TOKEN22_PROGRAM_ID
  };
  return await mintNft(client, accounts, data);
};
var mintNft = async (client, accounts, data) => {
  const {
    name,
    symbol,
    uri,
    sellerFeeBasisPoints,
    creators,
    primarySaleHappened = false,
    isMutable = true,
    tokenStandard = 0 /* NonFungible */,
    collection = null,
    uses = null,
    collectionDetails: collectionDetails2 = null,
    ruleSet = null,
    decimals = null,
    printSupply: printSupply2,
    isCollection = false
  } = data;
  const { authority, owner, tokenProgramId } = accounts;
  let { payer, mint } = accounts;
  if (payer === null) {
    payer = authority;
  }
  if (mint === void 0) {
    mint = await generateKeyPairSigner();
  }
  const [metadata] = await findMetadataPda({ mint: mint.address });
  const [masterEdition] = await findMasterEditionPda({ mint: mint.address });
  const [token] = await findAtaPda({
    owner: owner.address,
    mint: mint.address,
    tokenProgramId
  });
  let tokenRecord = void 0;
  if (tokenStandard === 4 /* ProgrammableNonFungible */) {
    [tokenRecord] = await findTokenRecordPda({ mint: mint.address, token });
  }
  const createIx = getCreateV1Instruction({
    metadata,
    masterEdition,
    mint,
    payer,
    authority,
    updateAuthority: authority,
    name,
    symbol,
    uri,
    sellerFeeBasisPoints,
    creators,
    primarySaleHappened,
    isMutable,
    tokenStandard,
    collection,
    uses,
    collectionDetails: collectionDetails2,
    ruleSet,
    decimals,
    printSupply: printSupply2,
    isCollection,
    splTokenProgram: tokenProgramId
  });
  const mintIx = getMintV1Instruction({
    token,
    tokenOwner: owner.address,
    metadata,
    masterEdition,
    mint: mint.address,
    authority,
    payer,
    tokenStandard,
    tokenRecord,
    splTokenProgram: tokenProgramId
  });
  await pipe(
    await createDefaultTransaction(client, owner.address),
    (tx) => appendTransactionInstruction(createIx, tx),
    (tx) => appendTransactionInstruction(mintIx, tx),
    (tx) => signAndSendTransaction(client, tx)
  );
  return {
    mint: mint.address,
    metadata,
    masterEdition,
    token,
    tokenRecord
  };
};

export { AuthorityType, Key, MPL_TOKEN_METADATA_PROGRAM_ADDRESS, MetadataDelegateRole, MigrationType, MplTokenMetadataAccount, MplTokenMetadataInstruction, MplTokenMetadataProgramError, MplTokenMetadataProgramErrorCode, PayloadKey, RevokeArgs, TokenDelegateRole, TokenStandard2 as TokenStandard, TokenState, UseMethod, VerificationArgs, accountMetaWithDefault, burnArgs, collectionDetails, collectionDetailsToggle, collectionToggle, createArgs, createDefaultNft, createDefaultToken22Nft, createDefaultToken22pNft, createDefaultpNft, decodeCollectionAuthorityRecord, decodeEdition, decodeEditionMarker, decodeEditionMarkerV2, decodeMasterEdition, decodeMetadata, decodeMetadataDelegateRecord, decodeTokenOwnedEscrow, decodeTokenRecord, decodeUseAuthorityRecord, delegateArgs, escrowAuthority, expectAddress, expectProgramDerivedAddress, expectSome, expectTransactionSigner, fetchAllCollectionAuthorityRecord, fetchAllEdition, fetchAllEditionMarker, fetchAllEditionMarkerV2, fetchAllMasterEdition, fetchAllMaybeCollectionAuthorityRecord, fetchAllMaybeEdition, fetchAllMaybeEditionMarker, fetchAllMaybeEditionMarkerV2, fetchAllMaybeMasterEdition, fetchAllMaybeMetadata, fetchAllMaybeMetadataDelegateRecord, fetchAllMaybeTokenOwnedEscrow, fetchAllMaybeTokenRecord, fetchAllMaybeUseAuthorityRecord, fetchAllMetadata, fetchAllMetadataDelegateRecord, fetchAllTokenOwnedEscrow, fetchAllTokenRecord, fetchAllUseAuthorityRecord, fetchCollectionAuthorityRecord, fetchCollectionAuthorityRecordFromSeeds, fetchEdition, fetchEditionMarker, fetchEditionMarkerFromSeeds, fetchEditionMarkerV2, fetchEditionMarkerV2FromSeeds, fetchMasterEdition, fetchMasterEditionFromSeeds, fetchMaybeCollectionAuthorityRecord, fetchMaybeCollectionAuthorityRecordFromSeeds, fetchMaybeEdition, fetchMaybeEditionMarker, fetchMaybeEditionMarkerFromSeeds, fetchMaybeEditionMarkerV2, fetchMaybeEditionMarkerV2FromSeeds, fetchMaybeMasterEdition, fetchMaybeMasterEditionFromSeeds, fetchMaybeMetadata, fetchMaybeMetadataDelegateRecord, fetchMaybeMetadataFromSeeds, fetchMaybeTokenOwnedEscrow, fetchMaybeTokenRecord, fetchMaybeTokenRecordFromSeeds, fetchMaybeUseAuthorityRecord, fetchMaybeUseAuthorityRecordFromSeeds, fetchMetadata, fetchMetadataDelegateRecord, fetchMetadataFromSeeds, fetchTokenOwnedEscrow, fetchTokenRecord, fetchTokenRecordFromSeeds, fetchUseAuthorityRecord, fetchUseAuthorityRecordFromSeeds, findAtaPda, findCollectionAuthorityRecordPda, findEditionMarkerPda, findEditionMarkerV2Pda, findMasterEditionPda, findMetadataPda, findTokenRecordPda, findUseAuthorityRecordPda, getAccountMetasWithSigners, getApproveCollectionAuthorityInstruction, getApproveCollectionAuthorityInstructionAsync, getApproveCollectionAuthorityInstructionDataCodec, getApproveCollectionAuthorityInstructionDataDecoder, getApproveCollectionAuthorityInstructionDataEncoder, getApproveCollectionAuthorityInstructionRaw, getApproveUseAuthorityInstruction, getApproveUseAuthorityInstructionAsync, getApproveUseAuthorityInstructionDataCodec, getApproveUseAuthorityInstructionDataDecoder, getApproveUseAuthorityInstructionDataEncoder, getApproveUseAuthorityInstructionRaw, getAuthorityTypeCodec, getAuthorityTypeDecoder, getAuthorityTypeEncoder, getAuthorizationDataCodec, getAuthorizationDataDecoder, getAuthorizationDataEncoder, getBubblegumSetCollectionSizeInstruction, getBubblegumSetCollectionSizeInstructionDataCodec, getBubblegumSetCollectionSizeInstructionDataDecoder, getBubblegumSetCollectionSizeInstructionDataEncoder, getBubblegumSetCollectionSizeInstructionRaw, getBurnArgsCodec, getBurnArgsDecoder, getBurnArgsEncoder, getBurnEditionNftInstruction, getBurnEditionNftInstructionDataCodec, getBurnEditionNftInstructionDataDecoder, getBurnEditionNftInstructionDataEncoder, getBurnEditionNftInstructionRaw, getBurnNftInstruction, getBurnNftInstructionAsync, getBurnNftInstructionDataCodec, getBurnNftInstructionDataDecoder, getBurnNftInstructionDataEncoder, getBurnNftInstructionRaw, getBurnV1Instruction, getBurnV1InstructionAsync, getBurnV1InstructionDataCodec, getBurnV1InstructionDataDecoder, getBurnV1InstructionDataEncoder, getBurnV1InstructionRaw, getCloseEscrowAccountInstruction, getCloseEscrowAccountInstructionAsync, getCloseEscrowAccountInstructionDataCodec, getCloseEscrowAccountInstructionDataDecoder, getCloseEscrowAccountInstructionDataEncoder, getCloseEscrowAccountInstructionRaw, getCollectInstruction, getCollectInstructionDataCodec, getCollectInstructionDataDecoder, getCollectInstructionDataEncoder, getCollectInstructionRaw, getCollectionAuthorityRecordAccountDataCodec, getCollectionAuthorityRecordAccountDataDecoder, getCollectionAuthorityRecordAccountDataEncoder, getCollectionCodec, getCollectionDecoder, getCollectionDetailsCodec, getCollectionDetailsDecoder, getCollectionDetailsEncoder, getCollectionDetailsToggleCodec, getCollectionDetailsToggleDecoder, getCollectionDetailsToggleEncoder, getCollectionEncoder, getCollectionToggleCodec, getCollectionToggleDecoder, getCollectionToggleEncoder, getConvertMasterEditionV1ToV2Instruction, getConvertMasterEditionV1ToV2InstructionDataCodec, getConvertMasterEditionV1ToV2InstructionDataDecoder, getConvertMasterEditionV1ToV2InstructionDataEncoder, getConvertMasterEditionV1ToV2InstructionRaw, getCreateArgsCodec, getCreateArgsDecoder, getCreateArgsEncoder, getCreateEscrowAccountInstruction, getCreateEscrowAccountInstructionAsync, getCreateEscrowAccountInstructionDataCodec, getCreateEscrowAccountInstructionDataDecoder, getCreateEscrowAccountInstructionDataEncoder, getCreateEscrowAccountInstructionRaw, getCreateMasterEditionV3Instruction, getCreateMasterEditionV3InstructionAsync, getCreateMasterEditionV3InstructionDataCodec, getCreateMasterEditionV3InstructionDataDecoder, getCreateMasterEditionV3InstructionDataEncoder, getCreateMasterEditionV3InstructionRaw, getCreateMetadataAccountV3Instruction, getCreateMetadataAccountV3InstructionAsync, getCreateMetadataAccountV3InstructionDataCodec, getCreateMetadataAccountV3InstructionDataDecoder, getCreateMetadataAccountV3InstructionDataEncoder, getCreateMetadataAccountV3InstructionRaw, getCreateV1Instruction, getCreateV1InstructionAsync, getCreateV1InstructionDataCodec, getCreateV1InstructionDataDecoder, getCreateV1InstructionDataEncoder, getCreateV1InstructionRaw, getCreatorCodec, getCreatorDecoder, getCreatorEncoder, getDataCodec, getDataDecoder, getDataEncoder, getDataV2Codec, getDataV2Decoder, getDataV2Encoder, getDelegateArgsCodec, getDelegateArgsDecoder, getDelegateArgsEncoder, getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstruction, getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionAsync, getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataCodec, getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataDecoder, getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataEncoder, getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionRaw, getEditionAccountDataCodec, getEditionAccountDataDecoder, getEditionAccountDataEncoder, getEditionMarkerAccountDataCodec, getEditionMarkerAccountDataDecoder, getEditionMarkerAccountDataEncoder, getEditionMarkerSize, getEditionMarkerV2AccountDataCodec, getEditionMarkerV2AccountDataDecoder, getEditionMarkerV2AccountDataEncoder, getEditionSize, getEscrowAuthorityCodec, getEscrowAuthorityDecoder, getEscrowAuthorityEncoder, getFreezeDelegatedAccountInstruction, getFreezeDelegatedAccountInstructionAsync, getFreezeDelegatedAccountInstructionDataCodec, getFreezeDelegatedAccountInstructionDataDecoder, getFreezeDelegatedAccountInstructionDataEncoder, getFreezeDelegatedAccountInstructionRaw, getKeyCodec, getKeyDecoder, getKeyEncoder, getLockArgsCodec, getLockArgsDecoder, getLockArgsEncoder, getLockV1Instruction, getLockV1InstructionAsync, getLockV1InstructionDataCodec, getLockV1InstructionDataDecoder, getLockV1InstructionDataEncoder, getLockV1InstructionRaw, getMasterEditionAccountDataCodec, getMasterEditionAccountDataDecoder, getMasterEditionAccountDataEncoder, getMetadataAccountDataCodec, getMetadataAccountDataDecoder, getMetadataAccountDataEncoder, getMetadataDelegateRecordAccountDataCodec, getMetadataDelegateRecordAccountDataDecoder, getMetadataDelegateRecordAccountDataEncoder, getMetadataDelegateRecordSize, getMetadataDelegateRoleCodec, getMetadataDelegateRoleDecoder, getMetadataDelegateRoleEncoder, getMigrateInstruction, getMigrateInstructionAsync, getMigrateInstructionDataCodec, getMigrateInstructionDataDecoder, getMigrateInstructionDataEncoder, getMigrateInstructionRaw, getMigrationTypeCodec, getMigrationTypeDecoder, getMigrationTypeEncoder, getMintArgsCodec, getMintArgsDecoder, getMintArgsEncoder, getMintNewEditionFromMasterEditionViaTokenArgsCodec, getMintNewEditionFromMasterEditionViaTokenArgsDecoder, getMintNewEditionFromMasterEditionViaTokenArgsEncoder, getMintNewEditionFromMasterEditionViaTokenInstruction, getMintNewEditionFromMasterEditionViaTokenInstructionDataCodec, getMintNewEditionFromMasterEditionViaTokenInstructionDataDecoder, getMintNewEditionFromMasterEditionViaTokenInstructionDataEncoder, getMintNewEditionFromMasterEditionViaTokenInstructionRaw, getMintNewEditionFromMasterEditionViaVaultProxyInstruction, getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataCodec, getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataDecoder, getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataEncoder, getMintNewEditionFromMasterEditionViaVaultProxyInstructionRaw, getMintV1Instruction, getMintV1InstructionAsync, getMintV1InstructionDataCodec, getMintV1InstructionDataDecoder, getMintV1InstructionDataEncoder, getMintV1InstructionRaw, getMplTokenMetadataProgram, getMplTokenMetadataProgramErrorFromCode, getPayloadCodec, getPayloadDecoder, getPayloadEncoder, getPayloadKeyCodec, getPayloadKeyDecoder, getPayloadKeyEncoder, getPayloadTypeCodec, getPayloadTypeDecoder, getPayloadTypeEncoder, getPrintArgsCodec, getPrintArgsDecoder, getPrintArgsEncoder, getPrintSupplyCodec, getPrintSupplyDecoder, getPrintSupplyEncoder, getPrintV1Instruction, getPrintV1InstructionAsync, getPrintV1InstructionDataCodec, getPrintV1InstructionDataDecoder, getPrintV1InstructionDataEncoder, getPrintV1InstructionRaw, getProgrammableConfigCodec, getProgrammableConfigDecoder, getProgrammableConfigEncoder, getProofInfoCodec, getProofInfoDecoder, getProofInfoEncoder, getPuffMetadataInstruction, getPuffMetadataInstructionDataCodec, getPuffMetadataInstructionDataDecoder, getPuffMetadataInstructionDataEncoder, getPuffMetadataInstructionRaw, getRemoveCreatorVerificationInstruction, getRemoveCreatorVerificationInstructionDataCodec, getRemoveCreatorVerificationInstructionDataDecoder, getRemoveCreatorVerificationInstructionDataEncoder, getRemoveCreatorVerificationInstructionRaw, getReservationCodec, getReservationDecoder, getReservationEncoder, getReservationV1Codec, getReservationV1Decoder, getReservationV1Encoder, getRevokeArgsCodec, getRevokeArgsDecoder, getRevokeArgsEncoder, getRuleSetToggleCodec, getRuleSetToggleDecoder, getRuleSetToggleEncoder, getSeedsVecCodec, getSeedsVecDecoder, getSeedsVecEncoder, getSetAndVerifyCollectionInstruction, getSetAndVerifyCollectionInstructionDataCodec, getSetAndVerifyCollectionInstructionDataDecoder, getSetAndVerifyCollectionInstructionDataEncoder, getSetAndVerifyCollectionInstructionRaw, getSetAndVerifySizedCollectionItemInstruction, getSetAndVerifySizedCollectionItemInstructionDataCodec, getSetAndVerifySizedCollectionItemInstructionDataDecoder, getSetAndVerifySizedCollectionItemInstructionDataEncoder, getSetAndVerifySizedCollectionItemInstructionRaw, getSetCollectionSizeArgsCodec, getSetCollectionSizeArgsDecoder, getSetCollectionSizeArgsEncoder, getSetCollectionSizeInstruction, getSetCollectionSizeInstructionDataCodec, getSetCollectionSizeInstructionDataDecoder, getSetCollectionSizeInstructionDataEncoder, getSetCollectionSizeInstructionRaw, getSetTokenStandardInstruction, getSetTokenStandardInstructionAsync, getSetTokenStandardInstructionDataCodec, getSetTokenStandardInstructionDataDecoder, getSetTokenStandardInstructionDataEncoder, getSetTokenStandardInstructionRaw, getSignMetadataInstruction, getSignMetadataInstructionDataCodec, getSignMetadataInstructionDataDecoder, getSignMetadataInstructionDataEncoder, getSignMetadataInstructionRaw, getThawDelegatedAccountInstruction, getThawDelegatedAccountInstructionAsync, getThawDelegatedAccountInstructionDataCodec, getThawDelegatedAccountInstructionDataDecoder, getThawDelegatedAccountInstructionDataEncoder, getThawDelegatedAccountInstructionRaw, getTokenDelegateRoleCodec, getTokenDelegateRoleDecoder, getTokenDelegateRoleEncoder, getTokenOwnedEscrowAccountDataCodec, getTokenOwnedEscrowAccountDataDecoder, getTokenOwnedEscrowAccountDataEncoder, getTokenRecordAccountDataCodec, getTokenRecordAccountDataDecoder, getTokenRecordAccountDataEncoder, getTokenRecordSize, getTokenStandardCodec, getTokenStandardDecoder, getTokenStandardEncoder, getTokenStateCodec, getTokenStateDecoder, getTokenStateEncoder, getTransferArgsCodec, getTransferArgsDecoder, getTransferArgsEncoder, getTransferOutOfEscrowInstruction, getTransferOutOfEscrowInstructionDataCodec, getTransferOutOfEscrowInstructionDataDecoder, getTransferOutOfEscrowInstructionDataEncoder, getTransferOutOfEscrowInstructionRaw, getTransferV1Instruction, getTransferV1InstructionAsync, getTransferV1InstructionDataCodec, getTransferV1InstructionDataDecoder, getTransferV1InstructionDataEncoder, getTransferV1InstructionRaw, getUnlockArgsCodec, getUnlockArgsDecoder, getUnlockArgsEncoder, getUnlockV1Instruction, getUnlockV1InstructionAsync, getUnlockV1InstructionDataCodec, getUnlockV1InstructionDataDecoder, getUnlockV1InstructionDataEncoder, getUnlockV1InstructionRaw, getUnverifyCollectionInstruction, getUnverifyCollectionInstructionDataCodec, getUnverifyCollectionInstructionDataDecoder, getUnverifyCollectionInstructionDataEncoder, getUnverifyCollectionInstructionRaw, getUnverifyCollectionV1Instruction, getUnverifyCollectionV1InstructionAsync, getUnverifyCollectionV1InstructionDataCodec, getUnverifyCollectionV1InstructionDataDecoder, getUnverifyCollectionV1InstructionDataEncoder, getUnverifyCollectionV1InstructionRaw, getUnverifyCreatorV1Instruction, getUnverifyCreatorV1InstructionDataCodec, getUnverifyCreatorV1InstructionDataDecoder, getUnverifyCreatorV1InstructionDataEncoder, getUnverifyCreatorV1InstructionRaw, getUnverifySizedCollectionItemInstruction, getUnverifySizedCollectionItemInstructionDataCodec, getUnverifySizedCollectionItemInstructionDataDecoder, getUnverifySizedCollectionItemInstructionDataEncoder, getUnverifySizedCollectionItemInstructionRaw, getUpdateArgsCodec, getUpdateArgsDecoder, getUpdateArgsEncoder, getUseArgsCodec, getUseArgsDecoder, getUseArgsEncoder, getUseAuthorityRecordAccountDataCodec, getUseAuthorityRecordAccountDataDecoder, getUseAuthorityRecordAccountDataEncoder, getUseAuthorityRecordSize, getUseMethodCodec, getUseMethodDecoder, getUseMethodEncoder, getUseV1Instruction, getUseV1InstructionAsync, getUseV1InstructionDataCodec, getUseV1InstructionDataDecoder, getUseV1InstructionDataEncoder, getUseV1InstructionRaw, getUsesCodec, getUsesDecoder, getUsesEncoder, getUsesToggleCodec, getUsesToggleDecoder, getUsesToggleEncoder, getUtilizeInstruction, getUtilizeInstructionAsync, getUtilizeInstructionDataCodec, getUtilizeInstructionDataDecoder, getUtilizeInstructionDataEncoder, getUtilizeInstructionRaw, getVerificationArgsCodec, getVerificationArgsDecoder, getVerificationArgsEncoder, getVerifyCollectionInstruction, getVerifyCollectionInstructionDataCodec, getVerifyCollectionInstructionDataDecoder, getVerifyCollectionInstructionDataEncoder, getVerifyCollectionInstructionRaw, getVerifyCollectionV1Instruction, getVerifyCollectionV1InstructionAsync, getVerifyCollectionV1InstructionDataCodec, getVerifyCollectionV1InstructionDataDecoder, getVerifyCollectionV1InstructionDataEncoder, getVerifyCollectionV1InstructionRaw, getVerifyCreatorV1Instruction, getVerifyCreatorV1InstructionDataCodec, getVerifyCreatorV1InstructionDataDecoder, getVerifyCreatorV1InstructionDataEncoder, getVerifyCreatorV1InstructionRaw, getVerifySizedCollectionItemInstruction, getVerifySizedCollectionItemInstructionDataCodec, getVerifySizedCollectionItemInstructionDataDecoder, getVerifySizedCollectionItemInstructionDataEncoder, getVerifySizedCollectionItemInstructionRaw, identifyMplTokenMetadataAccount, identifyMplTokenMetadataInstruction, isBurnArgs, isCollectionDetails, isCollectionDetailsToggle, isCollectionToggle, isCreateArgs, isDelegateArgs, isEscrowAuthority, isLockArgs, isMintArgs, isPayloadType, isPrintArgs, isPrintSupply, isProgrammableConfig, isRuleSetToggle, isTransactionSigner, isTransferArgs, isUnlockArgs, isUpdateArgs, isUseArgs, isUsesToggle, lockArgs, memcmp, mintArgs, mintNft, parseApproveCollectionAuthorityInstruction, parseApproveUseAuthorityInstruction, parseBubblegumSetCollectionSizeInstruction, parseBurnEditionNftInstruction, parseBurnNftInstruction, parseBurnV1Instruction, parseCloseEscrowAccountInstruction, parseCollectInstruction, parseConvertMasterEditionV1ToV2Instruction, parseCreateEscrowAccountInstruction, parseCreateMasterEditionV3Instruction, parseCreateMetadataAccountV3Instruction, parseCreateV1Instruction, parseDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstruction, parseFreezeDelegatedAccountInstruction, parseLockV1Instruction, parseMigrateInstruction, parseMintNewEditionFromMasterEditionViaTokenInstruction, parseMintNewEditionFromMasterEditionViaVaultProxyInstruction, parseMintV1Instruction, parsePrintV1Instruction, parsePuffMetadataInstruction, parseRemoveCreatorVerificationInstruction, parseSetAndVerifyCollectionInstruction, parseSetAndVerifySizedCollectionItemInstruction, parseSetCollectionSizeInstruction, parseSetTokenStandardInstruction, parseSignMetadataInstruction, parseThawDelegatedAccountInstruction, parseTransferOutOfEscrowInstruction, parseTransferV1Instruction, parseUnlockV1Instruction, parseUnverifyCollectionInstruction, parseUnverifyCollectionV1Instruction, parseUnverifyCreatorV1Instruction, parseUnverifySizedCollectionItemInstruction, parseUseV1Instruction, parseUtilizeInstruction, parseVerifyCollectionInstruction, parseVerifyCollectionV1Instruction, parseVerifyCreatorV1Instruction, parseVerifySizedCollectionItemInstruction, payloadType, printArgs, printSupply, programmableConfig, ruleSetToggle, transferArgs, unlockArgs, updateArgs, useArgs, usesToggle };
//# sourceMappingURL=out.js.map
//# sourceMappingURL=index.js.map